# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from scalekit.v1.emails import emails_pb2 as scalekit_dot_v1_dot_emails_dot_emails__pb2


class EmailServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetTemplatePlaceholders = channel.unary_unary(
                '/scalekit.v1.emails.EmailService/GetTemplatePlaceholders',
                request_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetPlaceholdersRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetPlaceholdersResponse.FromString,
                )
        self.GetTemplateUseCases = channel.unary_unary(
                '/scalekit.v1.emails.EmailService/GetTemplateUseCases',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetTemplateUseCasesResponse.FromString,
                )
        self.CreateEmailTemplate = channel.unary_unary(
                '/scalekit.v1.emails.EmailService/CreateEmailTemplate',
                request_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.CreateEmailTemplateRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.CreateEmailTemplateResponse.FromString,
                )
        self.UpdateEmailTemplate = channel.unary_unary(
                '/scalekit.v1.emails.EmailService/UpdateEmailTemplate',
                request_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.PatchEmailTemplateRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailTemplateResponse.FromString,
                )
        self.GetEmailConfiguration = channel.unary_unary(
                '/scalekit.v1.emails.EmailService/GetEmailConfiguration',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailConfigurationResponse.FromString,
                )
        self.UpsertEmailConfiguration = channel.unary_unary(
                '/scalekit.v1.emails.EmailService/UpsertEmailConfiguration',
                request_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.UpsertEmailConfigurationRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.UpsertEmailConfigurationResponse.FromString,
                )
        self.EnableEmailTemplate = channel.unary_unary(
                '/scalekit.v1.emails.EmailService/EnableEmailTemplate',
                request_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.EnableEmailTemplateRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.EnableEmailTemplateResponse.FromString,
                )
        self.DisableEmailTemplate = channel.unary_unary(
                '/scalekit.v1.emails.EmailService/DisableEmailTemplate',
                request_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.DisableEmailTemplateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetEmailTemplate = channel.unary_unary(
                '/scalekit.v1.emails.EmailService/GetEmailTemplate',
                request_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailTemplateRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailTemplateResponse.FromString,
                )
        self.ListEmailTemplates = channel.unary_unary(
                '/scalekit.v1.emails.EmailService/ListEmailTemplates',
                request_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.ListEmailTemplateRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.ListEmailTemplateResponse.FromString,
                )
        self.DeleteEmailTemplate = channel.unary_unary(
                '/scalekit.v1.emails.EmailService/DeleteEmailTemplate',
                request_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.DeleteEmailTemplateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.CreateEmailServer = channel.unary_unary(
                '/scalekit.v1.emails.EmailService/CreateEmailServer',
                request_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.CreateEmailServerRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.CreateEmailServerResponse.FromString,
                )
        self.UpdateEmailServerSettings = channel.unary_unary(
                '/scalekit.v1.emails.EmailService/UpdateEmailServerSettings',
                request_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.PatchEmailServerSettingsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailServerResponse.FromString,
                )
        self.EnableEmailServer = channel.unary_unary(
                '/scalekit.v1.emails.EmailService/EnableEmailServer',
                request_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.EnableEmailServerRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.EnableEmailServerResponse.FromString,
                )
        self.DisableEmailServer = channel.unary_unary(
                '/scalekit.v1.emails.EmailService/DisableEmailServer',
                request_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.DisableEmailServerRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetEmailServer = channel.unary_unary(
                '/scalekit.v1.emails.EmailService/GetEmailServer',
                request_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailServerRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailServerResponse.FromString,
                )
        self.ListEmailServers = channel.unary_unary(
                '/scalekit.v1.emails.EmailService/ListEmailServers',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.ListEmailServerResponse.FromString,
                )
        self.DeleteEmailServer = channel.unary_unary(
                '/scalekit.v1.emails.EmailService/DeleteEmailServer',
                request_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.DeleteEmailServerRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class EmailServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetTemplatePlaceholders(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTemplateUseCases(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateEmailTemplate(self, request, context):
        """For templates

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateEmailTemplate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEmailConfiguration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpsertEmailConfiguration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnableEmailTemplate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisableEmailTemplate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEmailTemplate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListEmailTemplates(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteEmailTemplate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateEmailServer(self, request, context):
        """Email Server Services
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateEmailServerSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnableEmailServer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisableEmailServer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEmailServer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListEmailServers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteEmailServer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_EmailServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetTemplatePlaceholders': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTemplatePlaceholders,
                    request_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetPlaceholdersRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetPlaceholdersResponse.SerializeToString,
            ),
            'GetTemplateUseCases': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTemplateUseCases,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetTemplateUseCasesResponse.SerializeToString,
            ),
            'CreateEmailTemplate': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateEmailTemplate,
                    request_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.CreateEmailTemplateRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.CreateEmailTemplateResponse.SerializeToString,
            ),
            'UpdateEmailTemplate': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateEmailTemplate,
                    request_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.PatchEmailTemplateRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailTemplateResponse.SerializeToString,
            ),
            'GetEmailConfiguration': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEmailConfiguration,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailConfigurationResponse.SerializeToString,
            ),
            'UpsertEmailConfiguration': grpc.unary_unary_rpc_method_handler(
                    servicer.UpsertEmailConfiguration,
                    request_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.UpsertEmailConfigurationRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.UpsertEmailConfigurationResponse.SerializeToString,
            ),
            'EnableEmailTemplate': grpc.unary_unary_rpc_method_handler(
                    servicer.EnableEmailTemplate,
                    request_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.EnableEmailTemplateRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.EnableEmailTemplateResponse.SerializeToString,
            ),
            'DisableEmailTemplate': grpc.unary_unary_rpc_method_handler(
                    servicer.DisableEmailTemplate,
                    request_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.DisableEmailTemplateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetEmailTemplate': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEmailTemplate,
                    request_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailTemplateRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailTemplateResponse.SerializeToString,
            ),
            'ListEmailTemplates': grpc.unary_unary_rpc_method_handler(
                    servicer.ListEmailTemplates,
                    request_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.ListEmailTemplateRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.ListEmailTemplateResponse.SerializeToString,
            ),
            'DeleteEmailTemplate': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteEmailTemplate,
                    request_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.DeleteEmailTemplateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateEmailServer': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateEmailServer,
                    request_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.CreateEmailServerRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.CreateEmailServerResponse.SerializeToString,
            ),
            'UpdateEmailServerSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateEmailServerSettings,
                    request_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.PatchEmailServerSettingsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailServerResponse.SerializeToString,
            ),
            'EnableEmailServer': grpc.unary_unary_rpc_method_handler(
                    servicer.EnableEmailServer,
                    request_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.EnableEmailServerRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.EnableEmailServerResponse.SerializeToString,
            ),
            'DisableEmailServer': grpc.unary_unary_rpc_method_handler(
                    servicer.DisableEmailServer,
                    request_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.DisableEmailServerRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetEmailServer': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEmailServer,
                    request_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailServerRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailServerResponse.SerializeToString,
            ),
            'ListEmailServers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListEmailServers,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.ListEmailServerResponse.SerializeToString,
            ),
            'DeleteEmailServer': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteEmailServer,
                    request_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.DeleteEmailServerRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'scalekit.v1.emails.EmailService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class EmailService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetTemplatePlaceholders(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.emails.EmailService/GetTemplatePlaceholders',
            scalekit_dot_v1_dot_emails_dot_emails__pb2.GetPlaceholdersRequest.SerializeToString,
            scalekit_dot_v1_dot_emails_dot_emails__pb2.GetPlaceholdersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTemplateUseCases(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.emails.EmailService/GetTemplateUseCases',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            scalekit_dot_v1_dot_emails_dot_emails__pb2.GetTemplateUseCasesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateEmailTemplate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.emails.EmailService/CreateEmailTemplate',
            scalekit_dot_v1_dot_emails_dot_emails__pb2.CreateEmailTemplateRequest.SerializeToString,
            scalekit_dot_v1_dot_emails_dot_emails__pb2.CreateEmailTemplateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateEmailTemplate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.emails.EmailService/UpdateEmailTemplate',
            scalekit_dot_v1_dot_emails_dot_emails__pb2.PatchEmailTemplateRequest.SerializeToString,
            scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailTemplateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEmailConfiguration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.emails.EmailService/GetEmailConfiguration',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailConfigurationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpsertEmailConfiguration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.emails.EmailService/UpsertEmailConfiguration',
            scalekit_dot_v1_dot_emails_dot_emails__pb2.UpsertEmailConfigurationRequest.SerializeToString,
            scalekit_dot_v1_dot_emails_dot_emails__pb2.UpsertEmailConfigurationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnableEmailTemplate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.emails.EmailService/EnableEmailTemplate',
            scalekit_dot_v1_dot_emails_dot_emails__pb2.EnableEmailTemplateRequest.SerializeToString,
            scalekit_dot_v1_dot_emails_dot_emails__pb2.EnableEmailTemplateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DisableEmailTemplate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.emails.EmailService/DisableEmailTemplate',
            scalekit_dot_v1_dot_emails_dot_emails__pb2.DisableEmailTemplateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEmailTemplate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.emails.EmailService/GetEmailTemplate',
            scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailTemplateRequest.SerializeToString,
            scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailTemplateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListEmailTemplates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.emails.EmailService/ListEmailTemplates',
            scalekit_dot_v1_dot_emails_dot_emails__pb2.ListEmailTemplateRequest.SerializeToString,
            scalekit_dot_v1_dot_emails_dot_emails__pb2.ListEmailTemplateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteEmailTemplate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.emails.EmailService/DeleteEmailTemplate',
            scalekit_dot_v1_dot_emails_dot_emails__pb2.DeleteEmailTemplateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateEmailServer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.emails.EmailService/CreateEmailServer',
            scalekit_dot_v1_dot_emails_dot_emails__pb2.CreateEmailServerRequest.SerializeToString,
            scalekit_dot_v1_dot_emails_dot_emails__pb2.CreateEmailServerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateEmailServerSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.emails.EmailService/UpdateEmailServerSettings',
            scalekit_dot_v1_dot_emails_dot_emails__pb2.PatchEmailServerSettingsRequest.SerializeToString,
            scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailServerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnableEmailServer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.emails.EmailService/EnableEmailServer',
            scalekit_dot_v1_dot_emails_dot_emails__pb2.EnableEmailServerRequest.SerializeToString,
            scalekit_dot_v1_dot_emails_dot_emails__pb2.EnableEmailServerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DisableEmailServer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.emails.EmailService/DisableEmailServer',
            scalekit_dot_v1_dot_emails_dot_emails__pb2.DisableEmailServerRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEmailServer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.emails.EmailService/GetEmailServer',
            scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailServerRequest.SerializeToString,
            scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailServerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListEmailServers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.emails.EmailService/ListEmailServers',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            scalekit_dot_v1_dot_emails_dot_emails__pb2.ListEmailServerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteEmailServer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.emails.EmailService/DeleteEmailServer',
            scalekit_dot_v1_dot_emails_dot_emails__pb2.DeleteEmailServerRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
