# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from scalekit.v1.directories import directories_pb2 as scalekit_dot_v1_dot_directories_dot_directories__pb2


class DirectoryServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateDirectory = channel.unary_unary(
                '/scalekit.v1.directories.DirectoryService/CreateDirectory',
                request_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.CreateDirectoryRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.CreateDirectoryResponse.FromString,
                )
        self.DeleteDirectory = channel.unary_unary(
                '/scalekit.v1.directories.DirectoryService/DeleteDirectory',
                request_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.DeleteDirectoryRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateDirectory = channel.unary_unary(
                '/scalekit.v1.directories.DirectoryService/UpdateDirectory',
                request_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.UpdateDirectoryRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.UpdateDirectoryResponse.FromString,
                )
        self.AssignGroupsForDirectory = channel.unary_unary(
                '/scalekit.v1.directories.DirectoryService/AssignGroupsForDirectory',
                request_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.AssignGroupsForDirectoryRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.AssignRoles = channel.unary_unary(
                '/scalekit.v1.directories.DirectoryService/AssignRoles',
                request_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.AssignRolesRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.AssignRolesResponse.FromString,
                )
        self.UpdateAttributes = channel.unary_unary(
                '/scalekit.v1.directories.DirectoryService/UpdateAttributes',
                request_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.UpdateAttributesRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.UpdateAttributesResponse.FromString,
                )
        self.GetDirectory = channel.unary_unary(
                '/scalekit.v1.directories.DirectoryService/GetDirectory',
                request_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.GetDirectoryRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.GetDirectoryResponse.FromString,
                )
        self.ListDirectories = channel.unary_unary(
                '/scalekit.v1.directories.DirectoryService/ListDirectories',
                request_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoriesRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoriesResponse.FromString,
                )
        self.EnableDirectory = channel.unary_unary(
                '/scalekit.v1.directories.DirectoryService/EnableDirectory',
                request_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ToggleDirectoryRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ToggleDirectoryResponse.FromString,
                )
        self.DisableDirectory = channel.unary_unary(
                '/scalekit.v1.directories.DirectoryService/DisableDirectory',
                request_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ToggleDirectoryRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ToggleDirectoryResponse.FromString,
                )
        self.ListDirectoryUsers = channel.unary_unary(
                '/scalekit.v1.directories.DirectoryService/ListDirectoryUsers',
                request_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoryUsersRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoryUsersResponse.FromString,
                )
        self.ListDirectoryGroups = channel.unary_unary(
                '/scalekit.v1.directories.DirectoryService/ListDirectoryGroups',
                request_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoryGroupsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoryGroupsResponse.FromString,
                )
        self.ListDirectoryGroupsSummary = channel.unary_unary(
                '/scalekit.v1.directories.DirectoryService/ListDirectoryGroupsSummary',
                request_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoryGroupsSummaryRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoryGroupsResponse.FromString,
                )
        self.CreateDirectorySecret = channel.unary_unary(
                '/scalekit.v1.directories.DirectoryService/CreateDirectorySecret',
                request_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.CreateDirectorySecretRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.CreateDirectorySecretResponse.FromString,
                )
        self.RegenerateDirectorySecret = channel.unary_unary(
                '/scalekit.v1.directories.DirectoryService/RegenerateDirectorySecret',
                request_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.RegenerateDirectorySecretRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.RegenerateDirectorySecretResponse.FromString,
                )
        self.TriggerDirectorySync = channel.unary_unary(
                '/scalekit.v1.directories.DirectoryService/TriggerDirectorySync',
                request_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.TriggerDirectorySyncRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class DirectoryServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateDirectory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDirectory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDirectory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AssignGroupsForDirectory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AssignRoles(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAttributes(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDirectory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDirectories(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnableDirectory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisableDirectory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDirectoryUsers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDirectoryGroups(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDirectoryGroupsSummary(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDirectorySecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegenerateDirectorySecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerDirectorySync(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DirectoryServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateDirectory': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDirectory,
                    request_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.CreateDirectoryRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.CreateDirectoryResponse.SerializeToString,
            ),
            'DeleteDirectory': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDirectory,
                    request_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.DeleteDirectoryRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateDirectory': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDirectory,
                    request_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.UpdateDirectoryRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.UpdateDirectoryResponse.SerializeToString,
            ),
            'AssignGroupsForDirectory': grpc.unary_unary_rpc_method_handler(
                    servicer.AssignGroupsForDirectory,
                    request_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.AssignGroupsForDirectoryRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'AssignRoles': grpc.unary_unary_rpc_method_handler(
                    servicer.AssignRoles,
                    request_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.AssignRolesRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.AssignRolesResponse.SerializeToString,
            ),
            'UpdateAttributes': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAttributes,
                    request_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.UpdateAttributesRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.UpdateAttributesResponse.SerializeToString,
            ),
            'GetDirectory': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDirectory,
                    request_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.GetDirectoryRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.GetDirectoryResponse.SerializeToString,
            ),
            'ListDirectories': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDirectories,
                    request_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoriesRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoriesResponse.SerializeToString,
            ),
            'EnableDirectory': grpc.unary_unary_rpc_method_handler(
                    servicer.EnableDirectory,
                    request_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ToggleDirectoryRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ToggleDirectoryResponse.SerializeToString,
            ),
            'DisableDirectory': grpc.unary_unary_rpc_method_handler(
                    servicer.DisableDirectory,
                    request_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ToggleDirectoryRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ToggleDirectoryResponse.SerializeToString,
            ),
            'ListDirectoryUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDirectoryUsers,
                    request_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoryUsersRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoryUsersResponse.SerializeToString,
            ),
            'ListDirectoryGroups': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDirectoryGroups,
                    request_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoryGroupsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoryGroupsResponse.SerializeToString,
            ),
            'ListDirectoryGroupsSummary': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDirectoryGroupsSummary,
                    request_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoryGroupsSummaryRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoryGroupsResponse.SerializeToString,
            ),
            'CreateDirectorySecret': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDirectorySecret,
                    request_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.CreateDirectorySecretRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.CreateDirectorySecretResponse.SerializeToString,
            ),
            'RegenerateDirectorySecret': grpc.unary_unary_rpc_method_handler(
                    servicer.RegenerateDirectorySecret,
                    request_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.RegenerateDirectorySecretRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.RegenerateDirectorySecretResponse.SerializeToString,
            ),
            'TriggerDirectorySync': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerDirectorySync,
                    request_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.TriggerDirectorySyncRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'scalekit.v1.directories.DirectoryService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DirectoryService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateDirectory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.directories.DirectoryService/CreateDirectory',
            scalekit_dot_v1_dot_directories_dot_directories__pb2.CreateDirectoryRequest.SerializeToString,
            scalekit_dot_v1_dot_directories_dot_directories__pb2.CreateDirectoryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDirectory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.directories.DirectoryService/DeleteDirectory',
            scalekit_dot_v1_dot_directories_dot_directories__pb2.DeleteDirectoryRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDirectory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.directories.DirectoryService/UpdateDirectory',
            scalekit_dot_v1_dot_directories_dot_directories__pb2.UpdateDirectoryRequest.SerializeToString,
            scalekit_dot_v1_dot_directories_dot_directories__pb2.UpdateDirectoryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AssignGroupsForDirectory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.directories.DirectoryService/AssignGroupsForDirectory',
            scalekit_dot_v1_dot_directories_dot_directories__pb2.AssignGroupsForDirectoryRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AssignRoles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.directories.DirectoryService/AssignRoles',
            scalekit_dot_v1_dot_directories_dot_directories__pb2.AssignRolesRequest.SerializeToString,
            scalekit_dot_v1_dot_directories_dot_directories__pb2.AssignRolesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAttributes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.directories.DirectoryService/UpdateAttributes',
            scalekit_dot_v1_dot_directories_dot_directories__pb2.UpdateAttributesRequest.SerializeToString,
            scalekit_dot_v1_dot_directories_dot_directories__pb2.UpdateAttributesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDirectory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.directories.DirectoryService/GetDirectory',
            scalekit_dot_v1_dot_directories_dot_directories__pb2.GetDirectoryRequest.SerializeToString,
            scalekit_dot_v1_dot_directories_dot_directories__pb2.GetDirectoryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDirectories(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.directories.DirectoryService/ListDirectories',
            scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoriesRequest.SerializeToString,
            scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoriesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnableDirectory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.directories.DirectoryService/EnableDirectory',
            scalekit_dot_v1_dot_directories_dot_directories__pb2.ToggleDirectoryRequest.SerializeToString,
            scalekit_dot_v1_dot_directories_dot_directories__pb2.ToggleDirectoryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DisableDirectory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.directories.DirectoryService/DisableDirectory',
            scalekit_dot_v1_dot_directories_dot_directories__pb2.ToggleDirectoryRequest.SerializeToString,
            scalekit_dot_v1_dot_directories_dot_directories__pb2.ToggleDirectoryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDirectoryUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.directories.DirectoryService/ListDirectoryUsers',
            scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoryUsersRequest.SerializeToString,
            scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoryUsersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDirectoryGroups(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.directories.DirectoryService/ListDirectoryGroups',
            scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoryGroupsRequest.SerializeToString,
            scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoryGroupsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDirectoryGroupsSummary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.directories.DirectoryService/ListDirectoryGroupsSummary',
            scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoryGroupsSummaryRequest.SerializeToString,
            scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoryGroupsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDirectorySecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.directories.DirectoryService/CreateDirectorySecret',
            scalekit_dot_v1_dot_directories_dot_directories__pb2.CreateDirectorySecretRequest.SerializeToString,
            scalekit_dot_v1_dot_directories_dot_directories__pb2.CreateDirectorySecretResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegenerateDirectorySecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.directories.DirectoryService/RegenerateDirectorySecret',
            scalekit_dot_v1_dot_directories_dot_directories__pb2.RegenerateDirectorySecretRequest.SerializeToString,
            scalekit_dot_v1_dot_directories_dot_directories__pb2.RegenerateDirectorySecretResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerDirectorySync(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.directories.DirectoryService/TriggerDirectorySync',
            scalekit_dot_v1_dot_directories_dot_directories__pb2.TriggerDirectorySyncRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
