# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from scalekit.v1.connections import connections_pb2 as scalekit_dot_v1_dot_connections_dot_connections__pb2


class ConnectionServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateEnvironmentConnection = channel.unary_unary(
                '/scalekit.v1.connections.ConnectionService/CreateEnvironmentConnection',
                request_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.CreateEnvironmentConnectionRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.CreateConnectionResponse.FromString,
                )
        self.CreateConnection = channel.unary_unary(
                '/scalekit.v1.connections.ConnectionService/CreateConnection',
                request_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.CreateConnectionRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.CreateConnectionResponse.FromString,
                )
        self.AssignDomainsToConnection = channel.unary_unary(
                '/scalekit.v1.connections.ConnectionService/AssignDomainsToConnection',
                request_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.AssignDomainsToConnectionRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.AssignDomainsToConnectionResponse.FromString,
                )
        self.GetEnvironmentConnection = channel.unary_unary(
                '/scalekit.v1.connections.ConnectionService/GetEnvironmentConnection',
                request_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.GetEnvironmentConnectionRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.GetConnectionResponse.FromString,
                )
        self.GetConnection = channel.unary_unary(
                '/scalekit.v1.connections.ConnectionService/GetConnection',
                request_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.GetConnectionRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.GetConnectionResponse.FromString,
                )
        self.ListConnections = channel.unary_unary(
                '/scalekit.v1.connections.ConnectionService/ListConnections',
                request_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ListConnectionsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ListConnectionsResponse.FromString,
                )
        self.ListOrganizationConnections = channel.unary_unary(
                '/scalekit.v1.connections.ConnectionService/ListOrganizationConnections',
                request_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ListOrganizationConnectionsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ListOrganizationConnectionsResponse.FromString,
                )
        self.SearchOrganizationConnections = channel.unary_unary(
                '/scalekit.v1.connections.ConnectionService/SearchOrganizationConnections',
                request_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.SearchOrganizationConnectionsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.SearchOrganizationConnectionsResponse.FromString,
                )
        self.UpdateEnvironmentConnection = channel.unary_unary(
                '/scalekit.v1.connections.ConnectionService/UpdateEnvironmentConnection',
                request_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.UpdateEnvironmentConnectionRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.UpdateConnectionResponse.FromString,
                )
        self.UpdateConnection = channel.unary_unary(
                '/scalekit.v1.connections.ConnectionService/UpdateConnection',
                request_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.UpdateConnectionRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.UpdateConnectionResponse.FromString,
                )
        self.DeleteEnvironmentConnection = channel.unary_unary(
                '/scalekit.v1.connections.ConnectionService/DeleteEnvironmentConnection',
                request_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.DeleteEnvironmentConnectionRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DeleteConnection = channel.unary_unary(
                '/scalekit.v1.connections.ConnectionService/DeleteConnection',
                request_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.DeleteConnectionRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.EnableEnvironmentConnection = channel.unary_unary(
                '/scalekit.v1.connections.ConnectionService/EnableEnvironmentConnection',
                request_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleEnvironmentConnectionRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleConnectionResponse.FromString,
                )
        self.EnableConnection = channel.unary_unary(
                '/scalekit.v1.connections.ConnectionService/EnableConnection',
                request_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleConnectionRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleConnectionResponse.FromString,
                )
        self.DisableEnvironmentConnection = channel.unary_unary(
                '/scalekit.v1.connections.ConnectionService/DisableEnvironmentConnection',
                request_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleEnvironmentConnectionRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleConnectionResponse.FromString,
                )
        self.DisableConnection = channel.unary_unary(
                '/scalekit.v1.connections.ConnectionService/DisableConnection',
                request_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleConnectionRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleConnectionResponse.FromString,
                )
        self.GetConnectionTestResult = channel.unary_unary(
                '/scalekit.v1.connections.ConnectionService/GetConnectionTestResult',
                request_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.GetConnectionTestResultRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.GetConnectionTestResultResponse.FromString,
                )
        self.ListAppConnections = channel.unary_unary(
                '/scalekit.v1.connections.ConnectionService/ListAppConnections',
                request_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ListAppConnectionsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ListAppConnectionsResponse.FromString,
                )


class ConnectionServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateEnvironmentConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AssignDomainsToConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEnvironmentConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListConnections(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOrganizationConnections(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchOrganizationConnections(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateEnvironmentConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteEnvironmentConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnableEnvironmentConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnableConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisableEnvironmentConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisableConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetConnectionTestResult(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAppConnections(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ConnectionServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateEnvironmentConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateEnvironmentConnection,
                    request_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.CreateEnvironmentConnectionRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.CreateConnectionResponse.SerializeToString,
            ),
            'CreateConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateConnection,
                    request_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.CreateConnectionRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.CreateConnectionResponse.SerializeToString,
            ),
            'AssignDomainsToConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.AssignDomainsToConnection,
                    request_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.AssignDomainsToConnectionRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.AssignDomainsToConnectionResponse.SerializeToString,
            ),
            'GetEnvironmentConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEnvironmentConnection,
                    request_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.GetEnvironmentConnectionRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.GetConnectionResponse.SerializeToString,
            ),
            'GetConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.GetConnection,
                    request_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.GetConnectionRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.GetConnectionResponse.SerializeToString,
            ),
            'ListConnections': grpc.unary_unary_rpc_method_handler(
                    servicer.ListConnections,
                    request_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ListConnectionsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ListConnectionsResponse.SerializeToString,
            ),
            'ListOrganizationConnections': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOrganizationConnections,
                    request_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ListOrganizationConnectionsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ListOrganizationConnectionsResponse.SerializeToString,
            ),
            'SearchOrganizationConnections': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchOrganizationConnections,
                    request_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.SearchOrganizationConnectionsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.SearchOrganizationConnectionsResponse.SerializeToString,
            ),
            'UpdateEnvironmentConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateEnvironmentConnection,
                    request_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.UpdateEnvironmentConnectionRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.UpdateConnectionResponse.SerializeToString,
            ),
            'UpdateConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateConnection,
                    request_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.UpdateConnectionRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.UpdateConnectionResponse.SerializeToString,
            ),
            'DeleteEnvironmentConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteEnvironmentConnection,
                    request_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.DeleteEnvironmentConnectionRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DeleteConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteConnection,
                    request_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.DeleteConnectionRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'EnableEnvironmentConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.EnableEnvironmentConnection,
                    request_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleEnvironmentConnectionRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleConnectionResponse.SerializeToString,
            ),
            'EnableConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.EnableConnection,
                    request_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleConnectionRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleConnectionResponse.SerializeToString,
            ),
            'DisableEnvironmentConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.DisableEnvironmentConnection,
                    request_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleEnvironmentConnectionRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleConnectionResponse.SerializeToString,
            ),
            'DisableConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.DisableConnection,
                    request_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleConnectionRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleConnectionResponse.SerializeToString,
            ),
            'GetConnectionTestResult': grpc.unary_unary_rpc_method_handler(
                    servicer.GetConnectionTestResult,
                    request_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.GetConnectionTestResultRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.GetConnectionTestResultResponse.SerializeToString,
            ),
            'ListAppConnections': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAppConnections,
                    request_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ListAppConnectionsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ListAppConnectionsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'scalekit.v1.connections.ConnectionService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ConnectionService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateEnvironmentConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connections.ConnectionService/CreateEnvironmentConnection',
            scalekit_dot_v1_dot_connections_dot_connections__pb2.CreateEnvironmentConnectionRequest.SerializeToString,
            scalekit_dot_v1_dot_connections_dot_connections__pb2.CreateConnectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connections.ConnectionService/CreateConnection',
            scalekit_dot_v1_dot_connections_dot_connections__pb2.CreateConnectionRequest.SerializeToString,
            scalekit_dot_v1_dot_connections_dot_connections__pb2.CreateConnectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AssignDomainsToConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connections.ConnectionService/AssignDomainsToConnection',
            scalekit_dot_v1_dot_connections_dot_connections__pb2.AssignDomainsToConnectionRequest.SerializeToString,
            scalekit_dot_v1_dot_connections_dot_connections__pb2.AssignDomainsToConnectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEnvironmentConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connections.ConnectionService/GetEnvironmentConnection',
            scalekit_dot_v1_dot_connections_dot_connections__pb2.GetEnvironmentConnectionRequest.SerializeToString,
            scalekit_dot_v1_dot_connections_dot_connections__pb2.GetConnectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connections.ConnectionService/GetConnection',
            scalekit_dot_v1_dot_connections_dot_connections__pb2.GetConnectionRequest.SerializeToString,
            scalekit_dot_v1_dot_connections_dot_connections__pb2.GetConnectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListConnections(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connections.ConnectionService/ListConnections',
            scalekit_dot_v1_dot_connections_dot_connections__pb2.ListConnectionsRequest.SerializeToString,
            scalekit_dot_v1_dot_connections_dot_connections__pb2.ListConnectionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOrganizationConnections(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connections.ConnectionService/ListOrganizationConnections',
            scalekit_dot_v1_dot_connections_dot_connections__pb2.ListOrganizationConnectionsRequest.SerializeToString,
            scalekit_dot_v1_dot_connections_dot_connections__pb2.ListOrganizationConnectionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SearchOrganizationConnections(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connections.ConnectionService/SearchOrganizationConnections',
            scalekit_dot_v1_dot_connections_dot_connections__pb2.SearchOrganizationConnectionsRequest.SerializeToString,
            scalekit_dot_v1_dot_connections_dot_connections__pb2.SearchOrganizationConnectionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateEnvironmentConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connections.ConnectionService/UpdateEnvironmentConnection',
            scalekit_dot_v1_dot_connections_dot_connections__pb2.UpdateEnvironmentConnectionRequest.SerializeToString,
            scalekit_dot_v1_dot_connections_dot_connections__pb2.UpdateConnectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connections.ConnectionService/UpdateConnection',
            scalekit_dot_v1_dot_connections_dot_connections__pb2.UpdateConnectionRequest.SerializeToString,
            scalekit_dot_v1_dot_connections_dot_connections__pb2.UpdateConnectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteEnvironmentConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connections.ConnectionService/DeleteEnvironmentConnection',
            scalekit_dot_v1_dot_connections_dot_connections__pb2.DeleteEnvironmentConnectionRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connections.ConnectionService/DeleteConnection',
            scalekit_dot_v1_dot_connections_dot_connections__pb2.DeleteConnectionRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnableEnvironmentConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connections.ConnectionService/EnableEnvironmentConnection',
            scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleEnvironmentConnectionRequest.SerializeToString,
            scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleConnectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnableConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connections.ConnectionService/EnableConnection',
            scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleConnectionRequest.SerializeToString,
            scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleConnectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DisableEnvironmentConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connections.ConnectionService/DisableEnvironmentConnection',
            scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleEnvironmentConnectionRequest.SerializeToString,
            scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleConnectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DisableConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connections.ConnectionService/DisableConnection',
            scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleConnectionRequest.SerializeToString,
            scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleConnectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetConnectionTestResult(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connections.ConnectionService/GetConnectionTestResult',
            scalekit_dot_v1_dot_connections_dot_connections__pb2.GetConnectionTestResultRequest.SerializeToString,
            scalekit_dot_v1_dot_connections_dot_connections__pb2.GetConnectionTestResultResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAppConnections(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connections.ConnectionService/ListAppConnections',
            scalekit_dot_v1_dot_connections_dot_connections__pb2.ListAppConnectionsRequest.SerializeToString,
            scalekit_dot_v1_dot_connections_dot_connections__pb2.ListAppConnectionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
