# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from scalekit.v1.connected_accounts import connected_accounts_pb2 as scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2


class ConnectedAccountServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListConnectedAccounts = channel.unary_unary(
                '/scalekit.v1.connected_accounts.ConnectedAccountService/ListConnectedAccounts',
                request_serializer=scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.ListConnectedAccountsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.ListConnectedAccountsResponse.FromString,
                )
        self.SearchConnectedAccounts = channel.unary_unary(
                '/scalekit.v1.connected_accounts.ConnectedAccountService/SearchConnectedAccounts',
                request_serializer=scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.SearchConnectedAccountsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.SearchConnectedAccountsResponse.FromString,
                )
        self.CreateConnectedAccount = channel.unary_unary(
                '/scalekit.v1.connected_accounts.ConnectedAccountService/CreateConnectedAccount',
                request_serializer=scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.CreateConnectedAccountRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.CreateConnectedAccountResponse.FromString,
                )
        self.UpdateConnectedAccount = channel.unary_unary(
                '/scalekit.v1.connected_accounts.ConnectedAccountService/UpdateConnectedAccount',
                request_serializer=scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.UpdateConnectedAccountRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.UpdateConnectedAccountResponse.FromString,
                )
        self.DeleteConnectedAccount = channel.unary_unary(
                '/scalekit.v1.connected_accounts.ConnectedAccountService/DeleteConnectedAccount',
                request_serializer=scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.DeleteConnectedAccountRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.DeleteConnectedAccountResponse.FromString,
                )
        self.GetMagicLinkForConnectedAccount = channel.unary_unary(
                '/scalekit.v1.connected_accounts.ConnectedAccountService/GetMagicLinkForConnectedAccount',
                request_serializer=scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.GetMagicLinkForConnectedAccountRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.GetMagicLinkForConnectedAccountResponse.FromString,
                )
        self.GetConnectedAccountAuth = channel.unary_unary(
                '/scalekit.v1.connected_accounts.ConnectedAccountService/GetConnectedAccountAuth',
                request_serializer=scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.GetConnectedAccountByIdentifierRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.GetConnectedAccountByIdentifierResponse.FromString,
                )
        self.GetMagicLinkForConnectedAccountWithRedirect = channel.unary_unary(
                '/scalekit.v1.connected_accounts.ConnectedAccountService/GetMagicLinkForConnectedAccountWithRedirect',
                request_serializer=scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.GetMagicLinkForConnectedAccountRedirectRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.GetMagicLinkForConnectedAccountRedirectResponse.FromString,
                )


class ConnectedAccountServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListConnectedAccounts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchConnectedAccounts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateConnectedAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateConnectedAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteConnectedAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMagicLinkForConnectedAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetConnectedAccountAuth(self, request, context):
        """this will return the auth details for a connected account by its identifier
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMagicLinkForConnectedAccountWithRedirect(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ConnectedAccountServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListConnectedAccounts': grpc.unary_unary_rpc_method_handler(
                    servicer.ListConnectedAccounts,
                    request_deserializer=scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.ListConnectedAccountsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.ListConnectedAccountsResponse.SerializeToString,
            ),
            'SearchConnectedAccounts': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchConnectedAccounts,
                    request_deserializer=scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.SearchConnectedAccountsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.SearchConnectedAccountsResponse.SerializeToString,
            ),
            'CreateConnectedAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateConnectedAccount,
                    request_deserializer=scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.CreateConnectedAccountRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.CreateConnectedAccountResponse.SerializeToString,
            ),
            'UpdateConnectedAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateConnectedAccount,
                    request_deserializer=scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.UpdateConnectedAccountRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.UpdateConnectedAccountResponse.SerializeToString,
            ),
            'DeleteConnectedAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteConnectedAccount,
                    request_deserializer=scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.DeleteConnectedAccountRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.DeleteConnectedAccountResponse.SerializeToString,
            ),
            'GetMagicLinkForConnectedAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMagicLinkForConnectedAccount,
                    request_deserializer=scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.GetMagicLinkForConnectedAccountRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.GetMagicLinkForConnectedAccountResponse.SerializeToString,
            ),
            'GetConnectedAccountAuth': grpc.unary_unary_rpc_method_handler(
                    servicer.GetConnectedAccountAuth,
                    request_deserializer=scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.GetConnectedAccountByIdentifierRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.GetConnectedAccountByIdentifierResponse.SerializeToString,
            ),
            'GetMagicLinkForConnectedAccountWithRedirect': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMagicLinkForConnectedAccountWithRedirect,
                    request_deserializer=scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.GetMagicLinkForConnectedAccountRedirectRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.GetMagicLinkForConnectedAccountRedirectResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'scalekit.v1.connected_accounts.ConnectedAccountService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ConnectedAccountService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListConnectedAccounts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connected_accounts.ConnectedAccountService/ListConnectedAccounts',
            scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.ListConnectedAccountsRequest.SerializeToString,
            scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.ListConnectedAccountsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SearchConnectedAccounts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connected_accounts.ConnectedAccountService/SearchConnectedAccounts',
            scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.SearchConnectedAccountsRequest.SerializeToString,
            scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.SearchConnectedAccountsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateConnectedAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connected_accounts.ConnectedAccountService/CreateConnectedAccount',
            scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.CreateConnectedAccountRequest.SerializeToString,
            scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.CreateConnectedAccountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateConnectedAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connected_accounts.ConnectedAccountService/UpdateConnectedAccount',
            scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.UpdateConnectedAccountRequest.SerializeToString,
            scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.UpdateConnectedAccountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteConnectedAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connected_accounts.ConnectedAccountService/DeleteConnectedAccount',
            scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.DeleteConnectedAccountRequest.SerializeToString,
            scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.DeleteConnectedAccountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMagicLinkForConnectedAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connected_accounts.ConnectedAccountService/GetMagicLinkForConnectedAccount',
            scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.GetMagicLinkForConnectedAccountRequest.SerializeToString,
            scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.GetMagicLinkForConnectedAccountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetConnectedAccountAuth(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connected_accounts.ConnectedAccountService/GetConnectedAccountAuth',
            scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.GetConnectedAccountByIdentifierRequest.SerializeToString,
            scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.GetConnectedAccountByIdentifierResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMagicLinkForConnectedAccountWithRedirect(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connected_accounts.ConnectedAccountService/GetMagicLinkForConnectedAccountWithRedirect',
            scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.GetMagicLinkForConnectedAccountRedirectRequest.SerializeToString,
            scalekit_dot_v1_dot_connected__accounts_dot_connected__accounts__pb2.GetMagicLinkForConnectedAccountRedirectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
