# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: scalekit/v1/environments/environments.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from scalekit.v1.commons import commons_pb2 as scalekit_dot_v1_dot_commons_dot_commons__pb2
from scalekit.v1.options import options_pb2 as scalekit_dot_v1_dot_options_dot_options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+scalekit/v1/environments/environments.proto\x12\x18scalekit.v1.environments\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a!scalekit/v1/commons/commons.proto\x1a!scalekit/v1/options/options.proto\"o\n\x19\x43reateCustomDomainRequest\x12\x1e\n\x02id\x18\x01 \x01(\tB\x0e\xbaH\x0br\t\x10\x01\x18 :\x03\x65nvR\x02id\x12\x32\n\rcustom_domain\x18\x02 \x01(\tB\r\xbaH\nr\x05\x10\x01\x18\xfa\x01\xc8\x01\x01R\x0c\x63ustomDomain\"e\n\x1a\x43reateCustomDomainResponse\x12G\n\x0b\x65nvironment\x18\x01 \x01(\x0b\x32%.scalekit.v1.environments.EnvironmentR\x0b\x65nvironment\"j\n\x14GetDNSRecordsRequest\x12\x1e\n\x02id\x18\x01 \x01(\tB\x0e\xbaH\x0br\t\x10\x01\x18 :\x03\x65nvR\x02id\x12\x32\n\rcustom_domain\x18\x02 \x01(\tB\r\xbaH\nr\x05\x10\x01\x18\xfa\x01\xc8\x01\x01R\x0c\x63ustomDomain\"^\n\x15GetDNSRecordsResponse\x12\x45\n\x0b\x64ns_records\x18\x01 \x03(\x0b\x32$.scalekit.v1.environments.DNSRecordsR\ndnsRecords\"w\n\nDNSRecords\x12\'\n\thost_name\x18\x01 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xfa\x01R\x08hostName\x12\x1e\n\x04type\x18\x02 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xfa\x01R\x04type\x12 \n\x05value\x18\x03 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xfa\x01R\x05value\"\x92\x04\n\x0b\x45nvironment\x12\x1e\n\x02id\x18\x01 \x01(\tB\x0e\xbaH\x0br\t\x10\x01\x18 :\x03\x65nvR\x02id\x12;\n\x0b\x63reate_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ncreateTime\x12;\n\x0bupdate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nupdateTime\x12-\n\x0c\x64isplay_name\x18\x04 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xc8\x01R\x0b\x64isplayName\x12\"\n\x06\x64omain\x18\x05 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xfa\x01R\x06\x64omain\x12@\n\x0bregion_code\x18\x06 \x01(\x0e\x32\x1f.scalekit.v1.commons.RegionCodeR\nregionCode\x12\x38\n\x04type\x18\x07 \x01(\x0e\x32$.scalekit.v1.commons.EnvironmentTypeR\x04type\x12(\n\rcustom_domain\x18\x08 \x01(\tH\x00R\x0c\x63ustomDomain\x88\x01\x01\x12^\n\x14\x63ustom_domain_status\x18\t \x01(\x0e\x32,.scalekit.v1.environments.CustomDomainStatusR\x12\x63ustomDomainStatusB\x10\n\x0e_custom_domain\"\xe7\x01\n\x11\x43reateEnvironment\x12-\n\x0c\x64isplay_name\x18\x04 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xc8\x01R\x0b\x64isplayName\x12\x45\n\x0bregion_code\x18\x06 \x01(\x0e\x32\x1f.scalekit.v1.commons.RegionCodeH\x00R\nregionCode\x88\x01\x01\x12=\n\x04type\x18\x07 \x01(\x0e\x32$.scalekit.v1.commons.EnvironmentTypeH\x01R\x04type\x88\x01\x01\x42\x0e\n\x0c_region_codeB\x07\n\x05_typeJ\x04\x08\x05\x10\x06\"j\n\x11UpdateEnvironment\x12\x32\n\x0c\x64isplay_name\x18\x04 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xd0\x0fH\x00R\x0b\x64isplayName\x88\x01\x01\x42\x0f\n\r_display_nameJ\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08\"S\n\x17UpdateEnvironmentDomain\x12\'\n\x06\x64omain\x18\x05 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xfa\x01H\x00R\x06\x64omain\x88\x01\x01\x42\t\n\x07_domainJ\x04\x08\x04\x10\x05\"q\n\x18\x43reateEnvironmentRequest\x12U\n\x0b\x65nvironment\x18\x01 \x01(\x0b\x32+.scalekit.v1.environments.CreateEnvironmentB\x06\xbaH\x03\xc8\x01\x01R\x0b\x65nvironment\"d\n\x19\x43reateEnvironmentResponse\x12G\n\x0b\x65nvironment\x18\x01 \x01(\x0b\x32%.scalekit.v1.environments.EnvironmentR\x0b\x65nvironment\"\x91\x01\n\x18UpdateEnvironmentRequest\x12\x1e\n\x02id\x18\x01 \x01(\tB\x0e\xbaH\x0br\t\x10\x01\x18 :\x03\x65nvR\x02id\x12U\n\x0b\x65nvironment\x18\x02 \x01(\x0b\x32+.scalekit.v1.environments.UpdateEnvironmentB\x06\xbaH\x03\xc8\x01\x01R\x0b\x65nvironment\"\x9d\x01\n\x1eUpdateEnvironmentDomainRequest\x12\x1e\n\x02id\x18\x01 \x01(\tB\x0e\xbaH\x0br\t\x10\x01\x18 :\x03\x65nvR\x02id\x12[\n\x0b\x65nvironment\x18\x02 \x01(\x0b\x32\x31.scalekit.v1.environments.UpdateEnvironmentDomainB\x06\xbaH\x03\xc8\x01\x01R\x0b\x65nvironment\"d\n\x19UpdateEnvironmentResponse\x12G\n\x0b\x65nvironment\x18\x01 \x01(\x0b\x32%.scalekit.v1.environments.EnvironmentR\x0b\x65nvironment\"7\n\x15GetEnvironmentRequest\x12\x1e\n\x02id\x18\x01 \x01(\tB\x0e\xbaH\x0br\t\x10\x01\x18 :\x03\x65nvR\x02id\"a\n\x16GetEnvironmentResponse\x12G\n\x0b\x65nvironment\x18\x01 \x01(\x0b\x32%.scalekit.v1.environments.EnvironmentR\x0b\x65nvironment\"U\n\x17ListEnvironmentsRequest\x12\x1b\n\tpage_size\x18\x01 \x01(\rR\x08pageSize\x12\x1d\n\npage_token\x18\x02 \x01(\tR\tpageToken\"\xac\x01\n\x18ListEnvironmentsResponse\x12&\n\x0fnext_page_token\x18\x01 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x02 \x01(\rR\ttotalSize\x12I\n\x0c\x65nvironments\x18\x03 \x03(\x0b\x32%.scalekit.v1.environments.EnvironmentR\x0c\x65nvironments\":\n\x18\x44\x65leteEnvironmentRequest\x12\x1e\n\x02id\x18\x01 \x01(\tB\x0e\xbaH\x0br\t\x10\x01\x18 :\x03\x65nvR\x02id\"@\n\x1eGenerateSamlCertificateRequest\x12\x1e\n\x02id\x18\x01 \x01(\tB\x0e\xbaH\x0br\t\x10\x01\x18 :\x03\x65nvR\x02id\"k\n\x1fGenerateSamlCertificateResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12 \n\x0b\x63\x65rtificate\x18\x02 \x01(\tR\x0b\x63\x65rtificate\x12\x16\n\x06\x65xpiry\x18\x03 \x01(\x03R\x06\x65xpiry\"\x99\x01\n!UpdatePortalCustomizationResponse\x12$\n\renvironmentId\x18\x01 \x01(\tR\renvironmentId\x12N\n\x16\x63ustomization_settings\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructR\x15\x63ustomizationSettings\"\x9a\x01\n UpdatePortalCustomizationRequest\x12\x1e\n\x02id\x18\x01 \x01(\tB\x0e\xbaH\x0br\t\x10\x01\x18 :\x03\x65nvR\x02id\x12V\n\x16\x63ustomization_settings\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x06\xbaH\x03\xc8\x01\x01R\x15\x63ustomizationSettings\":\n\x1dGetPortalCustomizationRequest\x12\x19\n\x02id\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x00\x18 R\x02id\"\x96\x01\n\x1eGetPortalCustomizationResponse\x12$\n\renvironmentId\x18\x01 \x01(\tR\renvironmentId\x12N\n\x16\x63ustomization_settings\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructR\x15\x63ustomizationSettings\"Z\n\x1c\x43reateAssetUploadUrlResponse\x12\x1d\n\nupload_url\x18\x01 \x01(\tR\tuploadUrl\x12\x1b\n\tfetch_url\x18\x02 \x01(\tR\x08\x66\x65tchUrl\"\x8d\x01\n\x1b\x43reateAssetUploadUrlRequest\x12\x1e\n\x02id\x18\x01 \x01(\tB\x0e\xbaH\x0br\t\x10\x01\x18 :\x03\x65nvR\x02id\x12N\n\x0e\x61sset_settings\x18\x02 \x01(\x0b\x32\'.scalekit.v1.environments.AssetSettingsR\rassetSettings\"\x91\x01\n\rAssetSettings\x12K\n\x08\x63\x61tegory\x18\x01 \x01(\x0e\x32\'.scalekit.v1.environments.AssetCategoryB\x06\xbaH\x03\xc8\x01\x01R\x08\x63\x61tegory\x12\x33\n\textension\x18\x02 \x01(\tB\x15\xbaH\x12r\x10R\x03jpgR\x04jpegR\x03pngR\textension\"\x89\x01\n\x15UpdateFeaturesRequest\x12\x1e\n\x02id\x18\x01 \x01(\tB\x0e\xbaH\x0br\t\x10\x01\x18 :\x03\x65nvR\x02id\x12P\n\x08\x66\x65\x61tures\x18\x02 \x03(\x0b\x32,.scalekit.v1.environments.EnvironmentFeatureB\x06\xbaH\x03\xc8\x01\x01R\x08\x66\x65\x61tures\"9\n\x17\x45nableFSAFeatureRequest\x12\x1e\n\x02id\x18\x01 \x01(\tB\x0e\xbaH\x0br\t\x10\x01\x18 :\x03\x65nvR\x02id\"4\n\x12GetFeaturesRequest\x12\x1e\n\x02id\x18\x01 \x01(\tB\x0e\xbaH\x0br\t\x10\x01\x18 :\x03\x65nvR\x02id\"_\n\x13GetFeaturesResponse\x12H\n\x08\x66\x65\x61tures\x18\x01 \x03(\x0b\x32,.scalekit.v1.environments.EnvironmentFeatureR\x08\x66\x65\x61tures\"`\n\x14\x45nableFeatureRequest\x12\x1e\n\x02id\x18\x01 \x01(\tB\x0e\xbaH\x0br\t\x10\x01\x18 :\x03\x65nvR\x02id\x12(\n\nfeature_id\x18\x02 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18 R\tfeatureId\"a\n\x15\x44isableFeatureRequest\x12\x1e\n\x02id\x18\x01 \x01(\tB\x0e\xbaH\x0br\t\x10\x01\x18 :\x03\x65nvR\x02id\x12(\n\nfeature_id\x18\x02 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18 R\tfeatureId\"B\n\x12\x45nvironmentFeature\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x18\n\x07\x65nabled\x18\x02 \x01(\x08R\x07\x65nabled\"F\n$GetEnvironmentSessionSettingsRequest\x12\x1e\n\x02id\x18\x01 \x01(\tB\x0e\xbaH\x0br\t\x10\x01\x18 :\x03\x65nvR\x02id\"E\n#GetEnvironmentUserManagementRequest\x12\x1e\n\x02id\x18\x01 \x01(\tB\x0e\xbaH\x0br\t\x10\x01\x18 :\x03\x65nvR\x02id\"}\n%GetEnvironmentSessionSettingsResponse\x12T\n\x10session_settings\x18\x01 \x01(\x0b\x32).scalekit.v1.environments.SessionSettingsR\x0fsessionSettings\"y\n$GetEnvironmentUserManagementResponse\x12Q\n\x0fuser_management\x18\x01 \x01(\x0b\x32(.scalekit.v1.environments.UserManagementR\x0euserManagement\"\xa7\x01\n\'CreateEnvironmentSessionSettingsRequest\x12\x1e\n\x02id\x18\x01 \x01(\tB\x0e\xbaH\x0br\t\x10\x01\x18 :\x03\x65nvR\x02id\x12\\\n\x10session_settings\x18\x02 \x01(\x0b\x32).scalekit.v1.environments.SessionSettingsB\x06\xbaH\x03\xc8\x01\x01R\x0fsessionSettings\"\xa3\x01\n&CreateEnvironmentUserManagementRequest\x12\x1e\n\x02id\x18\x01 \x01(\tB\x0e\xbaH\x0br\t\x10\x01\x18 :\x03\x65nvR\x02id\x12Y\n\x0fuser_management\x18\x02 \x01(\x0b\x32(.scalekit.v1.environments.UserManagementB\x06\xbaH\x03\xc8\x01\x01R\x0euserManagement\"\xa7\x01\n(CreateEnvironmentSessionSettingsResponse\x12%\n\x0e\x65nvironment_id\x18\x01 \x01(\tR\renvironmentId\x12T\n\x10session_settings\x18\x02 \x01(\x0b\x32).scalekit.v1.environments.SessionSettingsR\x0fsessionSettings\"\xa3\x01\n\'CreateEnvironmentUserManagementResponse\x12%\n\x0e\x65nvironment_id\x18\x01 \x01(\tR\renvironmentId\x12Q\n\x0fuser_management\x18\x02 \x01(\x0b\x32(.scalekit.v1.environments.UserManagementR\x0euserManagement\"\xa7\x01\n\'UpdateEnvironmentSessionSettingsRequest\x12\x1e\n\x02id\x18\x01 \x01(\tB\x0e\xbaH\x0br\t\x10\x01\x18 :\x03\x65nvR\x02id\x12\\\n\x10session_settings\x18\x02 \x01(\x0b\x32).scalekit.v1.environments.SessionSettingsB\x06\xbaH\x03\xc8\x01\x01R\x0fsessionSettings\"\xa3\x01\n&UpdateEnvironmentUserManagementRequest\x12\x1e\n\x02id\x18\x01 \x01(\tB\x0e\xbaH\x0br\t\x10\x01\x18 :\x03\x65nvR\x02id\x12Y\n\x0fuser_management\x18\x02 \x01(\x0b\x32(.scalekit.v1.environments.UserManagementB\x06\xbaH\x03\xc8\x01\x01R\x0euserManagement\"\xa7\x01\n(UpdateEnvironmentSessionSettingsResponse\x12%\n\x0e\x65nvironment_id\x18\x01 \x01(\tR\renvironmentId\x12T\n\x10session_settings\x18\x02 \x01(\x0b\x32).scalekit.v1.environments.SessionSettingsR\x0fsessionSettings\"\xa3\x01\n\'UpdateEnvironmentUserManagementResponse\x12%\n\x0e\x65nvironment_id\x18\x01 \x01(\tR\renvironmentId\x12Q\n\x0fuser_management\x18\x02 \x01(\x0b\x32(.scalekit.v1.environments.UserManagementR\x0euserManagement\"\xdc\x06\n\x0fSessionSettings\x12X\n\x13\x61\x63\x63\x65ss_token_expiry\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueB\x0b\xbaH\x08\x1a\x06\x18\xc0\xd1\x02(\x01R\x11\x61\x63\x63\x65ssTokenExpiry\x12\x65\n\x1a\x63lient_access_token_expiry\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueB\x0b\xbaH\x08\x1a\x06\x18\xc0\xd1\x02(\x01R\x17\x63lientAccessTokenExpiry\x12\x62\n\x18\x61\x62solute_session_timeout\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueB\x0b\xbaH\x08\x1a\x06\x18\xa0\x8a (\x01R\x16\x61\x62soluteSessionTimeout\x12X\n\x1asession_management_enabled\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x18sessionManagementEnabled\x12Y\n\x14idle_session_timeout\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueB\n\xbaH\x07\x1a\x05\x18\xe0N(\x01R\x12idleSessionTimeout\x12L\n\x14idle_session_enabled\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x12idleSessionEnabled\x12g\n\x17\x63ookie_persistence_type\x18\x07 \x01(\x0e\x32/.scalekit.v1.environments.CookiePersistenceTypeR\x15\x63ookiePersistenceType\x12h\n\x18\x63ookie_same_site_setting\x18\x08 \x01(\x0e\x32/.scalekit.v1.environments.CookieSameSiteSettingR\x15\x63ookieSameSiteSetting\x12N\n\x14\x63ookie_custom_domain\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x12\x63ookieCustomDomain\"\xf1\x05\n\x0eUserManagement\x12\x61\n\x1f\x61llow_duplicate_user_identities\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x1c\x61llowDuplicateUserIdentities\x12X\n\x1a\x61llow_multiple_memberships\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x18\x61llowMultipleMemberships\x12V\n\x19\x61llow_organization_signup\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x17\x61llowOrganizationSignup\x12o\n\x15org_user_relationship\x18\x04 \x01(\x0e\x32\x31.scalekit.v1.environments.OrgUserRelationshipTypeB\x08\xbaH\x05\x82\x01\x02\x10\x01R\x13orgUserRelationship\x12O\n\x16\x65nable_max_users_limit\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x13\x65nableMaxUsersLimit\x12P\n\x0fmax_users_limit\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueB\x0b\xbaH\x08\x1a\x06\x18\x9f\x8d\x06(\x01R\rmaxUsersLimit\x12V\n\x11invitation_expiry\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0b\xbaH\x08*\x06\x18\xc0\xd1\x02(\x01R\x10invitationExpiry\x12^\n\x16organization_meta_name\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\n\xbaH\x07r\x05\x10\x01\x18\xc8\x01R\x14organizationMetaName\":\n\x11GetContextRequest\x12%\n\x0e\x65nvironment_id\x18\x02 \x01(\tR\renvironmentId\"G\n\x12GetContextResponse\x12\x31\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x17.google.protobuf.StructR\x07\x63ontext\"p\n\x14UpdateContextRequest\x12%\n\x0e\x65nvironment_id\x18\x02 \x01(\tR\renvironmentId\x12\x31\n\x07\x63ontext\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\x07\x63ontext\"*\n\x18GetCurrentSessionRequest\x12\x0e\n\x02id\x18\x02 \x01(\tR\x02id\"\xc3\x02\n\x19GetCurrentSessionResponse\x12\x46\n\x0esession_expiry\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\rsessionExpiry\x88\x01\x01\x12J\n\x13\x61\x63\x63\x65ss_token_expiry\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11\x61\x63\x63\x65ssTokenExpiry\x12,\n\x0forganization_id\x18\x03 \x01(\tH\x01R\x0eorganizationId\x88\x01\x01\x12\x18\n\x07subject\x18\x04 \x01(\tR\x07subject\x12\x19\n\x05\x65mail\x18\x05 \x01(\tH\x02R\x05\x65mail\x88\x01\x01\x42\x11\n\x0f_session_expiryB\x12\n\x10_organization_idB\x08\n\x06_email\"\xc5\x01\n\x10ResourceMetadata\x12K\n\x04type\x18\x01 \x01(\x0e\x32\x37.scalekit.v1.environments.ResourceMetadata.ResourceTypeR\x04type\x12 \n\x0bidentifiers\x18\x02 \x03(\tR\x0bidentifiers\"B\n\x0cResourceType\x12\x10\n\x0corganization\x10\x00\x12\x0e\n\nconnection\x10\x01\x12\x10\n\x0c\x61uth_request\x10\x02\"c\n\x17ScalekitResourceRequest\x12H\n\tresources\x18\x01 \x03(\x0b\x32*.scalekit.v1.environments.ResourceMetadataR\tresources\"\xd2\x01\n\x18ScalekitResourceResponse\x12_\n\tresources\x18\x01 \x03(\x0b\x32\x41.scalekit.v1.environments.ScalekitResourceResponse.ResourcesEntryR\tresources\x1aU\n\x0eResourcesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructR\x05value:\x02\x38\x01*W\n\x12\x43ustomDomainStatus\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x12\x0b\n\x07INITIAL\x10\x04*O\n\rAssetCategory\x12\x1e\n\x1a\x41SSET_CATEGORY_UNSPECIFIED\x10\x00\x12\x1e\n\x1aPORTAL_CUSTOMIZATION_IMAGE\x10\x01*w\n\x17OrgUserRelationshipType\x12\'\n#OrgUserRelationshipType_UNSPECIFIED\x10\x00\x12\x17\n\x13SINGLE_ORGANIZATION\x10\x01\x12\x1a\n\x16MULTIPLE_ORGANIZATIONS\x10\x02*[\n\x15\x43ookiePersistenceType\x12%\n!CookiePersistenceType_UNSPECIFIED\x10\x00\x12\x0e\n\nPERSISTENT\x10\x01\x12\x0b\n\x07SESSION\x10\x02*[\n\x15\x43ookieSameSiteSetting\x12%\n!CookieSameSiteSetting_UNSPECIFIED\x10\x00\x12\x0c\n\x08LAX_MODE\x10\x01\x12\r\n\tNONE_MODE\x10\x02\x32\xce,\n\x12\x45nvironmentService\x12\xad\x01\n\x11\x43reateEnvironment\x12\x32.scalekit.v1.environments.CreateEnvironmentRequest\x1a\x33.scalekit.v1.environments.CreateEnvironmentResponse\"/\x82\xb5\x18\x02\x18T\x82\xd3\xe4\x93\x02#\"\x14/api/v1/environments:\x0b\x65nvironment\x12\xb2\x01\n\x11UpdateEnvironment\x12\x32.scalekit.v1.environments.UpdateEnvironmentRequest\x1a\x33.scalekit.v1.environments.UpdateEnvironmentResponse\"4\x82\xb5\x18\x02\x18P\x82\xd3\xe4\x93\x02(2\x19/api/v1/environments/{id}:\x0b\x65nvironment\x12\xc5\x01\n\x17UpdateEnvironmentDomain\x12\x38.scalekit.v1.environments.UpdateEnvironmentDomainRequest\x1a\x33.scalekit.v1.environments.UpdateEnvironmentResponse\";\x82\xb5\x18\x02\x18@\x82\xd3\xe4\x93\x02/2 /api/v1/environments/{id}:update:\x0b\x65nvironment\x12\x9c\x01\n\x0eGetEnvironment\x12/.scalekit.v1.environments.GetEnvironmentRequest\x1a\x30.scalekit.v1.environments.GetEnvironmentResponse\"\'\x82\xb5\x18\x02\x18P\x82\xd3\xe4\x93\x02\x1b\x12\x19/api/v1/environments/{id}\x12\x9c\x01\n\x0fListEnvironment\x12\x31.scalekit.v1.environments.ListEnvironmentsRequest\x1a\x32.scalekit.v1.environments.ListEnvironmentsResponse\"\"\x82\xb5\x18\x02\x18P\x82\xd3\xe4\x93\x02\x16\x12\x14/api/v1/environments\x12\x86\x01\n\x11\x44\x65leteEnvironment\x12\x32.scalekit.v1.environments.DeleteEnvironmentRequest\x1a\x16.google.protobuf.Empty\"%\x82\xb5\x18\x00\x82\xd3\xe4\x93\x02\x1b*\x19/api/v1/environments/{id}\x12\xa8\x01\n\x15GetRequiredDNSRecords\x12..scalekit.v1.environments.GetDNSRecordsRequest\x1a/.scalekit.v1.environments.GetDNSRecordsResponse\".\x82\xb5\x18\x02\x18T\x82\xd3\xe4\x93\x02\"\"\x1d/api/v1/environments/{id}/dns:\x01*\x12\x91\x01\n\x10VerifyDNSRecords\x12..scalekit.v1.environments.GetDNSRecordsRequest\x1a\x16.google.protobuf.Empty\"5\x82\xb5\x18\x02\x18T\x82\xd3\xe4\x93\x02)\"$/api/v1/environments/{id}/dns:verify:\x01*\x12\xba\x01\n\x12\x43reateCustomDomain\x12\x33.scalekit.v1.environments.CreateCustomDomainRequest\x1a\x34.scalekit.v1.environments.CreateCustomDomainResponse\"9\x82\xb5\x18\x02\x18T\x82\xd3\xe4\x93\x02-\"(/api/v1/environments/{id}/custom-domains:\x01*\x12\xbd\x01\n\x17\x43heckCustomDomainStatus\x12/.scalekit.v1.environments.GetEnvironmentRequest\x1a\x30.scalekit.v1.environments.GetEnvironmentResponse\"?\x82\xb5\x18\x02\x18T\x82\xd3\xe4\x93\x02\x33\"./api/v1/environments/{id}/custom-domains:check:\x01*\x12\xd8\x01\n\x1aGenerateNewSamlCertificate\x12\x38.scalekit.v1.environments.GenerateSamlCertificateRequest\x1a\x39.scalekit.v1.environments.GenerateSamlCertificateResponse\"E\x82\xb5\x18\x02\x18T\x82\xd3\xe4\x93\x02\x39\"4/api/v1/environments/{id}/saml-certificates:generate:\x01*\x12\xb1\x02\n\x19UpdatePortalCustomization\x12:.scalekit.v1.environments.UpdatePortalCustomizationRequest\x1a;.scalekit.v1.environments.UpdatePortalCustomizationResponse\"\x9a\x01\x82\xb5\x18\x02\x18T\x82\xd3\xe4\x93\x02\x8d\x01\x1a//api/v1/environments/{id}/portal_customizations:\x16\x63ustomization_settingsZB\x1a(/api/v1/environments/{id}/customizations:\x16\x63ustomization_settings\x12\xfa\x01\n\x16GetPortalCustomization\x12\x37.scalekit.v1.environments.GetPortalCustomizationRequest\x1a\x38.scalekit.v1.environments.GetPortalCustomizationResponse\"m\x82\xb5\x18\x02\x18p\x82\xd3\xe4\x93\x02\x61\x12//api/v1/environments/{id}/portal_customizationsZ.\x12,/api/v1/environments/-/portal_customizations\x12\xc4\x01\n\x14\x43reateAssetUploadURL\x12\x35.scalekit.v1.environments.CreateAssetUploadUrlRequest\x1a\x36.scalekit.v1.environments.CreateAssetUploadUrlResponse\"=\x82\xb5\x18\x02\x18P\x82\xd3\xe4\x93\x02\x31\"\x1f/api/v1/environments/{id}/asset:\x0e\x61sset_settings\x12\xac\x01\n\x0eUpdateFeatures\x12/.scalekit.v1.environments.UpdateFeaturesRequest\x1a-.scalekit.v1.environments.GetFeaturesResponse\":\x82\xb5\x18\x02\x18P\x82\xd3\xe4\x93\x02.\x1a\"/api/v1/environments/{id}/features:\x08\x66\x65\x61tures\x12\x9d\x01\n\x10\x45nableFSAFeature\x12\x31.scalekit.v1.environments.EnableFSAFeatureRequest\x1a\x16.google.protobuf.Empty\">\x82\xb5\x18\x02\x18T\x82\xd3\xe4\x93\x02\x32\"-/api/v1/environments/{id}/features/fsa/enable:\x01*\x12\x9d\x01\n\rEnableFeature\x12..scalekit.v1.environments.EnableFeatureRequest\x1a\x16.google.protobuf.Empty\"D\x82\xb5\x18\x02\x18p\x82\xd3\xe4\x93\x02\x38\"6/api/v1/environments/{id}/features/{feature_id}:enable\x12\xa0\x01\n\x0e\x44isableFeature\x12/.scalekit.v1.environments.DisableFeatureRequest\x1a\x16.google.protobuf.Empty\"E\x82\xb5\x18\x02\x18p\x82\xd3\xe4\x93\x02\x39\"7/api/v1/environments/{id}/features/{feature_id}:disable\x12\x9c\x01\n\x0bGetFeatures\x12,.scalekit.v1.environments.GetFeaturesRequest\x1a-.scalekit.v1.environments.GetFeaturesResponse\"0\x82\xb5\x18\x02\x18p\x82\xd3\xe4\x93\x02$\x12\"/api/v1/environments/{id}/features\x12\xf5\x01\n CreateEnvironmentSessionSettings\x12\x41.scalekit.v1.environments.CreateEnvironmentSessionSettingsRequest\x1a\x42.scalekit.v1.environments.CreateEnvironmentSessionSettingsResponse\"J\x82\xb5\x18\x02\x18T\x82\xd3\xe4\x93\x02>\"*/api/v1/environments/{id}/session-settings:\x10session_settings\x12\xf9\x01\n\x1f\x43reateEnvironmentUserManagement\x12@.scalekit.v1.environments.CreateEnvironmentUserManagementRequest\x1a\x41.scalekit.v1.environments.CreateEnvironmentUserManagementResponse\"Q\x82\xb5\x18\x02\x18T\x82\xd3\xe4\x93\x02\x45\"2/api/v1/environments/{id}/settings/user-management:\x0fuser_management\x12\xda\x01\n\x1dGetEnvironmentSessionSettings\x12>.scalekit.v1.environments.GetEnvironmentSessionSettingsRequest\x1a?.scalekit.v1.environments.GetEnvironmentSessionSettingsResponse\"8\x82\xb5\x18\x02\x18T\x82\xd3\xe4\x93\x02,\x12*/api/v1/environments/{id}/session-settings\x12\xdf\x01\n\x1cGetEnvironmentUserManagement\x12=.scalekit.v1.environments.GetEnvironmentUserManagementRequest\x1a>.scalekit.v1.environments.GetEnvironmentUserManagementResponse\"@\x82\xb5\x18\x02\x18T\x82\xd3\xe4\x93\x02\x34\x12\x32/api/v1/environments/{id}/settings/user-management\x12\xf5\x01\n UpdateEnvironmentSessionSettings\x12\x41.scalekit.v1.environments.UpdateEnvironmentSessionSettingsRequest\x1a\x42.scalekit.v1.environments.UpdateEnvironmentSessionSettingsResponse\"J\x82\xb5\x18\x02\x18T\x82\xd3\xe4\x93\x02>2*/api/v1/environments/{id}/session-settings:\x10session_settings\x12\xf9\x01\n\x1fUpdateEnvironmentUserManagement\x12@.scalekit.v1.environments.UpdateEnvironmentUserManagementRequest\x1a\x41.scalekit.v1.environments.UpdateEnvironmentUserManagementResponse\"Q\x82\xb5\x18\x02\x18T\x82\xd3\xe4\x93\x02\x45\x32\x32/api/v1/environments/{id}/settings/user-management:\x0fuser_management\x12\xa5\x01\n\nGetContext\x12+.scalekit.v1.environments.GetContextRequest\x1a,.scalekit.v1.environments.GetContextResponse\"<\x82\xb5\x18\x02\x18P\x82\xd3\xe4\x93\x02\x30\x12./api/v1/environments/{environment_id}/contexts\x12\x9e\x01\n\rUpdateContext\x12..scalekit.v1.environments.UpdateContextRequest\x1a\x16.google.protobuf.Empty\"E\x82\xb5\x18\x02\x18P\x82\xd3\xe4\x93\x02\x39\x1a./api/v1/environments/{environment_id}/contexts:\x07\x63ontext\x12\xee\x01\n\x11GetCurrentSession\x12\x32.scalekit.v1.environments.GetCurrentSessionRequest\x1a\x33.scalekit.v1.environments.GetCurrentSessionResponse\"p\x82\xb5\x18\x02\x18p\x82\xd3\xe4\x93\x02\x64\x12%/api/v1/environments/{id}/sessions:meZ$\x12\"/api/v1/environments/-/sessions:meZ\x15\x12\x13/api/v1/sessions:me\x12\xa2\x01\n\x14GetScalekitResources\x12\x31.scalekit.v1.environments.ScalekitResourceRequest\x1a\x32.scalekit.v1.environments.ScalekitResourceResponse\"#\x82\xb5\x18\x02\x18T\x82\xd3\xe4\x93\x02\x17\"\x12/api/v1/fetch:bulk:\x01*B8Z6github.com/scalekit-inc/scalekit/pkg/grpc/environmentsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'scalekit.v1.environments.environments_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/scalekit-inc/scalekit/pkg/grpc/environments'
  _globals['_CREATECUSTOMDOMAINREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_CREATECUSTOMDOMAINREQUEST'].fields_by_name['id']._serialized_options = b'\272H\013r\t\020\001\030 :\003env'
  _globals['_CREATECUSTOMDOMAINREQUEST'].fields_by_name['custom_domain']._loaded_options = None
  _globals['_CREATECUSTOMDOMAINREQUEST'].fields_by_name['custom_domain']._serialized_options = b'\272H\nr\005\020\001\030\372\001\310\001\001'
  _globals['_GETDNSRECORDSREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETDNSRECORDSREQUEST'].fields_by_name['id']._serialized_options = b'\272H\013r\t\020\001\030 :\003env'
  _globals['_GETDNSRECORDSREQUEST'].fields_by_name['custom_domain']._loaded_options = None
  _globals['_GETDNSRECORDSREQUEST'].fields_by_name['custom_domain']._serialized_options = b'\272H\nr\005\020\001\030\372\001\310\001\001'
  _globals['_DNSRECORDS'].fields_by_name['host_name']._loaded_options = None
  _globals['_DNSRECORDS'].fields_by_name['host_name']._serialized_options = b'\272H\007r\005\020\001\030\372\001'
  _globals['_DNSRECORDS'].fields_by_name['type']._loaded_options = None
  _globals['_DNSRECORDS'].fields_by_name['type']._serialized_options = b'\272H\007r\005\020\001\030\372\001'
  _globals['_DNSRECORDS'].fields_by_name['value']._loaded_options = None
  _globals['_DNSRECORDS'].fields_by_name['value']._serialized_options = b'\272H\007r\005\020\001\030\372\001'
  _globals['_ENVIRONMENT'].fields_by_name['id']._loaded_options = None
  _globals['_ENVIRONMENT'].fields_by_name['id']._serialized_options = b'\272H\013r\t\020\001\030 :\003env'
  _globals['_ENVIRONMENT'].fields_by_name['display_name']._loaded_options = None
  _globals['_ENVIRONMENT'].fields_by_name['display_name']._serialized_options = b'\272H\007r\005\020\001\030\310\001'
  _globals['_ENVIRONMENT'].fields_by_name['domain']._loaded_options = None
  _globals['_ENVIRONMENT'].fields_by_name['domain']._serialized_options = b'\272H\007r\005\020\001\030\372\001'
  _globals['_CREATEENVIRONMENT'].fields_by_name['display_name']._loaded_options = None
  _globals['_CREATEENVIRONMENT'].fields_by_name['display_name']._serialized_options = b'\272H\007r\005\020\001\030\310\001'
  _globals['_UPDATEENVIRONMENT'].fields_by_name['display_name']._loaded_options = None
  _globals['_UPDATEENVIRONMENT'].fields_by_name['display_name']._serialized_options = b'\272H\007r\005\020\001\030\320\017'
  _globals['_UPDATEENVIRONMENTDOMAIN'].fields_by_name['domain']._loaded_options = None
  _globals['_UPDATEENVIRONMENTDOMAIN'].fields_by_name['domain']._serialized_options = b'\272H\007r\005\020\001\030\372\001'
  _globals['_CREATEENVIRONMENTREQUEST'].fields_by_name['environment']._loaded_options = None
  _globals['_CREATEENVIRONMENTREQUEST'].fields_by_name['environment']._serialized_options = b'\272H\003\310\001\001'
  _globals['_UPDATEENVIRONMENTREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_UPDATEENVIRONMENTREQUEST'].fields_by_name['id']._serialized_options = b'\272H\013r\t\020\001\030 :\003env'
  _globals['_UPDATEENVIRONMENTREQUEST'].fields_by_name['environment']._loaded_options = None
  _globals['_UPDATEENVIRONMENTREQUEST'].fields_by_name['environment']._serialized_options = b'\272H\003\310\001\001'
  _globals['_UPDATEENVIRONMENTDOMAINREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_UPDATEENVIRONMENTDOMAINREQUEST'].fields_by_name['id']._serialized_options = b'\272H\013r\t\020\001\030 :\003env'
  _globals['_UPDATEENVIRONMENTDOMAINREQUEST'].fields_by_name['environment']._loaded_options = None
  _globals['_UPDATEENVIRONMENTDOMAINREQUEST'].fields_by_name['environment']._serialized_options = b'\272H\003\310\001\001'
  _globals['_GETENVIRONMENTREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETENVIRONMENTREQUEST'].fields_by_name['id']._serialized_options = b'\272H\013r\t\020\001\030 :\003env'
  _globals['_DELETEENVIRONMENTREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_DELETEENVIRONMENTREQUEST'].fields_by_name['id']._serialized_options = b'\272H\013r\t\020\001\030 :\003env'
  _globals['_GENERATESAMLCERTIFICATEREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GENERATESAMLCERTIFICATEREQUEST'].fields_by_name['id']._serialized_options = b'\272H\013r\t\020\001\030 :\003env'
  _globals['_UPDATEPORTALCUSTOMIZATIONREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_UPDATEPORTALCUSTOMIZATIONREQUEST'].fields_by_name['id']._serialized_options = b'\272H\013r\t\020\001\030 :\003env'
  _globals['_UPDATEPORTALCUSTOMIZATIONREQUEST'].fields_by_name['customization_settings']._loaded_options = None
  _globals['_UPDATEPORTALCUSTOMIZATIONREQUEST'].fields_by_name['customization_settings']._serialized_options = b'\272H\003\310\001\001'
  _globals['_GETPORTALCUSTOMIZATIONREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETPORTALCUSTOMIZATIONREQUEST'].fields_by_name['id']._serialized_options = b'\272H\006r\004\020\000\030 '
  _globals['_CREATEASSETUPLOADURLREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_CREATEASSETUPLOADURLREQUEST'].fields_by_name['id']._serialized_options = b'\272H\013r\t\020\001\030 :\003env'
  _globals['_ASSETSETTINGS'].fields_by_name['category']._loaded_options = None
  _globals['_ASSETSETTINGS'].fields_by_name['category']._serialized_options = b'\272H\003\310\001\001'
  _globals['_ASSETSETTINGS'].fields_by_name['extension']._loaded_options = None
  _globals['_ASSETSETTINGS'].fields_by_name['extension']._serialized_options = b'\272H\022r\020R\003jpgR\004jpegR\003png'
  _globals['_UPDATEFEATURESREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_UPDATEFEATURESREQUEST'].fields_by_name['id']._serialized_options = b'\272H\013r\t\020\001\030 :\003env'
  _globals['_UPDATEFEATURESREQUEST'].fields_by_name['features']._loaded_options = None
  _globals['_UPDATEFEATURESREQUEST'].fields_by_name['features']._serialized_options = b'\272H\003\310\001\001'
  _globals['_ENABLEFSAFEATUREREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_ENABLEFSAFEATUREREQUEST'].fields_by_name['id']._serialized_options = b'\272H\013r\t\020\001\030 :\003env'
  _globals['_GETFEATURESREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETFEATURESREQUEST'].fields_by_name['id']._serialized_options = b'\272H\013r\t\020\001\030 :\003env'
  _globals['_ENABLEFEATUREREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_ENABLEFEATUREREQUEST'].fields_by_name['id']._serialized_options = b'\272H\013r\t\020\001\030 :\003env'
  _globals['_ENABLEFEATUREREQUEST'].fields_by_name['feature_id']._loaded_options = None
  _globals['_ENABLEFEATUREREQUEST'].fields_by_name['feature_id']._serialized_options = b'\272H\006r\004\020\001\030 '
  _globals['_DISABLEFEATUREREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_DISABLEFEATUREREQUEST'].fields_by_name['id']._serialized_options = b'\272H\013r\t\020\001\030 :\003env'
  _globals['_DISABLEFEATUREREQUEST'].fields_by_name['feature_id']._loaded_options = None
  _globals['_DISABLEFEATUREREQUEST'].fields_by_name['feature_id']._serialized_options = b'\272H\006r\004\020\001\030 '
  _globals['_GETENVIRONMENTSESSIONSETTINGSREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETENVIRONMENTSESSIONSETTINGSREQUEST'].fields_by_name['id']._serialized_options = b'\272H\013r\t\020\001\030 :\003env'
  _globals['_GETENVIRONMENTUSERMANAGEMENTREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETENVIRONMENTUSERMANAGEMENTREQUEST'].fields_by_name['id']._serialized_options = b'\272H\013r\t\020\001\030 :\003env'
  _globals['_CREATEENVIRONMENTSESSIONSETTINGSREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_CREATEENVIRONMENTSESSIONSETTINGSREQUEST'].fields_by_name['id']._serialized_options = b'\272H\013r\t\020\001\030 :\003env'
  _globals['_CREATEENVIRONMENTSESSIONSETTINGSREQUEST'].fields_by_name['session_settings']._loaded_options = None
  _globals['_CREATEENVIRONMENTSESSIONSETTINGSREQUEST'].fields_by_name['session_settings']._serialized_options = b'\272H\003\310\001\001'
  _globals['_CREATEENVIRONMENTUSERMANAGEMENTREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_CREATEENVIRONMENTUSERMANAGEMENTREQUEST'].fields_by_name['id']._serialized_options = b'\272H\013r\t\020\001\030 :\003env'
  _globals['_CREATEENVIRONMENTUSERMANAGEMENTREQUEST'].fields_by_name['user_management']._loaded_options = None
  _globals['_CREATEENVIRONMENTUSERMANAGEMENTREQUEST'].fields_by_name['user_management']._serialized_options = b'\272H\003\310\001\001'
  _globals['_UPDATEENVIRONMENTSESSIONSETTINGSREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_UPDATEENVIRONMENTSESSIONSETTINGSREQUEST'].fields_by_name['id']._serialized_options = b'\272H\013r\t\020\001\030 :\003env'
  _globals['_UPDATEENVIRONMENTSESSIONSETTINGSREQUEST'].fields_by_name['session_settings']._loaded_options = None
  _globals['_UPDATEENVIRONMENTSESSIONSETTINGSREQUEST'].fields_by_name['session_settings']._serialized_options = b'\272H\003\310\001\001'
  _globals['_UPDATEENVIRONMENTUSERMANAGEMENTREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_UPDATEENVIRONMENTUSERMANAGEMENTREQUEST'].fields_by_name['id']._serialized_options = b'\272H\013r\t\020\001\030 :\003env'
  _globals['_UPDATEENVIRONMENTUSERMANAGEMENTREQUEST'].fields_by_name['user_management']._loaded_options = None
  _globals['_UPDATEENVIRONMENTUSERMANAGEMENTREQUEST'].fields_by_name['user_management']._serialized_options = b'\272H\003\310\001\001'
  _globals['_SESSIONSETTINGS'].fields_by_name['access_token_expiry']._loaded_options = None
  _globals['_SESSIONSETTINGS'].fields_by_name['access_token_expiry']._serialized_options = b'\272H\010\032\006\030\300\321\002(\001'
  _globals['_SESSIONSETTINGS'].fields_by_name['client_access_token_expiry']._loaded_options = None
  _globals['_SESSIONSETTINGS'].fields_by_name['client_access_token_expiry']._serialized_options = b'\272H\010\032\006\030\300\321\002(\001'
  _globals['_SESSIONSETTINGS'].fields_by_name['absolute_session_timeout']._loaded_options = None
  _globals['_SESSIONSETTINGS'].fields_by_name['absolute_session_timeout']._serialized_options = b'\272H\010\032\006\030\240\212 (\001'
  _globals['_SESSIONSETTINGS'].fields_by_name['idle_session_timeout']._loaded_options = None
  _globals['_SESSIONSETTINGS'].fields_by_name['idle_session_timeout']._serialized_options = b'\272H\007\032\005\030\340N(\001'
  _globals['_USERMANAGEMENT'].fields_by_name['org_user_relationship']._loaded_options = None
  _globals['_USERMANAGEMENT'].fields_by_name['org_user_relationship']._serialized_options = b'\272H\005\202\001\002\020\001'
  _globals['_USERMANAGEMENT'].fields_by_name['max_users_limit']._loaded_options = None
  _globals['_USERMANAGEMENT'].fields_by_name['max_users_limit']._serialized_options = b'\272H\010\032\006\030\237\215\006(\001'
  _globals['_USERMANAGEMENT'].fields_by_name['invitation_expiry']._loaded_options = None
  _globals['_USERMANAGEMENT'].fields_by_name['invitation_expiry']._serialized_options = b'\272H\010*\006\030\300\321\002(\001'
  _globals['_USERMANAGEMENT'].fields_by_name['organization_meta_name']._loaded_options = None
  _globals['_USERMANAGEMENT'].fields_by_name['organization_meta_name']._serialized_options = b'\272H\007r\005\020\001\030\310\001'
  _globals['_SCALEKITRESOURCERESPONSE_RESOURCESENTRY']._loaded_options = None
  _globals['_SCALEKITRESOURCERESPONSE_RESOURCESENTRY']._serialized_options = b'8\001'
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['CreateEnvironment']._loaded_options = None
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['CreateEnvironment']._serialized_options = b'\202\265\030\002\030T\202\323\344\223\002#\"\024/api/v1/environments:\013environment'
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['UpdateEnvironment']._loaded_options = None
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['UpdateEnvironment']._serialized_options = b'\202\265\030\002\030P\202\323\344\223\002(2\031/api/v1/environments/{id}:\013environment'
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['UpdateEnvironmentDomain']._loaded_options = None
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['UpdateEnvironmentDomain']._serialized_options = b'\202\265\030\002\030@\202\323\344\223\002/2 /api/v1/environments/{id}:update:\013environment'
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['GetEnvironment']._loaded_options = None
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['GetEnvironment']._serialized_options = b'\202\265\030\002\030P\202\323\344\223\002\033\022\031/api/v1/environments/{id}'
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['ListEnvironment']._loaded_options = None
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['ListEnvironment']._serialized_options = b'\202\265\030\002\030P\202\323\344\223\002\026\022\024/api/v1/environments'
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['DeleteEnvironment']._loaded_options = None
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['DeleteEnvironment']._serialized_options = b'\202\265\030\000\202\323\344\223\002\033*\031/api/v1/environments/{id}'
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['GetRequiredDNSRecords']._loaded_options = None
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['GetRequiredDNSRecords']._serialized_options = b'\202\265\030\002\030T\202\323\344\223\002\"\"\035/api/v1/environments/{id}/dns:\001*'
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['VerifyDNSRecords']._loaded_options = None
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['VerifyDNSRecords']._serialized_options = b'\202\265\030\002\030T\202\323\344\223\002)\"$/api/v1/environments/{id}/dns:verify:\001*'
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['CreateCustomDomain']._loaded_options = None
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['CreateCustomDomain']._serialized_options = b'\202\265\030\002\030T\202\323\344\223\002-\"(/api/v1/environments/{id}/custom-domains:\001*'
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['CheckCustomDomainStatus']._loaded_options = None
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['CheckCustomDomainStatus']._serialized_options = b'\202\265\030\002\030T\202\323\344\223\0023\"./api/v1/environments/{id}/custom-domains:check:\001*'
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['GenerateNewSamlCertificate']._loaded_options = None
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['GenerateNewSamlCertificate']._serialized_options = b'\202\265\030\002\030T\202\323\344\223\0029\"4/api/v1/environments/{id}/saml-certificates:generate:\001*'
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['UpdatePortalCustomization']._loaded_options = None
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['UpdatePortalCustomization']._serialized_options = b'\202\265\030\002\030T\202\323\344\223\002\215\001\032//api/v1/environments/{id}/portal_customizations:\026customization_settingsZB\032(/api/v1/environments/{id}/customizations:\026customization_settings'
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['GetPortalCustomization']._loaded_options = None
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['GetPortalCustomization']._serialized_options = b'\202\265\030\002\030p\202\323\344\223\002a\022//api/v1/environments/{id}/portal_customizationsZ.\022,/api/v1/environments/-/portal_customizations'
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['CreateAssetUploadURL']._loaded_options = None
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['CreateAssetUploadURL']._serialized_options = b'\202\265\030\002\030P\202\323\344\223\0021\"\037/api/v1/environments/{id}/asset:\016asset_settings'
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['UpdateFeatures']._loaded_options = None
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['UpdateFeatures']._serialized_options = b'\202\265\030\002\030P\202\323\344\223\002.\032\"/api/v1/environments/{id}/features:\010features'
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['EnableFSAFeature']._loaded_options = None
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['EnableFSAFeature']._serialized_options = b'\202\265\030\002\030T\202\323\344\223\0022\"-/api/v1/environments/{id}/features/fsa/enable:\001*'
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['EnableFeature']._loaded_options = None
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['EnableFeature']._serialized_options = b'\202\265\030\002\030p\202\323\344\223\0028\"6/api/v1/environments/{id}/features/{feature_id}:enable'
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['DisableFeature']._loaded_options = None
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['DisableFeature']._serialized_options = b'\202\265\030\002\030p\202\323\344\223\0029\"7/api/v1/environments/{id}/features/{feature_id}:disable'
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['GetFeatures']._loaded_options = None
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['GetFeatures']._serialized_options = b'\202\265\030\002\030p\202\323\344\223\002$\022\"/api/v1/environments/{id}/features'
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['CreateEnvironmentSessionSettings']._loaded_options = None
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['CreateEnvironmentSessionSettings']._serialized_options = b'\202\265\030\002\030T\202\323\344\223\002>\"*/api/v1/environments/{id}/session-settings:\020session_settings'
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['CreateEnvironmentUserManagement']._loaded_options = None
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['CreateEnvironmentUserManagement']._serialized_options = b'\202\265\030\002\030T\202\323\344\223\002E\"2/api/v1/environments/{id}/settings/user-management:\017user_management'
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['GetEnvironmentSessionSettings']._loaded_options = None
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['GetEnvironmentSessionSettings']._serialized_options = b'\202\265\030\002\030T\202\323\344\223\002,\022*/api/v1/environments/{id}/session-settings'
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['GetEnvironmentUserManagement']._loaded_options = None
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['GetEnvironmentUserManagement']._serialized_options = b'\202\265\030\002\030T\202\323\344\223\0024\0222/api/v1/environments/{id}/settings/user-management'
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['UpdateEnvironmentSessionSettings']._loaded_options = None
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['UpdateEnvironmentSessionSettings']._serialized_options = b'\202\265\030\002\030T\202\323\344\223\002>2*/api/v1/environments/{id}/session-settings:\020session_settings'
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['UpdateEnvironmentUserManagement']._loaded_options = None
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['UpdateEnvironmentUserManagement']._serialized_options = b'\202\265\030\002\030T\202\323\344\223\002E22/api/v1/environments/{id}/settings/user-management:\017user_management'
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['GetContext']._loaded_options = None
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['GetContext']._serialized_options = b'\202\265\030\002\030P\202\323\344\223\0020\022./api/v1/environments/{environment_id}/contexts'
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['UpdateContext']._loaded_options = None
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['UpdateContext']._serialized_options = b'\202\265\030\002\030P\202\323\344\223\0029\032./api/v1/environments/{environment_id}/contexts:\007context'
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['GetCurrentSession']._loaded_options = None
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['GetCurrentSession']._serialized_options = b'\202\265\030\002\030p\202\323\344\223\002d\022%/api/v1/environments/{id}/sessions:meZ$\022\"/api/v1/environments/-/sessions:meZ\025\022\023/api/v1/sessions:me'
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['GetScalekitResources']._loaded_options = None
  _globals['_ENVIRONMENTSERVICE'].methods_by_name['GetScalekitResources']._serialized_options = b'\202\265\030\002\030T\202\323\344\223\002\027\"\022/api/v1/fetch:bulk:\001*'
  _globals['_CUSTOMDOMAINSTATUS']._serialized_start=9211
  _globals['_CUSTOMDOMAINSTATUS']._serialized_end=9298
  _globals['_ASSETCATEGORY']._serialized_start=9300
  _globals['_ASSETCATEGORY']._serialized_end=9379
  _globals['_ORGUSERRELATIONSHIPTYPE']._serialized_start=9381
  _globals['_ORGUSERRELATIONSHIPTYPE']._serialized_end=9500
  _globals['_COOKIEPERSISTENCETYPE']._serialized_start=9502
  _globals['_COOKIEPERSISTENCETYPE']._serialized_end=9593
  _globals['_COOKIESAMESITESETTING']._serialized_start=9595
  _globals['_COOKIESAMESITESETTING']._serialized_end=9686
  _globals['_CREATECUSTOMDOMAINREQUEST']._serialized_start=418
  _globals['_CREATECUSTOMDOMAINREQUEST']._serialized_end=529
  _globals['_CREATECUSTOMDOMAINRESPONSE']._serialized_start=531
  _globals['_CREATECUSTOMDOMAINRESPONSE']._serialized_end=632
  _globals['_GETDNSRECORDSREQUEST']._serialized_start=634
  _globals['_GETDNSRECORDSREQUEST']._serialized_end=740
  _globals['_GETDNSRECORDSRESPONSE']._serialized_start=742
  _globals['_GETDNSRECORDSRESPONSE']._serialized_end=836
  _globals['_DNSRECORDS']._serialized_start=838
  _globals['_DNSRECORDS']._serialized_end=957
  _globals['_ENVIRONMENT']._serialized_start=960
  _globals['_ENVIRONMENT']._serialized_end=1490
  _globals['_CREATEENVIRONMENT']._serialized_start=1493
  _globals['_CREATEENVIRONMENT']._serialized_end=1724
  _globals['_UPDATEENVIRONMENT']._serialized_start=1726
  _globals['_UPDATEENVIRONMENT']._serialized_end=1832
  _globals['_UPDATEENVIRONMENTDOMAIN']._serialized_start=1834
  _globals['_UPDATEENVIRONMENTDOMAIN']._serialized_end=1917
  _globals['_CREATEENVIRONMENTREQUEST']._serialized_start=1919
  _globals['_CREATEENVIRONMENTREQUEST']._serialized_end=2032
  _globals['_CREATEENVIRONMENTRESPONSE']._serialized_start=2034
  _globals['_CREATEENVIRONMENTRESPONSE']._serialized_end=2134
  _globals['_UPDATEENVIRONMENTREQUEST']._serialized_start=2137
  _globals['_UPDATEENVIRONMENTREQUEST']._serialized_end=2282
  _globals['_UPDATEENVIRONMENTDOMAINREQUEST']._serialized_start=2285
  _globals['_UPDATEENVIRONMENTDOMAINREQUEST']._serialized_end=2442
  _globals['_UPDATEENVIRONMENTRESPONSE']._serialized_start=2444
  _globals['_UPDATEENVIRONMENTRESPONSE']._serialized_end=2544
  _globals['_GETENVIRONMENTREQUEST']._serialized_start=2546
  _globals['_GETENVIRONMENTREQUEST']._serialized_end=2601
  _globals['_GETENVIRONMENTRESPONSE']._serialized_start=2603
  _globals['_GETENVIRONMENTRESPONSE']._serialized_end=2700
  _globals['_LISTENVIRONMENTSREQUEST']._serialized_start=2702
  _globals['_LISTENVIRONMENTSREQUEST']._serialized_end=2787
  _globals['_LISTENVIRONMENTSRESPONSE']._serialized_start=2790
  _globals['_LISTENVIRONMENTSRESPONSE']._serialized_end=2962
  _globals['_DELETEENVIRONMENTREQUEST']._serialized_start=2964
  _globals['_DELETEENVIRONMENTREQUEST']._serialized_end=3022
  _globals['_GENERATESAMLCERTIFICATEREQUEST']._serialized_start=3024
  _globals['_GENERATESAMLCERTIFICATEREQUEST']._serialized_end=3088
  _globals['_GENERATESAMLCERTIFICATERESPONSE']._serialized_start=3090
  _globals['_GENERATESAMLCERTIFICATERESPONSE']._serialized_end=3197
  _globals['_UPDATEPORTALCUSTOMIZATIONRESPONSE']._serialized_start=3200
  _globals['_UPDATEPORTALCUSTOMIZATIONRESPONSE']._serialized_end=3353
  _globals['_UPDATEPORTALCUSTOMIZATIONREQUEST']._serialized_start=3356
  _globals['_UPDATEPORTALCUSTOMIZATIONREQUEST']._serialized_end=3510
  _globals['_GETPORTALCUSTOMIZATIONREQUEST']._serialized_start=3512
  _globals['_GETPORTALCUSTOMIZATIONREQUEST']._serialized_end=3570
  _globals['_GETPORTALCUSTOMIZATIONRESPONSE']._serialized_start=3573
  _globals['_GETPORTALCUSTOMIZATIONRESPONSE']._serialized_end=3723
  _globals['_CREATEASSETUPLOADURLRESPONSE']._serialized_start=3725
  _globals['_CREATEASSETUPLOADURLRESPONSE']._serialized_end=3815
  _globals['_CREATEASSETUPLOADURLREQUEST']._serialized_start=3818
  _globals['_CREATEASSETUPLOADURLREQUEST']._serialized_end=3959
  _globals['_ASSETSETTINGS']._serialized_start=3962
  _globals['_ASSETSETTINGS']._serialized_end=4107
  _globals['_UPDATEFEATURESREQUEST']._serialized_start=4110
  _globals['_UPDATEFEATURESREQUEST']._serialized_end=4247
  _globals['_ENABLEFSAFEATUREREQUEST']._serialized_start=4249
  _globals['_ENABLEFSAFEATUREREQUEST']._serialized_end=4306
  _globals['_GETFEATURESREQUEST']._serialized_start=4308
  _globals['_GETFEATURESREQUEST']._serialized_end=4360
  _globals['_GETFEATURESRESPONSE']._serialized_start=4362
  _globals['_GETFEATURESRESPONSE']._serialized_end=4457
  _globals['_ENABLEFEATUREREQUEST']._serialized_start=4459
  _globals['_ENABLEFEATUREREQUEST']._serialized_end=4555
  _globals['_DISABLEFEATUREREQUEST']._serialized_start=4557
  _globals['_DISABLEFEATUREREQUEST']._serialized_end=4654
  _globals['_ENVIRONMENTFEATURE']._serialized_start=4656
  _globals['_ENVIRONMENTFEATURE']._serialized_end=4722
  _globals['_GETENVIRONMENTSESSIONSETTINGSREQUEST']._serialized_start=4724
  _globals['_GETENVIRONMENTSESSIONSETTINGSREQUEST']._serialized_end=4794
  _globals['_GETENVIRONMENTUSERMANAGEMENTREQUEST']._serialized_start=4796
  _globals['_GETENVIRONMENTUSERMANAGEMENTREQUEST']._serialized_end=4865
  _globals['_GETENVIRONMENTSESSIONSETTINGSRESPONSE']._serialized_start=4867
  _globals['_GETENVIRONMENTSESSIONSETTINGSRESPONSE']._serialized_end=4992
  _globals['_GETENVIRONMENTUSERMANAGEMENTRESPONSE']._serialized_start=4994
  _globals['_GETENVIRONMENTUSERMANAGEMENTRESPONSE']._serialized_end=5115
  _globals['_CREATEENVIRONMENTSESSIONSETTINGSREQUEST']._serialized_start=5118
  _globals['_CREATEENVIRONMENTSESSIONSETTINGSREQUEST']._serialized_end=5285
  _globals['_CREATEENVIRONMENTUSERMANAGEMENTREQUEST']._serialized_start=5288
  _globals['_CREATEENVIRONMENTUSERMANAGEMENTREQUEST']._serialized_end=5451
  _globals['_CREATEENVIRONMENTSESSIONSETTINGSRESPONSE']._serialized_start=5454
  _globals['_CREATEENVIRONMENTSESSIONSETTINGSRESPONSE']._serialized_end=5621
  _globals['_CREATEENVIRONMENTUSERMANAGEMENTRESPONSE']._serialized_start=5624
  _globals['_CREATEENVIRONMENTUSERMANAGEMENTRESPONSE']._serialized_end=5787
  _globals['_UPDATEENVIRONMENTSESSIONSETTINGSREQUEST']._serialized_start=5790
  _globals['_UPDATEENVIRONMENTSESSIONSETTINGSREQUEST']._serialized_end=5957
  _globals['_UPDATEENVIRONMENTUSERMANAGEMENTREQUEST']._serialized_start=5960
  _globals['_UPDATEENVIRONMENTUSERMANAGEMENTREQUEST']._serialized_end=6123
  _globals['_UPDATEENVIRONMENTSESSIONSETTINGSRESPONSE']._serialized_start=6126
  _globals['_UPDATEENVIRONMENTSESSIONSETTINGSRESPONSE']._serialized_end=6293
  _globals['_UPDATEENVIRONMENTUSERMANAGEMENTRESPONSE']._serialized_start=6296
  _globals['_UPDATEENVIRONMENTUSERMANAGEMENTRESPONSE']._serialized_end=6459
  _globals['_SESSIONSETTINGS']._serialized_start=6462
  _globals['_SESSIONSETTINGS']._serialized_end=7322
  _globals['_USERMANAGEMENT']._serialized_start=7325
  _globals['_USERMANAGEMENT']._serialized_end=8078
  _globals['_GETCONTEXTREQUEST']._serialized_start=8080
  _globals['_GETCONTEXTREQUEST']._serialized_end=8138
  _globals['_GETCONTEXTRESPONSE']._serialized_start=8140
  _globals['_GETCONTEXTRESPONSE']._serialized_end=8211
  _globals['_UPDATECONTEXTREQUEST']._serialized_start=8213
  _globals['_UPDATECONTEXTREQUEST']._serialized_end=8325
  _globals['_GETCURRENTSESSIONREQUEST']._serialized_start=8327
  _globals['_GETCURRENTSESSIONREQUEST']._serialized_end=8369
  _globals['_GETCURRENTSESSIONRESPONSE']._serialized_start=8372
  _globals['_GETCURRENTSESSIONRESPONSE']._serialized_end=8695
  _globals['_RESOURCEMETADATA']._serialized_start=8698
  _globals['_RESOURCEMETADATA']._serialized_end=8895
  _globals['_RESOURCEMETADATA_RESOURCETYPE']._serialized_start=8829
  _globals['_RESOURCEMETADATA_RESOURCETYPE']._serialized_end=8895
  _globals['_SCALEKITRESOURCEREQUEST']._serialized_start=8897
  _globals['_SCALEKITRESOURCEREQUEST']._serialized_end=8996
  _globals['_SCALEKITRESOURCERESPONSE']._serialized_start=8999
  _globals['_SCALEKITRESOURCERESPONSE']._serialized_end=9209
  _globals['_SCALEKITRESOURCERESPONSE_RESOURCESENTRY']._serialized_start=9124
  _globals['_SCALEKITRESOURCERESPONSE_RESOURCESENTRY']._serialized_end=9209
  _globals['_ENVIRONMENTSERVICE']._serialized_start=9689
  _globals['_ENVIRONMENTSERVICE']._serialized_end=15399
# @@protoc_insertion_point(module_scope)
