# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: scalekit/v1/sessions/sessions.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from scalekit.v1.options import options_pb2 as scalekit_dot_v1_dot_options_dot_options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#scalekit/v1/sessions/sessions.proto\x12\x15scalekit.v1.auditlogs\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/api/visibility.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a!scalekit/v1/options/options.proto\"N\n\x15SessionDetailsRequest\x12\x35\n\nsession_id\x18\x01 \x01(\tB\x16\xbaH\x13r\x0e\x32\x0c^ses_[0-9]+$\xc8\x01\x01R\tsessionId\"L\n\x19UserSessionDetailsRequest\x12/\n\x07user_id\x18\x01 \x01(\tB\x16\xbaH\x13r\x0e\x32\x0c^usr_[0-9]+$\xc8\x01\x01R\x06userId\"M\n\x14RevokeSessionRequest\x12\x35\n\nsession_id\x18\x01 \x01(\tB\x16\xbaH\x13r\x0e\x32\x0c^ses_[0-9]+$\xc8\x01\x01R\tsessionId\"g\n\x15RevokeSessionResponse\x12N\n\x0frevoked_session\x18\x01 \x01(\x0b\x32%.scalekit.v1.auditlogs.SessionDetailsR\x0erevokedSession\"W\n\x12UserSessionDetails\x12\x41\n\x08sessions\x18\x01 \x03(\x0b\x32%.scalekit.v1.auditlogs.SessionDetailsR\x08sessions\"\xf6\n\n\x0eSessionDetails\x12\x1d\n\nsession_id\x18\x01 \x01(\tR\tsessionId\x12\x17\n\x07user_id\x18\x02 \x01(\tR\x06userId\x12?\n\x1b\x61uthenticated_organizations\x18\x03 \x03(\tR\x1a\x61uthenticatedOrganizations\x12\'\n\x0forganization_id\x18\x04 \x01(\tR\x0eorganizationId\x12\x39\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x12\x42\n\x0fidle_expires_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ridleExpiresAt\x12J\n\x13\x61\x62solute_expires_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11\x61\x62soluteExpiresAt\x12\x39\n\nexpired_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\texpiredAt\x12\x37\n\tlogout_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08logoutAt\x12\x16\n\x06status\x18\x0b \x01(\tR\x06status\x12,\n\x12initial_user_agent\x18\x0c \x01(\tR\x10initialUserAgent\x12\x1d\n\ninitial_os\x18\r \x01(\tR\tinitialOs\x12,\n\x12initial_os_version\x18\x0e \x01(\tR\x10initialOsVersion\x12\'\n\x0finitial_browser\x18\x0f \x01(\tR\x0einitialBrowser\x12\x36\n\x17initial_browser_version\x18\x10 \x01(\tR\x15initialBrowserVersion\x12.\n\x13initial_device_type\x18\x11 \x01(\tR\x11initialDeviceType\x12)\n\x10initial_timezone\x18\x12 \x01(\tR\x0finitialTimezone\x12\x1d\n\ninitial_ip\x18\x13 \x01(\tR\tinitialIp\x12J\n\x10initial_location\x18\x14 \x01(\x0b\x32\x1f.scalekit.v1.auditlogs.LocationR\x0finitialLocation\x12*\n\x11latest_user_agent\x18\x15 \x01(\tR\x0flatestUserAgent\x12\x1b\n\tlatest_os\x18\x16 \x01(\tR\x08latestOs\x12*\n\x11latest_os_version\x18\x17 \x01(\tR\x0flatestOsVersion\x12%\n\x0elatest_browser\x18\x18 \x01(\tR\rlatestBrowser\x12\x34\n\x16latest_browser_version\x18\x19 \x01(\tR\x14latestBrowserVersion\x12,\n\x12latest_device_type\x18\x1a \x01(\tR\x10latestDeviceType\x12\'\n\x0flatest_timezone\x18\x1b \x01(\tR\x0elatestTimezone\x12\x1b\n\tlatest_ip\x18\x1c \x01(\tR\x08latestIp\x12H\n\x0flatest_location\x18\x1d \x01(\x0b\x32\x1f.scalekit.v1.auditlogs.LocationR\x0elatestLocation\"\x9f\x01\n\x08Location\x12\x16\n\x06region\x18\x01 \x01(\tR\x06region\x12-\n\x12region_subdivision\x18\x02 \x01(\tR\x11regionSubdivision\x12\x12\n\x04\x63ity\x18\x03 \x01(\tR\x04\x63ity\x12\x1a\n\x08latitude\x18\x04 \x01(\tR\x08latitude\x12\x1c\n\tlongitude\x18\x05 \x01(\tR\tlongitude2\x90\x04\n\x0eSessionService\x12\x9d\x01\n\nGetSession\x12,.scalekit.v1.auditlogs.SessionDetailsRequest\x1a%.scalekit.v1.auditlogs.SessionDetails\":\x82\xb5\x18\x02\x18T\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02\x1f\x12\x1d/api/v1/sessions/{session_id}\x12\xad\x01\n\rRevokeSession\x12+.scalekit.v1.auditlogs.RevokeSessionRequest\x1a,.scalekit.v1.auditlogs.RevokeSessionResponse\"A\x82\xb5\x18\x02\x18T\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02&\x12$/api/v1/sessions/{session_id}/revoke\x12\xad\x01\n\x0fGetUserSessions\x12\x30.scalekit.v1.auditlogs.UserSessionDetailsRequest\x1a).scalekit.v1.auditlogs.UserSessionDetails\"=\x82\xb5\x18\x02\x18T\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02\"\x12 /api/v1/users/{user_id}/sessionsB4Z2github.com/scalekit-inc/scalekit/pkg/grpc/sessionsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'scalekit.v1.sessions.sessions_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z2github.com/scalekit-inc/scalekit/pkg/grpc/sessions'
  _globals['_SESSIONDETAILSREQUEST'].fields_by_name['session_id']._loaded_options = None
  _globals['_SESSIONDETAILSREQUEST'].fields_by_name['session_id']._serialized_options = b'\272H\023r\0162\014^ses_[0-9]+$\310\001\001'
  _globals['_USERSESSIONDETAILSREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_USERSESSIONDETAILSREQUEST'].fields_by_name['user_id']._serialized_options = b'\272H\023r\0162\014^usr_[0-9]+$\310\001\001'
  _globals['_REVOKESESSIONREQUEST'].fields_by_name['session_id']._loaded_options = None
  _globals['_REVOKESESSIONREQUEST'].fields_by_name['session_id']._serialized_options = b'\272H\023r\0162\014^ses_[0-9]+$\310\001\001'
  _globals['_SESSIONSERVICE'].methods_by_name['GetSession']._loaded_options = None
  _globals['_SESSIONSERVICE'].methods_by_name['GetSession']._serialized_options = b'\202\265\030\002\030T\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002\037\022\035/api/v1/sessions/{session_id}'
  _globals['_SESSIONSERVICE'].methods_by_name['RevokeSession']._loaded_options = None
  _globals['_SESSIONSERVICE'].methods_by_name['RevokeSession']._serialized_options = b'\202\265\030\002\030T\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002&\022$/api/v1/sessions/{session_id}/revoke'
  _globals['_SESSIONSERVICE'].methods_by_name['GetUserSessions']._loaded_options = None
  _globals['_SESSIONSERVICE'].methods_by_name['GetUserSessions']._serialized_options = b'\202\265\030\002\030T\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002\"\022 /api/v1/users/{user_id}/sessions'
  _globals['_SESSIONDETAILSREQUEST']._serialized_start=218
  _globals['_SESSIONDETAILSREQUEST']._serialized_end=296
  _globals['_USERSESSIONDETAILSREQUEST']._serialized_start=298
  _globals['_USERSESSIONDETAILSREQUEST']._serialized_end=374
  _globals['_REVOKESESSIONREQUEST']._serialized_start=376
  _globals['_REVOKESESSIONREQUEST']._serialized_end=453
  _globals['_REVOKESESSIONRESPONSE']._serialized_start=455
  _globals['_REVOKESESSIONRESPONSE']._serialized_end=558
  _globals['_USERSESSIONDETAILS']._serialized_start=560
  _globals['_USERSESSIONDETAILS']._serialized_end=647
  _globals['_SESSIONDETAILS']._serialized_start=650
  _globals['_SESSIONDETAILS']._serialized_end=2048
  _globals['_LOCATION']._serialized_start=2051
  _globals['_LOCATION']._serialized_end=2210
  _globals['_SESSIONSERVICE']._serialized_start=2213
  _globals['_SESSIONSERVICE']._serialized_end=2741
# @@protoc_insertion_point(module_scope)
