# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from scalekit.v1.webhooks import webhooks_pb2 as scalekit_dot_v1_dot_webhooks_dot_webhooks__pb2


class WebhookServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetPortalURL = channel.unary_unary(
                '/scalekit.v1.webhooks.WebhookService/GetPortalURL',
                request_serializer=scalekit_dot_v1_dot_webhooks_dot_webhooks__pb2.GetPortalURLRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_webhooks_dot_webhooks__pb2.GetPortalURLResponse.FromString,
                )
        self.WebhookWrapper = channel.unary_unary(
                '/scalekit.v1.webhooks.WebhookService/WebhookWrapper',
                request_serializer=scalekit_dot_v1_dot_webhooks_dot_webhooks__pb2.WebhookWrapperRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )
        self.SendTestEvent = channel.unary_unary(
                '/scalekit.v1.webhooks.WebhookService/SendTestEvent',
                request_serializer=scalekit_dot_v1_dot_webhooks_dot_webhooks__pb2.SendTestEventRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_webhooks_dot_webhooks__pb2.SendTestEventResponse.FromString,
                )


class WebhookServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetPortalURL(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WebhookWrapper(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendTestEvent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_WebhookServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetPortalURL': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPortalURL,
                    request_deserializer=scalekit_dot_v1_dot_webhooks_dot_webhooks__pb2.GetPortalURLRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_webhooks_dot_webhooks__pb2.GetPortalURLResponse.SerializeToString,
            ),
            'WebhookWrapper': grpc.unary_unary_rpc_method_handler(
                    servicer.WebhookWrapper,
                    request_deserializer=scalekit_dot_v1_dot_webhooks_dot_webhooks__pb2.WebhookWrapperRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
            'SendTestEvent': grpc.unary_unary_rpc_method_handler(
                    servicer.SendTestEvent,
                    request_deserializer=scalekit_dot_v1_dot_webhooks_dot_webhooks__pb2.SendTestEventRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_webhooks_dot_webhooks__pb2.SendTestEventResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'scalekit.v1.webhooks.WebhookService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class WebhookService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetPortalURL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.webhooks.WebhookService/GetPortalURL',
            scalekit_dot_v1_dot_webhooks_dot_webhooks__pb2.GetPortalURLRequest.SerializeToString,
            scalekit_dot_v1_dot_webhooks_dot_webhooks__pb2.GetPortalURLResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WebhookWrapper(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.webhooks.WebhookService/WebhookWrapper',
            scalekit_dot_v1_dot_webhooks_dot_webhooks__pb2.WebhookWrapperRequest.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendTestEvent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.webhooks.WebhookService/SendTestEvent',
            scalekit_dot_v1_dot_webhooks_dot_webhooks__pb2.SendTestEventRequest.SerializeToString,
            scalekit_dot_v1_dot_webhooks_dot_webhooks__pb2.SendTestEventResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
