# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from scalekit.v1.clients import clients_pb2 as scalekit_dot_v1_dot_clients_dot_clients__pb2


class ClientServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListClient = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/ListClient',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.ListClientsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.ListClientsResponse.FromString,
                )
        self.GetClient = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/GetClient',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetClientRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetClientResponse.FromString,
                )
        self.UpdateClient = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/UpdateClient',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateClientRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateClientResponse.FromString,
                )
        self.CreateClientSecret = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/CreateClientSecret',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateClientSecretRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateClientSecretResponse.FromString,
                )
        self.UpdateClientSecret = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/UpdateClientSecret',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateClientSecretRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateClientSecretResponse.FromString,
                )
        self.DeleteClientSecret = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/DeleteClientSecret',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.DeleteClientSecretRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.CreateOrganizationClient = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/CreateOrganizationClient',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateOrganizationClientRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateOrganizationClientResponse.FromString,
                )
        self.GetOrganizationClient = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/GetOrganizationClient',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetOrganizationClientRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetOrganizationClientResponse.FromString,
                )
        self.CreateOrganizationClientSecret = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/CreateOrganizationClientSecret',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateOrganizationClientSecretRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateOrganizationClientSecretResponse.FromString,
                )
        self.DeleteOrganizationClientSecret = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/DeleteOrganizationClientSecret',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.DeleteOrganizationClientSecretRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateOrganizationClient = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/UpdateOrganizationClient',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateOrganizationClientRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateOrganizationClientResponse.FromString,
                )
        self.DeleteOrganizationClient = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/DeleteOrganizationClient',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.DeleteOrganizationClientRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ListOrganizationClients = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/ListOrganizationClients',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.ListOrganizationClientsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.ListOrganizationClientsResponse.FromString,
                )
        self.CreateResource = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/CreateResource',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateResourceRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateResourceResponse.FromString,
                )
        self.GetResource = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/GetResource',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetResourceRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetResourceResponse.FromString,
                )
        self.ListResources = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/ListResources',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.ListResourcesRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.ListResourcesResponse.FromString,
                )
        self.UpdateResource = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/UpdateResource',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateResourceRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateResourceResponse.FromString,
                )
        self.DeleteResource = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/DeleteResource',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.DeleteResourceRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DeleteResourceProvider = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/DeleteResourceProvider',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.DeleteResourceProviderRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetResourceResponse.FromString,
                )
        self.CreateResourceClient = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/CreateResourceClient',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateResourceClientRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateResourceClientResponse.FromString,
                )
        self.GetResourceClient = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/GetResourceClient',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetResourceClientRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetResourceClientResponse.FromString,
                )
        self.RegisterClient = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/RegisterClient',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.RegisterClientRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.RegisterClientResponse.FromString,
                )
        self.CreateScope = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/CreateScope',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateScopeRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateScopeResponse.FromString,
                )
        self.ListScopes = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/ListScopes',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.ListScopesRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.ListScopesResponse.FromString,
                )
        self.UpdateScope = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/UpdateScope',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateScopeRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateScopeResponse.FromString,
                )
        self.DeleteScope = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/DeleteScope',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.DeleteScopeRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetConsentDetails = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/GetConsentDetails',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetConsentDetailsResponse.FromString,
                )


class ClientServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListClient(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetClient(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateClient(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateClientSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateClientSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteClientSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateOrganizationClient(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrganizationClient(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateOrganizationClientSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteOrganizationClientSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateOrganizationClient(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteOrganizationClient(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOrganizationClients(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateResource(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetResource(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListResources(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateResource(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteResource(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteResourceProvider(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateResourceClient(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetResourceClient(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterClient(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateScope(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListScopes(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateScope(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteScope(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetConsentDetails(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ClientServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListClient': grpc.unary_unary_rpc_method_handler(
                    servicer.ListClient,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.ListClientsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.ListClientsResponse.SerializeToString,
            ),
            'GetClient': grpc.unary_unary_rpc_method_handler(
                    servicer.GetClient,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetClientRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetClientResponse.SerializeToString,
            ),
            'UpdateClient': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateClient,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateClientRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateClientResponse.SerializeToString,
            ),
            'CreateClientSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateClientSecret,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateClientSecretRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateClientSecretResponse.SerializeToString,
            ),
            'UpdateClientSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateClientSecret,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateClientSecretRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateClientSecretResponse.SerializeToString,
            ),
            'DeleteClientSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteClientSecret,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.DeleteClientSecretRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateOrganizationClient': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateOrganizationClient,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateOrganizationClientRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateOrganizationClientResponse.SerializeToString,
            ),
            'GetOrganizationClient': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganizationClient,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetOrganizationClientRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetOrganizationClientResponse.SerializeToString,
            ),
            'CreateOrganizationClientSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateOrganizationClientSecret,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateOrganizationClientSecretRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateOrganizationClientSecretResponse.SerializeToString,
            ),
            'DeleteOrganizationClientSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteOrganizationClientSecret,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.DeleteOrganizationClientSecretRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateOrganizationClient': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateOrganizationClient,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateOrganizationClientRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateOrganizationClientResponse.SerializeToString,
            ),
            'DeleteOrganizationClient': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteOrganizationClient,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.DeleteOrganizationClientRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListOrganizationClients': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOrganizationClients,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.ListOrganizationClientsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.ListOrganizationClientsResponse.SerializeToString,
            ),
            'CreateResource': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateResource,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateResourceRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateResourceResponse.SerializeToString,
            ),
            'GetResource': grpc.unary_unary_rpc_method_handler(
                    servicer.GetResource,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetResourceRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetResourceResponse.SerializeToString,
            ),
            'ListResources': grpc.unary_unary_rpc_method_handler(
                    servicer.ListResources,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.ListResourcesRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.ListResourcesResponse.SerializeToString,
            ),
            'UpdateResource': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateResource,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateResourceRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateResourceResponse.SerializeToString,
            ),
            'DeleteResource': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteResource,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.DeleteResourceRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DeleteResourceProvider': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteResourceProvider,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.DeleteResourceProviderRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetResourceResponse.SerializeToString,
            ),
            'CreateResourceClient': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateResourceClient,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateResourceClientRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateResourceClientResponse.SerializeToString,
            ),
            'GetResourceClient': grpc.unary_unary_rpc_method_handler(
                    servicer.GetResourceClient,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetResourceClientRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetResourceClientResponse.SerializeToString,
            ),
            'RegisterClient': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterClient,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.RegisterClientRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.RegisterClientResponse.SerializeToString,
            ),
            'CreateScope': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateScope,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateScopeRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateScopeResponse.SerializeToString,
            ),
            'ListScopes': grpc.unary_unary_rpc_method_handler(
                    servicer.ListScopes,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.ListScopesRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.ListScopesResponse.SerializeToString,
            ),
            'UpdateScope': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateScope,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateScopeRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateScopeResponse.SerializeToString,
            ),
            'DeleteScope': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteScope,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.DeleteScopeRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetConsentDetails': grpc.unary_unary_rpc_method_handler(
                    servicer.GetConsentDetails,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetConsentDetailsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'scalekit.v1.clients.ClientService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ClientService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListClient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/ListClient',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.ListClientsRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.ListClientsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetClient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/GetClient',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.GetClientRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.GetClientResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateClient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/UpdateClient',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateClientRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateClientResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateClientSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/CreateClientSecret',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateClientSecretRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateClientSecretResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateClientSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/UpdateClientSecret',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateClientSecretRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateClientSecretResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteClientSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/DeleteClientSecret',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.DeleteClientSecretRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateOrganizationClient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/CreateOrganizationClient',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateOrganizationClientRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateOrganizationClientResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrganizationClient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/GetOrganizationClient',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.GetOrganizationClientRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.GetOrganizationClientResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateOrganizationClientSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/CreateOrganizationClientSecret',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateOrganizationClientSecretRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateOrganizationClientSecretResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteOrganizationClientSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/DeleteOrganizationClientSecret',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.DeleteOrganizationClientSecretRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateOrganizationClient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/UpdateOrganizationClient',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateOrganizationClientRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateOrganizationClientResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteOrganizationClient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/DeleteOrganizationClient',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.DeleteOrganizationClientRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOrganizationClients(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/ListOrganizationClients',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.ListOrganizationClientsRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.ListOrganizationClientsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateResource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/CreateResource',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateResourceRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateResourceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetResource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/GetResource',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.GetResourceRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.GetResourceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListResources(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/ListResources',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.ListResourcesRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.ListResourcesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateResource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/UpdateResource',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateResourceRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateResourceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteResource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/DeleteResource',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.DeleteResourceRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteResourceProvider(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/DeleteResourceProvider',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.DeleteResourceProviderRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.GetResourceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateResourceClient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/CreateResourceClient',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateResourceClientRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateResourceClientResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetResourceClient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/GetResourceClient',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.GetResourceClientRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.GetResourceClientResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterClient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/RegisterClient',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.RegisterClientRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.RegisterClientResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateScope(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/CreateScope',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateScopeRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateScopeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListScopes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/ListScopes',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.ListScopesRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.ListScopesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateScope(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/UpdateScope',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateScopeRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateScopeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteScope(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/DeleteScope',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.DeleteScopeRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetConsentDetails(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/GetConsentDetails',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.GetConsentDetailsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
