# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from scalekit.v1.domains import domains_pb2 as scalekit_dot_v1_dot_domains_dot_domains__pb2


class DomainServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateDomain = channel.unary_unary(
                '/scalekit.v1.domains.DomainService/CreateDomain',
                request_serializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.CreateDomainRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.CreateDomainResponse.FromString,
                )
        self.UpdateDomain = channel.unary_unary(
                '/scalekit.v1.domains.DomainService/UpdateDomain',
                request_serializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.UpdateDomainRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.UpdateDomainResponse.FromString,
                )
        self.VerifyDomain = channel.unary_unary(
                '/scalekit.v1.domains.DomainService/VerifyDomain',
                request_serializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.VerifyDomainRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_wrappers__pb2.BoolValue.FromString,
                )
        self.GetDomain = channel.unary_unary(
                '/scalekit.v1.domains.DomainService/GetDomain',
                request_serializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.GetDomainRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.GetDomainResponse.FromString,
                )
        self.DeleteDomain = channel.unary_unary(
                '/scalekit.v1.domains.DomainService/DeleteDomain',
                request_serializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.DeleteDomainRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ListDomains = channel.unary_unary(
                '/scalekit.v1.domains.DomainService/ListDomains',
                request_serializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.ListDomainRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.ListDomainResponse.FromString,
                )
        self.ListAuthorizedDomains = channel.unary_unary(
                '/scalekit.v1.domains.DomainService/ListAuthorizedDomains',
                request_serializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.ListAuthorizedDomainRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.ListAuthorizedDomainResponse.FromString,
                )


class DomainServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateDomain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDomain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VerifyDomain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDomain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDomain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDomains(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAuthorizedDomains(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DomainServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDomain,
                    request_deserializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.CreateDomainRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.CreateDomainResponse.SerializeToString,
            ),
            'UpdateDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDomain,
                    request_deserializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.UpdateDomainRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.UpdateDomainResponse.SerializeToString,
            ),
            'VerifyDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.VerifyDomain,
                    request_deserializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.VerifyDomainRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_wrappers__pb2.BoolValue.SerializeToString,
            ),
            'GetDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDomain,
                    request_deserializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.GetDomainRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.GetDomainResponse.SerializeToString,
            ),
            'DeleteDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDomain,
                    request_deserializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.DeleteDomainRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListDomains': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDomains,
                    request_deserializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.ListDomainRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.ListDomainResponse.SerializeToString,
            ),
            'ListAuthorizedDomains': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAuthorizedDomains,
                    request_deserializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.ListAuthorizedDomainRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.ListAuthorizedDomainResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'scalekit.v1.domains.DomainService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DomainService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.domains.DomainService/CreateDomain',
            scalekit_dot_v1_dot_domains_dot_domains__pb2.CreateDomainRequest.SerializeToString,
            scalekit_dot_v1_dot_domains_dot_domains__pb2.CreateDomainResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.domains.DomainService/UpdateDomain',
            scalekit_dot_v1_dot_domains_dot_domains__pb2.UpdateDomainRequest.SerializeToString,
            scalekit_dot_v1_dot_domains_dot_domains__pb2.UpdateDomainResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def VerifyDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.domains.DomainService/VerifyDomain',
            scalekit_dot_v1_dot_domains_dot_domains__pb2.VerifyDomainRequest.SerializeToString,
            google_dot_protobuf_dot_wrappers__pb2.BoolValue.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.domains.DomainService/GetDomain',
            scalekit_dot_v1_dot_domains_dot_domains__pb2.GetDomainRequest.SerializeToString,
            scalekit_dot_v1_dot_domains_dot_domains__pb2.GetDomainResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.domains.DomainService/DeleteDomain',
            scalekit_dot_v1_dot_domains_dot_domains__pb2.DeleteDomainRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDomains(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.domains.DomainService/ListDomains',
            scalekit_dot_v1_dot_domains_dot_domains__pb2.ListDomainRequest.SerializeToString,
            scalekit_dot_v1_dot_domains_dot_domains__pb2.ListDomainResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAuthorizedDomains(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.domains.DomainService/ListAuthorizedDomains',
            scalekit_dot_v1_dot_domains_dot_domains__pb2.ListAuthorizedDomainRequest.SerializeToString,
            scalekit_dot_v1_dot_domains_dot_domains__pb2.ListAuthorizedDomainResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
