# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: scalekit/v1/providers/providers.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2
from scalekit.v1.options import options_pb2 as scalekit_dot_v1_dot_options_dot_options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%scalekit/v1/providers/providers.proto\x12\x15scalekit.v1.providers\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1bgoogle/api/visibility.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\x1a!scalekit/v1/options/options.proto\"\xa6\x02\n\x08Provider\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1e\n\nidentifier\x18\x02 \x01(\tR\nidentifier\x12!\n\x0c\x64isplay_name\x18\x03 \x01(\tR\x0b\x64isplayName\x12 \n\x0b\x64\x65scription\x18\x04 \x01(\tR\x0b\x64\x65scription\x12\x1e\n\ncategories\x18\x05 \x03(\tR\ncategories\x12?\n\rauth_patterns\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.ListValueR\x0c\x61uthPatterns\x12\x19\n\x08icon_src\x18\x07 \x01(\tR\x07iconSrc\x12)\n\x10\x64isplay_priority\x18\x08 \x01(\x05R\x0f\x64isplayPriority\"\xcb\x06\n\x0e\x43reateProvider\x12\x87\x01\n\nidentifier\x18\x02 \x01(\tBg\x92\x41\x46\x32\x30Unique identifier for the connected app providerJ\x12\"google_workspace\"\xbaH\x1br\x16\x10\x01\x18\x64\x32\x10^[a-zA-Z0-9_-]*$\xc8\x01\x01R\nidentifier\x12t\n\x0c\x64isplay_name\x18\x03 \x01(\tBQ\x92\x41\x41\x32+Display name for the connected app providerJ\x12\"Google Workspace\"\xbaH\nr\x05\x10\x01\x18\xc8\x01\xc8\x01\x01R\x0b\x64isplayName\x12\x92\x01\n\x0b\x64\x65scription\x18\x04 \x01(\tBp\x92\x41m2)Description of the connected app providerJ@\"Connect to Google Workspace for email and calendar integration\"R\x0b\x64\x65scription\x12i\n\ncategories\x18\x05 \x03(\tBI\x92\x41\x46\x32)Categories for the connected app providerJ\x19[\"productivity\", \"email\"]R\ncategories\x12\x82\x01\n\rauth_patterns\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.ListValueBA\x92\x41\x38\x32\x36\x41uthentication patterns for the connected app provider\xbaH\x03\xc8\x01\x01R\x0c\x61uthPatterns\x12\x82\x01\n\x08icon_src\x18\x07 \x01(\tBg\x92\x41\x64\x32/Image source URL for the connected app providerJ1\"https://example.com/images/google_workspace.png\"R\x07iconSrc\x12)\n\x10\x64isplay_priority\x18\x08 \x01(\x05R\x0f\x64isplayPriorityJ\x04\x08\x01\x10\x02\"\x96\x01\n\x15\x43reateProviderRequest\x12}\n\x08provider\x18\x01 \x01(\x0b\x32%.scalekit.v1.providers.CreateProviderB:\x92\x41\x31\x32/Details of the connected app provider to create\xbaH\x03\xc8\x01\x01R\x08provider\"U\n\x16\x43reateProviderResponse\x12;\n\x08provider\x18\x01 \x01(\x0b\x32\x1f.scalekit.v1.providers.ProviderR\x08provider\"\xc0\x05\n\x0eUpdateProvider\x12t\n\x0c\x64isplay_name\x18\x03 \x01(\tBQ\x92\x41\x41\x32+Display name for the connected app providerJ\x12\"Google Workspace\"\xbaH\nr\x05\x10\x01\x18\xc8\x01\xc8\x01\x01R\x0b\x64isplayName\x12\x92\x01\n\x0b\x64\x65scription\x18\x04 \x01(\tBp\x92\x41m2)Description of the connected app providerJ@\"Connect to Google Workspace for email and calendar integration\"R\x0b\x64\x65scription\x12i\n\ncategories\x18\x05 \x03(\tBI\x92\x41\x46\x32)Categories for the connected app providerJ\x19[\"productivity\", \"email\"]R\ncategories\x12|\n\rauth_patterns\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.ListValueB;\x92\x41\x38\x32\x36\x41uthentication patterns for the connected app providerR\x0c\x61uthPatterns\x12\x82\x01\n\x08icon_src\x18\x07 \x01(\tBg\x92\x41\x64\x32/Image source URL for the connected app providerJ1\"https://example.com/images/google_workspace.png\"R\x07iconSrc\x12)\n\x10\x64isplay_priority\x18\x08 \x01(\x05R\x0f\x64isplayPriorityJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03\"\xd3\x01\n\x15UpdateProviderRequest\x12;\n\nidentifier\x18\x01 \x01(\tB\x1b\xbaH\x18r\x16\x10\x00\x18\x64\x32\x10^[a-zA-Z0-9_-]*$R\nidentifier\x12}\n\x08provider\x18\x02 \x01(\x0b\x32%.scalekit.v1.providers.UpdateProviderB:\x92\x41\x31\x32/Fields to update for the connected app provider\xbaH\x03\xc8\x01\x01R\x08provider\"U\n\x16UpdateProviderResponse\x12;\n\x08provider\x18\x01 \x01(\x0b\x32\x1f.scalekit.v1.providers.ProviderR\x08provider\"\x8f\x01\n\x14ListProvidersRequest\x12;\n\nidentifier\x18\x01 \x01(\tB\x1b\xbaH\x18r\x16\x10\x00\x18\x64\x32\x10^[a-zA-Z0-9_-]*$R\nidentifier\x12\x1b\n\tpage_size\x18\x02 \x01(\rR\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\xc5\x01\n\x15ListProvidersResponse\x12=\n\tproviders\x18\x01 \x03(\x0b\x32\x1f.scalekit.v1.providers.ProviderR\tproviders\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\rR\ttotalSize\x12&\n\x0fprev_page_token\x18\x04 \x01(\tR\rprevPageToken\"T\n\x15\x44\x65leteProviderRequest\x12;\n\nidentifier\x18\x01 \x01(\tB\x1b\xbaH\x18r\x16\x10\x00\x18\x64\x32\x10^[a-zA-Z0-9_-]*$R\nidentifier\"\x18\n\x16\x44\x65leteProviderResponse2\xbc\x05\n\x0fProviderService\x12\xa7\x01\n\x0e\x43reateProvider\x12,.scalekit.v1.providers.CreateProviderRequest\x1a-.scalekit.v1.providers.CreateProviderResponse\"8\x82\xb5\x18\x02\x18\x04\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02\x1d\"\x11/api/v1/providers:\x08provider\x12\xb4\x01\n\x0eUpdateProvider\x12,.scalekit.v1.providers.UpdateProviderRequest\x1a-.scalekit.v1.providers.UpdateProviderResponse\"E\x82\xb5\x18\x02\x18\x04\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02*\x1a\x1e/api/v1/providers/{identifier}:\x08provider\x12\xaa\x01\n\x0e\x44\x65leteProvider\x12,.scalekit.v1.providers.DeleteProviderRequest\x1a-.scalekit.v1.providers.DeleteProviderResponse\";\x82\xb5\x18\x02\x18\x04\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02 *\x1e/api/v1/providers/{identifier}\x12\x9a\x01\n\rListProviders\x12+.scalekit.v1.providers.ListProvidersRequest\x1a,.scalekit.v1.providers.ListProvidersResponse\".\x82\xb5\x18\x02\x18T\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02\x13\x12\x11/api/v1/providersB5Z3github.com/scalekit-inc/scalekit/pkg/grpc/providersb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'scalekit.v1.providers.providers_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/scalekit-inc/scalekit/pkg/grpc/providers'
  _globals['_CREATEPROVIDER'].fields_by_name['identifier']._loaded_options = None
  _globals['_CREATEPROVIDER'].fields_by_name['identifier']._serialized_options = b'\222AF20Unique identifier for the connected app providerJ\022\"google_workspace\"\272H\033r\026\020\001\030d2\020^[a-zA-Z0-9_-]*$\310\001\001'
  _globals['_CREATEPROVIDER'].fields_by_name['display_name']._loaded_options = None
  _globals['_CREATEPROVIDER'].fields_by_name['display_name']._serialized_options = b'\222AA2+Display name for the connected app providerJ\022\"Google Workspace\"\272H\nr\005\020\001\030\310\001\310\001\001'
  _globals['_CREATEPROVIDER'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEPROVIDER'].fields_by_name['description']._serialized_options = b'\222Am2)Description of the connected app providerJ@\"Connect to Google Workspace for email and calendar integration\"'
  _globals['_CREATEPROVIDER'].fields_by_name['categories']._loaded_options = None
  _globals['_CREATEPROVIDER'].fields_by_name['categories']._serialized_options = b'\222AF2)Categories for the connected app providerJ\031[\"productivity\", \"email\"]'
  _globals['_CREATEPROVIDER'].fields_by_name['auth_patterns']._loaded_options = None
  _globals['_CREATEPROVIDER'].fields_by_name['auth_patterns']._serialized_options = b'\222A826Authentication patterns for the connected app provider\272H\003\310\001\001'
  _globals['_CREATEPROVIDER'].fields_by_name['icon_src']._loaded_options = None
  _globals['_CREATEPROVIDER'].fields_by_name['icon_src']._serialized_options = b'\222Ad2/Image source URL for the connected app providerJ1\"https://example.com/images/google_workspace.png\"'
  _globals['_CREATEPROVIDERREQUEST'].fields_by_name['provider']._loaded_options = None
  _globals['_CREATEPROVIDERREQUEST'].fields_by_name['provider']._serialized_options = b'\222A12/Details of the connected app provider to create\272H\003\310\001\001'
  _globals['_UPDATEPROVIDER'].fields_by_name['display_name']._loaded_options = None
  _globals['_UPDATEPROVIDER'].fields_by_name['display_name']._serialized_options = b'\222AA2+Display name for the connected app providerJ\022\"Google Workspace\"\272H\nr\005\020\001\030\310\001\310\001\001'
  _globals['_UPDATEPROVIDER'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEPROVIDER'].fields_by_name['description']._serialized_options = b'\222Am2)Description of the connected app providerJ@\"Connect to Google Workspace for email and calendar integration\"'
  _globals['_UPDATEPROVIDER'].fields_by_name['categories']._loaded_options = None
  _globals['_UPDATEPROVIDER'].fields_by_name['categories']._serialized_options = b'\222AF2)Categories for the connected app providerJ\031[\"productivity\", \"email\"]'
  _globals['_UPDATEPROVIDER'].fields_by_name['auth_patterns']._loaded_options = None
  _globals['_UPDATEPROVIDER'].fields_by_name['auth_patterns']._serialized_options = b'\222A826Authentication patterns for the connected app provider'
  _globals['_UPDATEPROVIDER'].fields_by_name['icon_src']._loaded_options = None
  _globals['_UPDATEPROVIDER'].fields_by_name['icon_src']._serialized_options = b'\222Ad2/Image source URL for the connected app providerJ1\"https://example.com/images/google_workspace.png\"'
  _globals['_UPDATEPROVIDERREQUEST'].fields_by_name['identifier']._loaded_options = None
  _globals['_UPDATEPROVIDERREQUEST'].fields_by_name['identifier']._serialized_options = b'\272H\030r\026\020\000\030d2\020^[a-zA-Z0-9_-]*$'
  _globals['_UPDATEPROVIDERREQUEST'].fields_by_name['provider']._loaded_options = None
  _globals['_UPDATEPROVIDERREQUEST'].fields_by_name['provider']._serialized_options = b'\222A12/Fields to update for the connected app provider\272H\003\310\001\001'
  _globals['_LISTPROVIDERSREQUEST'].fields_by_name['identifier']._loaded_options = None
  _globals['_LISTPROVIDERSREQUEST'].fields_by_name['identifier']._serialized_options = b'\272H\030r\026\020\000\030d2\020^[a-zA-Z0-9_-]*$'
  _globals['_DELETEPROVIDERREQUEST'].fields_by_name['identifier']._loaded_options = None
  _globals['_DELETEPROVIDERREQUEST'].fields_by_name['identifier']._serialized_options = b'\272H\030r\026\020\000\030d2\020^[a-zA-Z0-9_-]*$'
  _globals['_PROVIDERSERVICE'].methods_by_name['CreateProvider']._loaded_options = None
  _globals['_PROVIDERSERVICE'].methods_by_name['CreateProvider']._serialized_options = b'\202\265\030\002\030\004\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002\035\"\021/api/v1/providers:\010provider'
  _globals['_PROVIDERSERVICE'].methods_by_name['UpdateProvider']._loaded_options = None
  _globals['_PROVIDERSERVICE'].methods_by_name['UpdateProvider']._serialized_options = b'\202\265\030\002\030\004\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002*\032\036/api/v1/providers/{identifier}:\010provider'
  _globals['_PROVIDERSERVICE'].methods_by_name['DeleteProvider']._loaded_options = None
  _globals['_PROVIDERSERVICE'].methods_by_name['DeleteProvider']._serialized_options = b'\202\265\030\002\030\004\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002 *\036/api/v1/providers/{identifier}'
  _globals['_PROVIDERSERVICE'].methods_by_name['ListProviders']._loaded_options = None
  _globals['_PROVIDERSERVICE'].methods_by_name['ListProviders']._serialized_options = b'\202\265\030\002\030T\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002\023\022\021/api/v1/providers'
  _globals['_PROVIDER']._serialized_start=332
  _globals['_PROVIDER']._serialized_end=626
  _globals['_CREATEPROVIDER']._serialized_start=629
  _globals['_CREATEPROVIDER']._serialized_end=1472
  _globals['_CREATEPROVIDERREQUEST']._serialized_start=1475
  _globals['_CREATEPROVIDERREQUEST']._serialized_end=1625
  _globals['_CREATEPROVIDERRESPONSE']._serialized_start=1627
  _globals['_CREATEPROVIDERRESPONSE']._serialized_end=1712
  _globals['_UPDATEPROVIDER']._serialized_start=1715
  _globals['_UPDATEPROVIDER']._serialized_end=2419
  _globals['_UPDATEPROVIDERREQUEST']._serialized_start=2422
  _globals['_UPDATEPROVIDERREQUEST']._serialized_end=2633
  _globals['_UPDATEPROVIDERRESPONSE']._serialized_start=2635
  _globals['_UPDATEPROVIDERRESPONSE']._serialized_end=2720
  _globals['_LISTPROVIDERSREQUEST']._serialized_start=2723
  _globals['_LISTPROVIDERSREQUEST']._serialized_end=2866
  _globals['_LISTPROVIDERSRESPONSE']._serialized_start=2869
  _globals['_LISTPROVIDERSRESPONSE']._serialized_end=3066
  _globals['_DELETEPROVIDERREQUEST']._serialized_start=3068
  _globals['_DELETEPROVIDERREQUEST']._serialized_end=3152
  _globals['_DELETEPROVIDERRESPONSE']._serialized_start=3154
  _globals['_DELETEPROVIDERRESPONSE']._serialized_end=3178
  _globals['_PROVIDERSERVICE']._serialized_start=3181
  _globals['_PROVIDERSERVICE']._serialized_end=3881
# @@protoc_insertion_point(module_scope)
