# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: scalekit/v1/members/members.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from scalekit.v1.commons import commons_pb2 as scalekit_dot_v1_dot_commons_dot_commons__pb2
from scalekit.v1.options import options_pb2 as scalekit_dot_v1_dot_options_dot_options__pb2
from scalekit.v1.users import users_pb2 as scalekit_dot_v1_dot_users_dot_users__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!scalekit/v1/members/members.proto\x12\x13scalekit.v1.members\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a!scalekit/v1/commons/commons.proto\x1a!scalekit/v1/options/options.proto\x1a\x1dscalekit/v1/users/users.proto\"\xe2\x05\n\x06Member\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12;\n\x0b\x63reate_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ncreateTime\x12;\n\x0bupdate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nupdateTime\x12!\n\x0cworkspace_id\x18\x04 \x01(\tR\x0bworkspaceId\x12\x33\n\x04role\x18\x05 \x01(\x0e\x32\x1f.scalekit.v1.members.MemberRoleR\x04role\x12,\n\nfirst_name\x18\x06 \x01(\tB\x08\xbaH\x05r\x03\x18\xc8\x01H\x00R\tfirstName\x88\x01\x01\x12*\n\tlast_name\x18\x07 \x01(\tB\x08\xbaH\x05r\x03\x18\xc8\x01H\x01R\x08lastName\x88\x01\x01\x12\x1d\n\x05\x65mail\x18\x08 \x01(\tB\x07\xbaH\x04r\x02`\x01R\x05\x65mail\x12`\n\x08metadata\x18\t \x03(\x0b\x32).scalekit.v1.members.Member.MetadataEntryB\x19\xbaH\x16\x9a\x01\x13\x10\n\"\x06r\x04\x10\x03\x18\x19*\x07r\x05\x10\x01\x18\x80\x02R\x08metadata\x12V\n\rorganizations\x18\n \x03(\x0b\x32+.scalekit.v1.commons.OrganizationMembershipB\x03\xe0\x41\x03R\rorganizations\x12\x43\n\x0cuser_profile\x18\x0b \x01(\x0b\x32 .scalekit.v1.commons.UserProfileR\x0buserProfile\x12$\n\x0b\x65xternal_id\x18\x0c \x01(\tB\x03\xe0\x41\x03R\nexternalId\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\r\n\x0b_first_nameB\x0c\n\n_last_name\"R\n\x13\x43reateMemberRequest\x12;\n\x06member\x18\x01 \x01(\x0b\x32\x1b.scalekit.v1.members.MemberB\x06\xbaH\x03\xc8\x01\x01R\x06member\"K\n\x14\x43reateMemberResponse\x12\x33\n\x06member\x18\x01 \x01(\x0b\x32\x1b.scalekit.v1.members.MemberR\x06member\"\xc6\x03\n\x0cUpdateMember\x12\x38\n\x04role\x18\x05 \x01(\x0e\x32\x1f.scalekit.v1.members.MemberRoleH\x00R\x04role\x88\x01\x01\x12.\n\nfirst_name\x18\x06 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xc8\x01H\x01R\tfirstName\x88\x01\x01\x12,\n\tlast_name\x18\x07 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xc8\x01H\x02R\x08lastName\x88\x01\x01\x12\x66\n\x08metadata\x18\t \x03(\x0b\x32/.scalekit.v1.members.UpdateMember.MetadataEntryB\x19\xbaH\x16\x9a\x01\x13\x10\n\"\x06r\x04\x10\x03\x18\x19*\x07r\x05\x10\x01\x18\x80\x02R\x08metadata\x12G\n\x0cuser_profile\x18\n \x01(\x0b\x32$.scalekit.v1.users.UpdateUserProfileR\x0buserProfile\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x07\n\x05_roleB\r\n\x0b_first_nameB\x0c\n\n_last_nameJ\x04\x08\x04\x10\x05J\x04\x08\x08\x10\t\"W\n\x1aUpdateCurrentMemberRequest\x12\x39\n\x06member\x18\x01 \x01(\x0b\x32!.scalekit.v1.members.UpdateMemberR\x06member\"k\n\x13UpdateMemberRequest\x12\x19\n\x02id\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x13\x18\x19R\x02id\x12\x39\n\x06member\x18\x02 \x01(\x0b\x32!.scalekit.v1.members.UpdateMemberR\x06member\"K\n\x14UpdateMemberResponse\x12\x33\n\x06member\x18\x01 \x01(\x0b\x32\x1b.scalekit.v1.members.MemberR\x06member\"\x19\n\x17GetCurrentMemberRequest\"-\n\x10GetMemberRequest\x12\x19\n\x02id\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x13\x18\x19R\x02id\"H\n\x11GetMemberResponse\x12\x33\n\x06member\x18\x01 \x01(\x0b\x32\x1b.scalekit.v1.members.MemberR\x06member\"O\n\x11ListMemberRequest\x12\x1b\n\tpage_size\x18\x01 \x01(\rR\x08pageSize\x12\x1d\n\npage_token\x18\x02 \x01(\tR\tpageToken\"\x92\x01\n\x12ListMemberResponse\x12&\n\x0fnext_page_token\x18\x01 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x02 \x01(\rR\ttotalSize\x12\x35\n\x07members\x18\x03 \x03(\x0b\x32\x1b.scalekit.v1.members.MemberR\x07members\"0\n\x13\x44\x65leteMemberRequest\x12\x19\n\x02id\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x13\x18\x19R\x02id*>\n\nMemberRole\x12\x1b\n\x17MEMBER_ROLE_UNSPECIFIED\x10\x00\x12\t\n\x05\x41\x44MIN\x10\x01\x12\x08\n\x04USER\x10\x02\x32\xd3\x07\n\x0eMembersService\x12\x8a\x01\n\x0c\x43reateMember\x12(.scalekit.v1.members.CreateMemberRequest\x1a).scalekit.v1.members.CreateMemberResponse\"%\x82\xb5\x18\x02\x18@\x82\xd3\xe4\x93\x02\x19\"\x0f/api/v1/members:\x06member\x12\x9d\x01\n\x13UpdateCurrentMember\x12/.scalekit.v1.members.UpdateCurrentMemberRequest\x1a).scalekit.v1.members.UpdateMemberResponse\"*\x82\xb5\x18\x02\x18P\x82\xd3\xe4\x93\x02\x1e\x32\x14/api/v1/members:this:\x06member\x12\x8f\x01\n\x0cUpdateMember\x12(.scalekit.v1.members.UpdateMemberRequest\x1a).scalekit.v1.members.UpdateMemberResponse\"*\x82\xb5\x18\x02\x18@\x82\xd3\xe4\x93\x02\x1e\x32\x14/api/v1/members/{id}:\x06member\x12\x8c\x01\n\x10GetCurrentMember\x12,.scalekit.v1.members.GetCurrentMemberRequest\x1a&.scalekit.v1.members.GetMemberResponse\"\"\x82\xb5\x18\x02\x18P\x82\xd3\xe4\x93\x02\x16\x12\x14/api/v1/members:this\x12~\n\tGetMember\x12%.scalekit.v1.members.GetMemberRequest\x1a&.scalekit.v1.members.GetMemberResponse\"\"\x82\xb5\x18\x02\x18@\x82\xd3\xe4\x93\x02\x16\x12\x14/api/v1/members/{id}\x12}\n\x0bListMembers\x12&.scalekit.v1.members.ListMemberRequest\x1a\'.scalekit.v1.members.ListMemberResponse\"\x1d\x82\xb5\x18\x02\x18@\x82\xd3\xe4\x93\x02\x11\x12\x0f/api/v1/members\x12t\n\x0c\x44\x65leteMember\x12(.scalekit.v1.members.DeleteMemberRequest\x1a\x16.google.protobuf.Empty\"\"\x82\xb5\x18\x02\x18@\x82\xd3\xe4\x93\x02\x16*\x14/api/v1/members/{id}B3Z1github.com/scalekit-inc/scalekit/pkg/grpc/membersb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'scalekit.v1.members.members_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/scalekit-inc/scalekit/pkg/grpc/members'
  _globals['_MEMBER_METADATAENTRY']._loaded_options = None
  _globals['_MEMBER_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_MEMBER'].fields_by_name['first_name']._loaded_options = None
  _globals['_MEMBER'].fields_by_name['first_name']._serialized_options = b'\272H\005r\003\030\310\001'
  _globals['_MEMBER'].fields_by_name['last_name']._loaded_options = None
  _globals['_MEMBER'].fields_by_name['last_name']._serialized_options = b'\272H\005r\003\030\310\001'
  _globals['_MEMBER'].fields_by_name['email']._loaded_options = None
  _globals['_MEMBER'].fields_by_name['email']._serialized_options = b'\272H\004r\002`\001'
  _globals['_MEMBER'].fields_by_name['metadata']._loaded_options = None
  _globals['_MEMBER'].fields_by_name['metadata']._serialized_options = b'\272H\026\232\001\023\020\n\"\006r\004\020\003\030\031*\007r\005\020\001\030\200\002'
  _globals['_MEMBER'].fields_by_name['organizations']._loaded_options = None
  _globals['_MEMBER'].fields_by_name['organizations']._serialized_options = b'\340A\003'
  _globals['_MEMBER'].fields_by_name['external_id']._loaded_options = None
  _globals['_MEMBER'].fields_by_name['external_id']._serialized_options = b'\340A\003'
  _globals['_CREATEMEMBERREQUEST'].fields_by_name['member']._loaded_options = None
  _globals['_CREATEMEMBERREQUEST'].fields_by_name['member']._serialized_options = b'\272H\003\310\001\001'
  _globals['_UPDATEMEMBER_METADATAENTRY']._loaded_options = None
  _globals['_UPDATEMEMBER_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEMEMBER'].fields_by_name['first_name']._loaded_options = None
  _globals['_UPDATEMEMBER'].fields_by_name['first_name']._serialized_options = b'\272H\007r\005\020\001\030\310\001'
  _globals['_UPDATEMEMBER'].fields_by_name['last_name']._loaded_options = None
  _globals['_UPDATEMEMBER'].fields_by_name['last_name']._serialized_options = b'\272H\007r\005\020\001\030\310\001'
  _globals['_UPDATEMEMBER'].fields_by_name['metadata']._loaded_options = None
  _globals['_UPDATEMEMBER'].fields_by_name['metadata']._serialized_options = b'\272H\026\232\001\023\020\n\"\006r\004\020\003\030\031*\007r\005\020\001\030\200\002'
  _globals['_UPDATEMEMBERREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_UPDATEMEMBERREQUEST'].fields_by_name['id']._serialized_options = b'\272H\006r\004\020\023\030\031'
  _globals['_GETMEMBERREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETMEMBERREQUEST'].fields_by_name['id']._serialized_options = b'\272H\006r\004\020\023\030\031'
  _globals['_DELETEMEMBERREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_DELETEMEMBERREQUEST'].fields_by_name['id']._serialized_options = b'\272H\006r\004\020\023\030\031'
  _globals['_MEMBERSSERVICE'].methods_by_name['CreateMember']._loaded_options = None
  _globals['_MEMBERSSERVICE'].methods_by_name['CreateMember']._serialized_options = b'\202\265\030\002\030@\202\323\344\223\002\031\"\017/api/v1/members:\006member'
  _globals['_MEMBERSSERVICE'].methods_by_name['UpdateCurrentMember']._loaded_options = None
  _globals['_MEMBERSSERVICE'].methods_by_name['UpdateCurrentMember']._serialized_options = b'\202\265\030\002\030P\202\323\344\223\002\0362\024/api/v1/members:this:\006member'
  _globals['_MEMBERSSERVICE'].methods_by_name['UpdateMember']._loaded_options = None
  _globals['_MEMBERSSERVICE'].methods_by_name['UpdateMember']._serialized_options = b'\202\265\030\002\030@\202\323\344\223\002\0362\024/api/v1/members/{id}:\006member'
  _globals['_MEMBERSSERVICE'].methods_by_name['GetCurrentMember']._loaded_options = None
  _globals['_MEMBERSSERVICE'].methods_by_name['GetCurrentMember']._serialized_options = b'\202\265\030\002\030P\202\323\344\223\002\026\022\024/api/v1/members:this'
  _globals['_MEMBERSSERVICE'].methods_by_name['GetMember']._loaded_options = None
  _globals['_MEMBERSSERVICE'].methods_by_name['GetMember']._serialized_options = b'\202\265\030\002\030@\202\323\344\223\002\026\022\024/api/v1/members/{id}'
  _globals['_MEMBERSSERVICE'].methods_by_name['ListMembers']._loaded_options = None
  _globals['_MEMBERSSERVICE'].methods_by_name['ListMembers']._serialized_options = b'\202\265\030\002\030@\202\323\344\223\002\021\022\017/api/v1/members'
  _globals['_MEMBERSSERVICE'].methods_by_name['DeleteMember']._loaded_options = None
  _globals['_MEMBERSSERVICE'].methods_by_name['DeleteMember']._serialized_options = b'\202\265\030\002\030@\202\323\344\223\002\026*\024/api/v1/members/{id}'
  _globals['_MEMBERROLE']._serialized_start=2375
  _globals['_MEMBERROLE']._serialized_end=2437
  _globals['_MEMBER']._serialized_start=314
  _globals['_MEMBER']._serialized_end=1052
  _globals['_MEMBER_METADATAENTRY']._serialized_start=964
  _globals['_MEMBER_METADATAENTRY']._serialized_end=1023
  _globals['_CREATEMEMBERREQUEST']._serialized_start=1054
  _globals['_CREATEMEMBERREQUEST']._serialized_end=1136
  _globals['_CREATEMEMBERRESPONSE']._serialized_start=1138
  _globals['_CREATEMEMBERRESPONSE']._serialized_end=1213
  _globals['_UPDATEMEMBER']._serialized_start=1216
  _globals['_UPDATEMEMBER']._serialized_end=1670
  _globals['_UPDATEMEMBER_METADATAENTRY']._serialized_start=964
  _globals['_UPDATEMEMBER_METADATAENTRY']._serialized_end=1023
  _globals['_UPDATECURRENTMEMBERREQUEST']._serialized_start=1672
  _globals['_UPDATECURRENTMEMBERREQUEST']._serialized_end=1759
  _globals['_UPDATEMEMBERREQUEST']._serialized_start=1761
  _globals['_UPDATEMEMBERREQUEST']._serialized_end=1868
  _globals['_UPDATEMEMBERRESPONSE']._serialized_start=1870
  _globals['_UPDATEMEMBERRESPONSE']._serialized_end=1945
  _globals['_GETCURRENTMEMBERREQUEST']._serialized_start=1947
  _globals['_GETCURRENTMEMBERREQUEST']._serialized_end=1972
  _globals['_GETMEMBERREQUEST']._serialized_start=1974
  _globals['_GETMEMBERREQUEST']._serialized_end=2019
  _globals['_GETMEMBERRESPONSE']._serialized_start=2021
  _globals['_GETMEMBERRESPONSE']._serialized_end=2093
  _globals['_LISTMEMBERREQUEST']._serialized_start=2095
  _globals['_LISTMEMBERREQUEST']._serialized_end=2174
  _globals['_LISTMEMBERRESPONSE']._serialized_start=2177
  _globals['_LISTMEMBERRESPONSE']._serialized_end=2323
  _globals['_DELETEMEMBERREQUEST']._serialized_start=2325
  _globals['_DELETEMEMBERREQUEST']._serialized_end=2373
  _globals['_MEMBERSSERVICE']._serialized_start=2440
  _globals['_MEMBERSSERVICE']._serialized_end=3419
# @@protoc_insertion_point(module_scope)
