# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from scalekit.v1.organizations import organizations_pb2 as scalekit_dot_v1_dot_organizations_dot_organizations__pb2


class OrganizationServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateOrganization = channel.unary_unary(
                '/scalekit.v1.organizations.OrganizationService/CreateOrganization',
                request_serializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.CreateOrganizationRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.CreateOrganizationResponse.FromString,
                )
        self.UpdateOrganization = channel.unary_unary(
                '/scalekit.v1.organizations.OrganizationService/UpdateOrganization',
                request_serializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.UpdateOrganizationRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.UpdateOrganizationResponse.FromString,
                )
        self.GetOrganization = channel.unary_unary(
                '/scalekit.v1.organizations.OrganizationService/GetOrganization',
                request_serializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.GetOrganizationRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.GetOrganizationResponse.FromString,
                )
        self.ListOrganization = channel.unary_unary(
                '/scalekit.v1.organizations.OrganizationService/ListOrganization',
                request_serializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.ListOrganizationsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.ListOrganizationsResponse.FromString,
                )
        self.SearchOrganization = channel.unary_unary(
                '/scalekit.v1.organizations.OrganizationService/SearchOrganization',
                request_serializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.SearchOrganizationsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.SearchOrganizationsResponse.FromString,
                )
        self.DeleteOrganization = channel.unary_unary(
                '/scalekit.v1.organizations.OrganizationService/DeleteOrganization',
                request_serializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.DeleteOrganizationRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GeneratePortalLink = channel.unary_unary(
                '/scalekit.v1.organizations.OrganizationService/GeneratePortalLink',
                request_serializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.GeneratePortalLinkRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.GeneratePortalLinkResponse.FromString,
                )
        self.DeletePortalLink = channel.unary_unary(
                '/scalekit.v1.organizations.OrganizationService/DeletePortalLink',
                request_serializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.DeletePortalLinkRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DeletePortalLinkByID = channel.unary_unary(
                '/scalekit.v1.organizations.OrganizationService/DeletePortalLinkByID',
                request_serializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.DeletePortalLinkByIdRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetPortalLinks = channel.unary_unary(
                '/scalekit.v1.organizations.OrganizationService/GetPortalLinks',
                request_serializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.GetPortalLinkRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.GetPortalLinksResponse.FromString,
                )
        self.UpdateOrganizationSettings = channel.unary_unary(
                '/scalekit.v1.organizations.OrganizationService/UpdateOrganizationSettings',
                request_serializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.UpdateOrganizationSettingsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.GetOrganizationResponse.FromString,
                )
        self.CreateOrganizationSessionSettings = channel.unary_unary(
                '/scalekit.v1.organizations.OrganizationService/CreateOrganizationSessionSettings',
                request_serializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.CreateOrganizationSessionSettingsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.CreateOrganizationSessionSettingsResponse.FromString,
                )
        self.GetOrganizationSessionSettings = channel.unary_unary(
                '/scalekit.v1.organizations.OrganizationService/GetOrganizationSessionSettings',
                request_serializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.GetOrganizationSessionSettingsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.GetOrganizationSessionSettingsResponse.FromString,
                )
        self.UpdateOrganizationSessionSettings = channel.unary_unary(
                '/scalekit.v1.organizations.OrganizationService/UpdateOrganizationSessionSettings',
                request_serializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.UpdateOrganizationSessionSettingsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.UpdateOrganizationSessionSettingsResponse.FromString,
                )
        self.DeleteOrganizationSessionSettings = channel.unary_unary(
                '/scalekit.v1.organizations.OrganizationService/DeleteOrganizationSessionSettings',
                request_serializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.DeleteOrganizationSessionSettingsRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateUserManagementSettings = channel.unary_unary(
                '/scalekit.v1.organizations.OrganizationService/UpdateUserManagementSettings',
                request_serializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.UpdateUserManagementSettingsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.UpdateUserManagementSettingsResponse.FromString,
                )
        self.GetOrganizationUserManagementSetting = channel.unary_unary(
                '/scalekit.v1.organizations.OrganizationService/GetOrganizationUserManagementSetting',
                request_serializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.GetOrganizationUserManagementSettingsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.GetOrganizationUserManagementSettingsResponse.FromString,
                )


class OrganizationServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateOrganization(self, request, context):
        """Create Organization
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateOrganization(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrganization(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOrganization(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchOrganization(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteOrganization(self, request, context):
        """Delete an Organization
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GeneratePortalLink(self, request, context):
        """Generate Portal Link for Org
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeletePortalLink(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeletePortalLinkByID(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPortalLinks(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateOrganizationSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateOrganizationSessionSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrganizationSessionSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateOrganizationSessionSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteOrganizationSessionSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUserManagementSettings(self, request, context):
        """Update user management setting for an organization
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrganizationUserManagementSetting(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_OrganizationServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateOrganization': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateOrganization,
                    request_deserializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.CreateOrganizationRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.CreateOrganizationResponse.SerializeToString,
            ),
            'UpdateOrganization': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateOrganization,
                    request_deserializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.UpdateOrganizationRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.UpdateOrganizationResponse.SerializeToString,
            ),
            'GetOrganization': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganization,
                    request_deserializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.GetOrganizationRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.GetOrganizationResponse.SerializeToString,
            ),
            'ListOrganization': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOrganization,
                    request_deserializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.ListOrganizationsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.ListOrganizationsResponse.SerializeToString,
            ),
            'SearchOrganization': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchOrganization,
                    request_deserializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.SearchOrganizationsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.SearchOrganizationsResponse.SerializeToString,
            ),
            'DeleteOrganization': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteOrganization,
                    request_deserializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.DeleteOrganizationRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GeneratePortalLink': grpc.unary_unary_rpc_method_handler(
                    servicer.GeneratePortalLink,
                    request_deserializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.GeneratePortalLinkRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.GeneratePortalLinkResponse.SerializeToString,
            ),
            'DeletePortalLink': grpc.unary_unary_rpc_method_handler(
                    servicer.DeletePortalLink,
                    request_deserializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.DeletePortalLinkRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DeletePortalLinkByID': grpc.unary_unary_rpc_method_handler(
                    servicer.DeletePortalLinkByID,
                    request_deserializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.DeletePortalLinkByIdRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetPortalLinks': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPortalLinks,
                    request_deserializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.GetPortalLinkRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.GetPortalLinksResponse.SerializeToString,
            ),
            'UpdateOrganizationSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateOrganizationSettings,
                    request_deserializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.UpdateOrganizationSettingsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.GetOrganizationResponse.SerializeToString,
            ),
            'CreateOrganizationSessionSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateOrganizationSessionSettings,
                    request_deserializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.CreateOrganizationSessionSettingsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.CreateOrganizationSessionSettingsResponse.SerializeToString,
            ),
            'GetOrganizationSessionSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganizationSessionSettings,
                    request_deserializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.GetOrganizationSessionSettingsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.GetOrganizationSessionSettingsResponse.SerializeToString,
            ),
            'UpdateOrganizationSessionSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateOrganizationSessionSettings,
                    request_deserializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.UpdateOrganizationSessionSettingsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.UpdateOrganizationSessionSettingsResponse.SerializeToString,
            ),
            'DeleteOrganizationSessionSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteOrganizationSessionSettings,
                    request_deserializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.DeleteOrganizationSessionSettingsRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateUserManagementSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateUserManagementSettings,
                    request_deserializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.UpdateUserManagementSettingsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.UpdateUserManagementSettingsResponse.SerializeToString,
            ),
            'GetOrganizationUserManagementSetting': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganizationUserManagementSetting,
                    request_deserializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.GetOrganizationUserManagementSettingsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_organizations_dot_organizations__pb2.GetOrganizationUserManagementSettingsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'scalekit.v1.organizations.OrganizationService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class OrganizationService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateOrganization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.organizations.OrganizationService/CreateOrganization',
            scalekit_dot_v1_dot_organizations_dot_organizations__pb2.CreateOrganizationRequest.SerializeToString,
            scalekit_dot_v1_dot_organizations_dot_organizations__pb2.CreateOrganizationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateOrganization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.organizations.OrganizationService/UpdateOrganization',
            scalekit_dot_v1_dot_organizations_dot_organizations__pb2.UpdateOrganizationRequest.SerializeToString,
            scalekit_dot_v1_dot_organizations_dot_organizations__pb2.UpdateOrganizationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrganization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.organizations.OrganizationService/GetOrganization',
            scalekit_dot_v1_dot_organizations_dot_organizations__pb2.GetOrganizationRequest.SerializeToString,
            scalekit_dot_v1_dot_organizations_dot_organizations__pb2.GetOrganizationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOrganization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.organizations.OrganizationService/ListOrganization',
            scalekit_dot_v1_dot_organizations_dot_organizations__pb2.ListOrganizationsRequest.SerializeToString,
            scalekit_dot_v1_dot_organizations_dot_organizations__pb2.ListOrganizationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SearchOrganization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.organizations.OrganizationService/SearchOrganization',
            scalekit_dot_v1_dot_organizations_dot_organizations__pb2.SearchOrganizationsRequest.SerializeToString,
            scalekit_dot_v1_dot_organizations_dot_organizations__pb2.SearchOrganizationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteOrganization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.organizations.OrganizationService/DeleteOrganization',
            scalekit_dot_v1_dot_organizations_dot_organizations__pb2.DeleteOrganizationRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GeneratePortalLink(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.organizations.OrganizationService/GeneratePortalLink',
            scalekit_dot_v1_dot_organizations_dot_organizations__pb2.GeneratePortalLinkRequest.SerializeToString,
            scalekit_dot_v1_dot_organizations_dot_organizations__pb2.GeneratePortalLinkResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeletePortalLink(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.organizations.OrganizationService/DeletePortalLink',
            scalekit_dot_v1_dot_organizations_dot_organizations__pb2.DeletePortalLinkRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeletePortalLinkByID(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.organizations.OrganizationService/DeletePortalLinkByID',
            scalekit_dot_v1_dot_organizations_dot_organizations__pb2.DeletePortalLinkByIdRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPortalLinks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.organizations.OrganizationService/GetPortalLinks',
            scalekit_dot_v1_dot_organizations_dot_organizations__pb2.GetPortalLinkRequest.SerializeToString,
            scalekit_dot_v1_dot_organizations_dot_organizations__pb2.GetPortalLinksResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateOrganizationSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.organizations.OrganizationService/UpdateOrganizationSettings',
            scalekit_dot_v1_dot_organizations_dot_organizations__pb2.UpdateOrganizationSettingsRequest.SerializeToString,
            scalekit_dot_v1_dot_organizations_dot_organizations__pb2.GetOrganizationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateOrganizationSessionSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.organizations.OrganizationService/CreateOrganizationSessionSettings',
            scalekit_dot_v1_dot_organizations_dot_organizations__pb2.CreateOrganizationSessionSettingsRequest.SerializeToString,
            scalekit_dot_v1_dot_organizations_dot_organizations__pb2.CreateOrganizationSessionSettingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrganizationSessionSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.organizations.OrganizationService/GetOrganizationSessionSettings',
            scalekit_dot_v1_dot_organizations_dot_organizations__pb2.GetOrganizationSessionSettingsRequest.SerializeToString,
            scalekit_dot_v1_dot_organizations_dot_organizations__pb2.GetOrganizationSessionSettingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateOrganizationSessionSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.organizations.OrganizationService/UpdateOrganizationSessionSettings',
            scalekit_dot_v1_dot_organizations_dot_organizations__pb2.UpdateOrganizationSessionSettingsRequest.SerializeToString,
            scalekit_dot_v1_dot_organizations_dot_organizations__pb2.UpdateOrganizationSessionSettingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteOrganizationSessionSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.organizations.OrganizationService/DeleteOrganizationSessionSettings',
            scalekit_dot_v1_dot_organizations_dot_organizations__pb2.DeleteOrganizationSessionSettingsRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateUserManagementSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.organizations.OrganizationService/UpdateUserManagementSettings',
            scalekit_dot_v1_dot_organizations_dot_organizations__pb2.UpdateUserManagementSettingsRequest.SerializeToString,
            scalekit_dot_v1_dot_organizations_dot_organizations__pb2.UpdateUserManagementSettingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrganizationUserManagementSetting(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.organizations.OrganizationService/GetOrganizationUserManagementSetting',
            scalekit_dot_v1_dot_organizations_dot_organizations__pb2.GetOrganizationUserManagementSettingsRequest.SerializeToString,
            scalekit_dot_v1_dot_organizations_dot_organizations__pb2.GetOrganizationUserManagementSettingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
