# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from scalekit.v1.auth import auth_pb2 as scalekit_dot_v1_dot_auth_dot_auth__pb2


class AuthServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListAuthMethods = channel.unary_unary(
                '/scalekit.v1.auth.AuthService/ListAuthMethods',
                request_serializer=scalekit_dot_v1_dot_auth_dot_auth__pb2.ListAuthMethodsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_auth_dot_auth__pb2.ListAuthMethodsResponse.FromString,
                )
        self.DiscoveryAuthMethod = channel.unary_unary(
                '/scalekit.v1.auth.AuthService/DiscoveryAuthMethod',
                request_serializer=scalekit_dot_v1_dot_auth_dot_auth__pb2.DiscoveryAuthMethodRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_auth_dot_auth__pb2.DiscoveryAuthMethodResponse.FromString,
                )
        self.VerifyPasswordLessOtp = channel.unary_unary(
                '/scalekit.v1.auth.AuthService/VerifyPasswordLessOtp',
                request_serializer=scalekit_dot_v1_dot_auth_dot_auth__pb2.VerifyPasswordLessRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_auth_dot_auth__pb2.VerifyPasswordLessResponse.FromString,
                )
        self.ResendPasswordless = channel.unary_unary(
                '/scalekit.v1.auth.AuthService/ResendPasswordless',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ListUserOrganizations = channel.unary_unary(
                '/scalekit.v1.auth.AuthService/ListUserOrganizations',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_auth_dot_auth__pb2.ListUserOrganizationsResponse.FromString,
                )
        self.SignupOrganization = channel.unary_unary(
                '/scalekit.v1.auth.AuthService/SignupOrganization',
                request_serializer=scalekit_dot_v1_dot_auth_dot_auth__pb2.SignupOrganizationRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_auth_dot_auth__pb2.SignupOrganizationResponse.FromString,
                )
        self.GetAuthState = channel.unary_unary(
                '/scalekit.v1.auth.AuthService/GetAuthState',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_auth_dot_auth__pb2.GetAuthStateResponse.FromString,
                )
        self.Logout = channel.unary_unary(
                '/scalekit.v1.auth.AuthService/Logout',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetActiveSession = channel.unary_unary(
                '/scalekit.v1.auth.AuthService/GetActiveSession',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetAuthCustomizations = channel.unary_unary(
                '/scalekit.v1.auth.AuthService/GetAuthCustomizations',
                request_serializer=scalekit_dot_v1_dot_auth_dot_auth__pb2.GetAuthCustomizationsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_auth_dot_auth__pb2.GetAuthCustomizationsResponse.FromString,
                )
        self.GetAuthFeatures = channel.unary_unary(
                '/scalekit.v1.auth.AuthService/GetAuthFeatures',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_auth_dot_auth__pb2.GetAuthFeaturesResponse.FromString,
                )
        self.UpdateLoginUserDetails = channel.unary_unary(
                '/scalekit.v1.auth.AuthService/UpdateLoginUserDetails',
                request_serializer=scalekit_dot_v1_dot_auth_dot_auth__pb2.UpdateLoginUserDetailsRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class AuthServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListAuthMethods(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DiscoveryAuthMethod(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VerifyPasswordLessOtp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResendPasswordless(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUserOrganizations(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SignupOrganization(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAuthState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Logout(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetActiveSession(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAuthCustomizations(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAuthFeatures(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateLoginUserDetails(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AuthServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListAuthMethods': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAuthMethods,
                    request_deserializer=scalekit_dot_v1_dot_auth_dot_auth__pb2.ListAuthMethodsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_auth_dot_auth__pb2.ListAuthMethodsResponse.SerializeToString,
            ),
            'DiscoveryAuthMethod': grpc.unary_unary_rpc_method_handler(
                    servicer.DiscoveryAuthMethod,
                    request_deserializer=scalekit_dot_v1_dot_auth_dot_auth__pb2.DiscoveryAuthMethodRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_auth_dot_auth__pb2.DiscoveryAuthMethodResponse.SerializeToString,
            ),
            'VerifyPasswordLessOtp': grpc.unary_unary_rpc_method_handler(
                    servicer.VerifyPasswordLessOtp,
                    request_deserializer=scalekit_dot_v1_dot_auth_dot_auth__pb2.VerifyPasswordLessRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_auth_dot_auth__pb2.VerifyPasswordLessResponse.SerializeToString,
            ),
            'ResendPasswordless': grpc.unary_unary_rpc_method_handler(
                    servicer.ResendPasswordless,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListUserOrganizations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUserOrganizations,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=scalekit_dot_v1_dot_auth_dot_auth__pb2.ListUserOrganizationsResponse.SerializeToString,
            ),
            'SignupOrganization': grpc.unary_unary_rpc_method_handler(
                    servicer.SignupOrganization,
                    request_deserializer=scalekit_dot_v1_dot_auth_dot_auth__pb2.SignupOrganizationRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_auth_dot_auth__pb2.SignupOrganizationResponse.SerializeToString,
            ),
            'GetAuthState': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAuthState,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=scalekit_dot_v1_dot_auth_dot_auth__pb2.GetAuthStateResponse.SerializeToString,
            ),
            'Logout': grpc.unary_unary_rpc_method_handler(
                    servicer.Logout,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetActiveSession': grpc.unary_unary_rpc_method_handler(
                    servicer.GetActiveSession,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetAuthCustomizations': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAuthCustomizations,
                    request_deserializer=scalekit_dot_v1_dot_auth_dot_auth__pb2.GetAuthCustomizationsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_auth_dot_auth__pb2.GetAuthCustomizationsResponse.SerializeToString,
            ),
            'GetAuthFeatures': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAuthFeatures,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=scalekit_dot_v1_dot_auth_dot_auth__pb2.GetAuthFeaturesResponse.SerializeToString,
            ),
            'UpdateLoginUserDetails': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateLoginUserDetails,
                    request_deserializer=scalekit_dot_v1_dot_auth_dot_auth__pb2.UpdateLoginUserDetailsRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'scalekit.v1.auth.AuthService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AuthService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListAuthMethods(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.auth.AuthService/ListAuthMethods',
            scalekit_dot_v1_dot_auth_dot_auth__pb2.ListAuthMethodsRequest.SerializeToString,
            scalekit_dot_v1_dot_auth_dot_auth__pb2.ListAuthMethodsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DiscoveryAuthMethod(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.auth.AuthService/DiscoveryAuthMethod',
            scalekit_dot_v1_dot_auth_dot_auth__pb2.DiscoveryAuthMethodRequest.SerializeToString,
            scalekit_dot_v1_dot_auth_dot_auth__pb2.DiscoveryAuthMethodResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def VerifyPasswordLessOtp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.auth.AuthService/VerifyPasswordLessOtp',
            scalekit_dot_v1_dot_auth_dot_auth__pb2.VerifyPasswordLessRequest.SerializeToString,
            scalekit_dot_v1_dot_auth_dot_auth__pb2.VerifyPasswordLessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResendPasswordless(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.auth.AuthService/ResendPasswordless',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListUserOrganizations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.auth.AuthService/ListUserOrganizations',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            scalekit_dot_v1_dot_auth_dot_auth__pb2.ListUserOrganizationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SignupOrganization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.auth.AuthService/SignupOrganization',
            scalekit_dot_v1_dot_auth_dot_auth__pb2.SignupOrganizationRequest.SerializeToString,
            scalekit_dot_v1_dot_auth_dot_auth__pb2.SignupOrganizationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAuthState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.auth.AuthService/GetAuthState',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            scalekit_dot_v1_dot_auth_dot_auth__pb2.GetAuthStateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Logout(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.auth.AuthService/Logout',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetActiveSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.auth.AuthService/GetActiveSession',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAuthCustomizations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.auth.AuthService/GetAuthCustomizations',
            scalekit_dot_v1_dot_auth_dot_auth__pb2.GetAuthCustomizationsRequest.SerializeToString,
            scalekit_dot_v1_dot_auth_dot_auth__pb2.GetAuthCustomizationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAuthFeatures(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.auth.AuthService/GetAuthFeatures',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            scalekit_dot_v1_dot_auth_dot_auth__pb2.GetAuthFeaturesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateLoginUserDetails(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.auth.AuthService/UpdateLoginUserDetails',
            scalekit_dot_v1_dot_auth_dot_auth__pb2.UpdateLoginUserDetailsRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
