# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: scalekit/v1/connected_accounts/connected_accounts.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2
from scalekit.v1.options import options_pb2 as scalekit_dot_v1_dot_options_dot_options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7scalekit/v1/connected_accounts/connected_accounts.proto\x12\x1escalekit.v1.connected_accounts\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1bgoogle/api/visibility.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\x1a!scalekit/v1/options/options.proto\"\xfa\x06\n\x1cListConnectedAccountsRequest\x12t\n\x0forganization_id\x18\x01 \x01(\tBF\x92\x41:2!Organization ID for the connectorJ\x15\"org_121312434123312\"\xbaH\x06r\x04\x10\x00\x18 H\x00R\x0eorganizationId\x88\x01\x01\x12]\n\x07user_id\x18\x02 \x01(\tB?\x92\x41\x33\x32\x19User ID for the connectorJ\x16\"user_121312434123312\"\xbaH\x06r\x04\x10\x00\x18 H\x01R\x06userId\x88\x01\x01\x12\x61\n\tconnector\x18\x03 \x01(\tB>\x92\x41 2\x14\x43onnector identifierJ\x08\"notion\"\xbaH\x18r\x16\x10\x00\x18\x32\x32\x10^[a-zA-Z0-9_-]*$H\x02R\tconnector\x88\x01\x01\x12\x62\n\nidentifier\x18\x04 \x01(\tB=\x92\x41\x31\x32!Organization ID for the connectorJ\x0c\"app_google\"\xbaH\x06r\x04\x10\x00\x18\x64H\x03R\nidentifier\x88\x01\x01\x12U\n\x08provider\x18\x05 \x01(\tB9\x92\x41-2!Provider of the connected accountJ\x08\"google\"\xbaH\x06r\x04\x10\x00\x18\x32R\x08provider\x12^\n\tpage_size\x18\x06 \x01(\rBA\x92\x41\x35\x32/Number of connected accounts to return per pageJ\x02\x31\x30\xbaH\x06*\x04\x10\x64(\x00R\x08pageSize\x12l\n\npage_token\x18\x07 \x01(\tBM\x92\x41\x41\x32<Token for pagination, used to fetch the next page of resultsJ\x01\x31\xbaH\x06r\x04\x10\x00\x18\x64R\tpageToken\x12\\\n\x05query\x18\x08 \x01(\tBF\x92\x41:2)Search query to filter connected accountsJ\r\"search_term\"\xbaH\x06r\x04\x10\x00\x18\x64R\x05queryB\x12\n\x10_organization_idB\n\n\x08_user_idB\x0c\n\n_connectorB\r\n\x0b_identifier\"\xd3\x03\n\x1dListConnectedAccountsResponse\x12\x66\n\x12\x63onnected_accounts\x18\x01 \x03(\x0b\x32\x37.scalekit.v1.connected_accounts.ConnectedAccountForListR\x11\x63onnectedAccounts\x12`\n\ntotal_size\x18\x02 \x01(\rBA\x92\x41>27Total number of connected accounts matching the requestJ\x03\x31\x30\x30R\ttotalSize\x12o\n\x0fnext_page_token\x18\x03 \x01(\tBG\x92\x41;2\"Token for the next page of resultsJ\x15\"next_page_token_123\"\xbaH\x06r\x04\x10\x00\x18 R\rnextPageToken\x12w\n\x0fprev_page_token\x18\x04 \x01(\tBO\x92\x41\x43\x32&Token for the previous page of resultsJ\x19\"previous_page_token_123\"\xbaH\x06r\x04\x10\x00\x18 R\rprevPageToken\"\xf5\x05\n\x1eSearchConnectedAccountsRequest\x12\xb9\x01\n\x05query\x18\x01 \x01(\tB\xa2\x01\x92\x41\x91\x01\x32\x86\x01Search term to match against connected account identifiers, providers, or connectors. Must be at least 3 characters. Case insensitive.J\x06google\xbaH\nr\x05\x10\x03\x18\xc8\x01\xc8\x01\x01R\x05query\x12\x85\x01\n\tpage_size\x18\x02 \x01(\rBh\x92\x41^2XMaximum number of connected accounts to return per page. Value must be between 1 and 30.J\x02\x33\x30\xbaH\x04*\x02\x18\x1eR\x08pageSize\x12\xa5\x01\n\npage_token\x18\x03 \x01(\tB\x85\x01\x92\x41\x81\x01\x32\x61Token from a previous response for pagination. Provide this to retrieve the next page of results.J\x1c\x65yJwYWdlIjoyLCJsaW1pdCI6MzB9R\tpageToken:\xe6\x01\x92\x41\xe2\x01\n\x9c\x01*\x19Search Connected Accounts2\x7fSearch for connected accounts in your environment using a text query that matches against identifiers, providers, or connectors2Aquery=google&page_size=30&page_token=eyJwYWdlIjoyLCJsaW1pdCI6MzB9\"\xda\x03\n\x1fSearchConnectedAccountsResponse\x12\x66\n\x12\x63onnected_accounts\x18\x01 \x03(\x0b\x32\x37.scalekit.v1.connected_accounts.ConnectedAccountForListR\x11\x63onnectedAccounts\x12\x65\n\ntotal_size\x18\x02 \x01(\rBF\x92\x41\x43\x32<Total number of connected accounts matching the search queryJ\x03\x31\x30\x30R\ttotalSize\x12o\n\x0fnext_page_token\x18\x03 \x01(\tBG\x92\x41;2\"Token for the next page of resultsJ\x15\"next_page_token_123\"\xbaH\x06r\x04\x10\x00\x18 R\rnextPageToken\x12w\n\x0fprev_page_token\x18\x04 \x01(\tBO\x92\x41\x43\x32&Token for the previous page of resultsJ\x19\"previous_page_token_123\"\xbaH\x06r\x04\x10\x00\x18 R\rprevPageToken\"\xb8\x06\n\x1d\x43reateConnectedAccountRequest\x12t\n\x0forganization_id\x18\x01 \x01(\tBF\x92\x41:2!Organization ID for the connectorJ\x15\"org_121312434123312\"\xbaH\x06r\x04\x10\x00\x18 H\x00R\x0eorganizationId\x88\x01\x01\x12]\n\x07user_id\x18\x02 \x01(\tB?\x92\x41\x33\x32\x19User ID for the connectorJ\x16\"user_121312434123312\"\xbaH\x06r\x04\x10\x00\x18 H\x01R\x06userId\x88\x01\x01\x12\x61\n\tconnector\x18\x03 \x01(\tB>\x92\x41 2\x14\x43onnector identifierJ\x08\"notion\"\xbaH\x18r\x16\x10\x00\x18\x32\x32\x10^[a-zA-Z0-9_-]*$H\x02R\tconnector\x88\x01\x01\x12\x62\n\nidentifier\x18\x04 \x01(\tB=\x92\x41\x31\x32!Organization ID for the connectorJ\x0c\"app_google\"\xbaH\x06r\x04\x10\x00\x18\x64H\x03R\nidentifier\x88\x01\x01\x12\xbd\x02\n\x11\x63onnected_account\x18\x05 \x01(\x0b\x32\x36.scalekit.v1.connected_accounts.CreateConnectedAccountB\xd7\x01\x92\x41\xcd\x01\x32*Details of the connected account to createJ\x9e\x01{ \"authorization_type\": \"OAUTH2\", \"authorization_details\": { \"oauth_token\": { \"access_token\": \"...\", \"refresh_token\": \"...\", \"scopes\": [\"read\", \"write\"] } } }\xbaH\x03\xc8\x01\x01R\x10\x63onnectedAccountB\x12\n\x10_organization_idB\n\n\x08_user_idB\x0c\n\n_connectorB\r\n\x0b_identifier\"\xaf\x01\n\x1e\x43reateConnectedAccountResponse\x12\x8c\x01\n\x11\x63onnected_account\x18\x01 \x01(\x0b\x32\x30.scalekit.v1.connected_accounts.ConnectedAccountB-\x92\x41*2(Details of the created connected accountR\x10\x63onnectedAccount\"\x96\x07\n\x1dUpdateConnectedAccountRequest\x12t\n\x0forganization_id\x18\x01 \x01(\tBF\x92\x41:2!Organization ID for the connectorJ\x15\"org_121312434123312\"\xbaH\x06r\x04\x10\x00\x18 H\x00R\x0eorganizationId\x88\x01\x01\x12]\n\x07user_id\x18\x02 \x01(\tB?\x92\x41\x33\x32\x19User ID for the connectorJ\x16\"user_121312434123312\"\xbaH\x06r\x04\x10\x00\x18 H\x01R\x06userId\x88\x01\x01\x12O\n\tconnector\x18\x03 \x01(\tB,\x92\x41 2\x14\x43onnector identifierJ\x08\"notion\"\xbaH\x06r\x04\x10\x00\x18\x32H\x02R\tconnector\x88\x01\x01\x12\x62\n\nidentifier\x18\x04 \x01(\tB=\x92\x41\x31\x32!Organization ID for the connectorJ\x0c\"app_google\"\xbaH\x06r\x04\x10\x00\x18\x64H\x03R\nidentifier\x88\x01\x01\x12g\n\x02id\x18\x06 \x01(\tBR\x92\x41\x41\x32\x35Unique identifier for the connected account to updateJ\x08\"ca_123\"\xbaH\x0br\t\x10\x00\x18 :\x03\x63\x61_H\x04R\x02id\x88\x01\x01\x12\xbd\x02\n\x11\x63onnected_account\x18\x05 \x01(\x0b\x32\x36.scalekit.v1.connected_accounts.UpdateConnectedAccountB\xd7\x01\x92\x41\xcd\x01\x32*Details of the connected account to updateJ\x9e\x01{ \"authorization_type\": \"OAUTH2\", \"authorization_details\": { \"oauth_token\": { \"access_token\": \"...\", \"refresh_token\": \"...\", \"scopes\": [\"read\", \"write\"] } } }\xbaH\x03\xc8\x01\x01R\x10\x63onnectedAccountB\x12\n\x10_organization_idB\n\n\x08_user_idB\x0c\n\n_connectorB\r\n\x0b_identifierB\x05\n\x03_id\"\xaf\x01\n\x1eUpdateConnectedAccountResponse\x12\x8c\x01\n\x11\x63onnected_account\x18\x01 \x01(\x0b\x32\x30.scalekit.v1.connected_accounts.ConnectedAccountB-\x92\x41*2(Details of the updated connected accountR\x10\x63onnectedAccount\"\xe8\x04\n\x1d\x44\x65leteConnectedAccountRequest\x12t\n\x0forganization_id\x18\x01 \x01(\tBF\x92\x41:2!Organization ID for the connectorJ\x15\"org_121312434123312\"\xbaH\x06r\x04\x10\x00\x18 H\x00R\x0eorganizationId\x88\x01\x01\x12]\n\x07user_id\x18\x02 \x01(\tB?\x92\x41\x33\x32\x19User ID for the connectorJ\x16\"user_121312434123312\"\xbaH\x06r\x04\x10\x00\x18 H\x01R\x06userId\x88\x01\x01\x12\x61\n\tconnector\x18\x03 \x01(\tB>\x92\x41 2\x14\x43onnector identifierJ\x08\"notion\"\xbaH\x18r\x16\x10\x00\x18\x32\x32\x10^[a-zA-Z0-9_-]*$H\x02R\tconnector\x88\x01\x01\x12\x62\n\nidentifier\x18\x04 \x01(\tB=\x92\x41\x31\x32!Organization ID for the connectorJ\x0c\"app_google\"\xbaH\x06r\x04\x10\x00\x18\x64H\x03R\nidentifier\x88\x01\x01\x12g\n\x02id\x18\x05 \x01(\tBR\x92\x41\x41\x32\x35Unique identifier for the connected account to deleteJ\x08\"ca_123\"\xbaH\x0br\t\x10\x00\x18 :\x03\x63\x61_H\x04R\x02id\x88\x01\x01\x42\x12\n\x10_organization_idB\n\n\x08_user_idB\x0c\n\n_connectorB\r\n\x0b_identifierB\x05\n\x03_id\" \n\x1e\x44\x65leteConnectedAccountResponse\"\xd5\x04\n&GetMagicLinkForConnectedAccountRequest\x12t\n\x0forganization_id\x18\x01 \x01(\tBF\x92\x41:2!Organization ID for the connectorJ\x15\"org_121312434123312\"\xbaH\x06r\x04\x10\x00\x18 H\x00R\x0eorganizationId\x88\x01\x01\x12]\n\x07user_id\x18\x02 \x01(\tB?\x92\x41\x33\x32\x19User ID for the connectorJ\x16\"user_121312434123312\"\xbaH\x06r\x04\x10\x00\x18 H\x01R\x06userId\x88\x01\x01\x12O\n\tconnector\x18\x03 \x01(\tB,\x92\x41 2\x14\x43onnector identifierJ\x08\"notion\"\xbaH\x06r\x04\x10\x00\x18\x32H\x02R\tconnector\x88\x01\x01\x12\x62\n\nidentifier\x18\x04 \x01(\tB=\x92\x41\x31\x32!Organization ID for the connectorJ\x0c\"app_google\"\xbaH\x06r\x04\x10\x00\x18\x64H\x03R\nidentifier\x88\x01\x01\x12]\n\x02id\x18\x05 \x01(\tBH\x92\x41\x37\x32+Unique identifier for the connected accountJ\x08\"ca_123\"\xbaH\x0br\t\x10\x00\x18 :\x03\x63\x61_H\x04R\x02id\x88\x01\x01\x42\x12\n\x10_organization_idB\n\n\x08_user_idB\x0c\n\n_connectorB\r\n\x0b_identifierB\x05\n\x03_id\"\x99\x01\n.GetMagicLinkForConnectedAccountRedirectRequest\x12g\n\x0bredirect_to\x18\x01 \x01(\tBF\x92\x41:2!Organization ID for the connectorJ\x15\"org_121312434123312\"\xbaH\x06r\x04\x10\x00\x18 R\nredirectTo\"\x9c\x02\n\'GetMagicLinkForConnectedAccountResponse\x12r\n\x04link\x18\x01 \x01(\tB^\x92\x41[2%Authentication link for the connectorJ2\"https://notion.com/oauth/authorize?client_id=...\"R\x04link\x12}\n\x06\x65xpiry\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampBI\x92\x41\x46\x32,Expiry timestamp for the authentication linkJ\x16\"2024-03-20T15:04:05Z\"R\x06\x65xpiry\"\xb1\x02\n/GetMagicLinkForConnectedAccountRedirectResponse\x12\x7f\n\x0bredirect_to\x18\x01 \x01(\tB^\x92\x41[2%Authentication link for the connectorJ2\"https://notion.com/oauth/authorize?client_id=...\"R\nredirectTo\x12}\n\x06\x65xpiry\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampBI\x92\x41\x46\x32,Expiry timestamp for the authentication linkJ\x16\"2024-03-20T15:04:05Z\"R\x06\x65xpiry\"\xd5\x04\n&GetConnectedAccountByIdentifierRequest\x12t\n\x0forganization_id\x18\x01 \x01(\tBF\x92\x41:2!Organization ID for the connectorJ\x15\"org_121312434123312\"\xbaH\x06r\x04\x10\x00\x18 H\x00R\x0eorganizationId\x88\x01\x01\x12]\n\x07user_id\x18\x02 \x01(\tB?\x92\x41\x33\x32\x19User ID for the connectorJ\x16\"user_121312434123312\"\xbaH\x06r\x04\x10\x00\x18 H\x01R\x06userId\x88\x01\x01\x12O\n\tconnector\x18\x03 \x01(\tB,\x92\x41 2\x14\x43onnector identifierJ\x08\"notion\"\xbaH\x06r\x04\x10\x00\x18\x32H\x02R\tconnector\x88\x01\x01\x12\x62\n\nidentifier\x18\x04 \x01(\tB=\x92\x41\x31\x32!Organization ID for the connectorJ\x0c\"app_google\"\xbaH\x06r\x04\x10\x00\x18\x64H\x03R\nidentifier\x88\x01\x01\x12]\n\x02id\x18\x05 \x01(\tBH\x92\x41\x37\x32+Unique identifier for the connected accountJ\x08\"ca_123\"\xbaH\x0br\t\x10\x00\x18 :\x03\x63\x61_H\x04R\x02id\x88\x01\x01\x42\x12\n\x10_organization_idB\n\n\x08_user_idB\x0c\n\n_connectorB\r\n\x0b_identifierB\x05\n\x03_id\"\x88\x01\n\'GetConnectedAccountByIdentifierResponse\x12]\n\x11\x63onnected_account\x18\x01 \x01(\x0b\x32\x30.scalekit.v1.connected_accounts.ConnectedAccountR\x10\x63onnectedAccount\"\xff\x05\n\x10\x43onnectedAccount\x12\x1e\n\nidentifier\x18\x01 \x01(\tR\nidentifier\x12\x1a\n\x08provider\x18\x02 \x01(\tR\x08provider\x12G\n\x06status\x18\x03 \x01(\x0e\x32/.scalekit.v1.connected_accounts.ConnectorStatusR\x06status\x12\\\n\x12\x61uthorization_type\x18\x04 \x01(\x0e\x32-.scalekit.v1.connected_accounts.ConnectorTypeR\x11\x61uthorizationType\x12i\n\x15\x61uthorization_details\x18\x05 \x01(\x0b\x32\x34.scalekit.v1.connected_accounts.AuthorizationDetailsR\x14\x61uthorizationDetails\x12\x44\n\x10token_expires_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0etokenExpiresAt\x12\x39\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x12\x1c\n\tconnector\x18\x08 \x01(\tR\tconnector\x12<\n\x0clast_used_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nlastUsedAt\x12X\n\x02id\x18\n \x01(\tBH\x92\x41\x37\x32+Unique identifier for the connected accountJ\x08\"ca_123\"\xbaH\x0br\t\x10\x00\x18 :\x03\x63\x61_R\x02id\x12\x66\n\rconnection_id\x18\x0b \x01(\tBA\x92\x41\x35\x32\'Connection ID for the connected accountJ\n\"conn_123\"\xbaH\x06r\x04\x10\x00\x18 R\x0c\x63onnectionId\"\xfd\x01\n\x16\x43reateConnectedAccount\x12\xac\x01\n\x15\x61uthorization_details\x18\x05 \x01(\x0b\x32\x34.scalekit.v1.connected_accounts.AuthorizationDetailsBA\x92\x41\x38\x32\x36\x44\x65tails of the authorization for the connected account\xbaH\x03\xc8\x01\x01R\x14\x61uthorizationDetailsJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08J\x04\x08\x08\x10\tJ\x04\x08\t\x10\nJ\x04\x08\n\x10\x0b\"\xf7\x01\n\x16UpdateConnectedAccount\x12\xac\x01\n\x15\x61uthorization_details\x18\x05 \x01(\x0b\x32\x34.scalekit.v1.connected_accounts.AuthorizationDetailsBA\x92\x41\x38\x32\x36\x44\x65tails of the authorization for the connected account\xbaH\x03\xc8\x01\x01R\x14\x61uthorizationDetailsJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08J\x04\x08\x08\x10\tJ\x04\x08\t\x10\n\"\xd7\x04\n\x17\x43onnectedAccountForList\x12\x1e\n\nidentifier\x18\x01 \x01(\tR\nidentifier\x12\x1a\n\x08provider\x18\x02 \x01(\tR\x08provider\x12G\n\x06status\x18\x03 \x01(\x0e\x32/.scalekit.v1.connected_accounts.ConnectorStatusR\x06status\x12\\\n\x12\x61uthorization_type\x18\x04 \x01(\x0e\x32-.scalekit.v1.connected_accounts.ConnectorTypeR\x11\x61uthorizationType\x12\x44\n\x10token_expires_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0etokenExpiresAt\x12\x39\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x12\x1c\n\tconnector\x18\x08 \x01(\tR\tconnector\x12<\n\x0clast_used_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nlastUsedAt\x12\x0e\n\x02id\x18\n \x01(\tR\x02id\x12\x66\n\rconnection_id\x18\x0b \x01(\tBA\x92\x41\x35\x32\'Connection ID for the connected accountJ\n\"conn_123\"\xbaH\x06r\x04\x10\x00\x18 R\x0c\x63onnectionIdJ\x04\x08\x05\x10\x06\"\xbf\x01\n\x14\x41uthorizationDetails\x12M\n\x0boauth_token\x18\x01 \x01(\x0b\x32*.scalekit.v1.connected_accounts.OauthTokenH\x00R\noauthToken\x12M\n\x0bstatic_auth\x18\x02 \x01(\x0b\x32*.scalekit.v1.connected_accounts.StaticAuthH\x00R\nstaticAuthB\t\n\x07\x64\x65tails\"l\n\nOauthToken\x12!\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\tR\x0b\x61\x63\x63\x65ssToken\x12#\n\rrefresh_token\x18\x02 \x01(\tR\x0crefreshToken\x12\x16\n\x06scopes\x18\x03 \x03(\tR\x06scopes\"?\n\nStaticAuth\x12\x31\n\x07\x64\x65tails\x18\x01 \x01(\x0b\x32\x17.google.protobuf.StructR\x07\x64\x65tails*_\n\x0f\x43onnectorStatus\x12!\n\x1d\x43ONNECTION_STATUS_UNSPECIFIED\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x0b\n\x07\x45XPIRED\x10\x02\x12\x10\n\x0cPENDING_AUTH\x10\x03*\x81\x01\n\rConnectorType\x12\x1f\n\x1b\x43ONNECTION_TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05OAUTH\x10\x01\x12\x0b\n\x07\x41PI_KEY\x10\x02\x12\x0e\n\nBASIC_AUTH\x10\x03\x12\x10\n\x0c\x42\x45\x41RER_TOKEN\x10\x04\x12\n\n\x06\x43USTOM\x10\x05\x12\t\n\x05\x42\x41SIC\x10\x06\x32\xb0\x15\n\x17\x43onnectedAccountService\x12\xd0\x02\n\x15ListConnectedAccounts\x12<.scalekit.v1.connected_accounts.ListConnectedAccountsRequest\x1a=.scalekit.v1.connected_accounts.ListConnectedAccountsResponse\"\xb9\x01\x92\x41\x7f\n\rAppConnectors\x12\x1bList all connected accounts\x1aQList all connected accounts, optionally filtered by connection and/or identifier.\x82\xb5\x18\x02\x18t\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02\x1c\x12\x1a/api/v1/connected_accounts\x12\x8a\x03\n\x17SearchConnectedAccounts\x12>.scalekit.v1.connected_accounts.SearchConnectedAccountsRequest\x1a?.scalekit.v1.connected_accounts.SearchConnectedAccountsResponse\"\xed\x01\x92\x41\xab\x01\n\rAppConnectors\x12\x19Search connected accounts\x1a\x7fSearch for connected accounts in your environment using a text query that matches against identifiers, providers, or connectors\x82\xb5\x18\x02\x18t\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02#\x12!/api/v1/connected_accounts:search\x12\xa3\x02\n\x16\x43reateConnectedAccount\x12=.scalekit.v1.connected_accounts.CreateConnectedAccountRequest\x1a>.scalekit.v1.connected_accounts.CreateConnectedAccountResponse\"\x89\x01\x92\x41L\n\rAppConnectors\x12\x1a\x43reate a connected account\x1a\x1f\x43reate a new connected account.\x82\xb5\x18\x02\x18t\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02\x1f\"\x1a/api/v1/connected_accounts:\x01*\x12\xa9\x02\n\x16UpdateConnectedAccount\x12=.scalekit.v1.connected_accounts.UpdateConnectedAccountRequest\x1a>.scalekit.v1.connected_accounts.UpdateConnectedAccountResponse\"\x8f\x01\x92\x41R\n\rAppConnectors\x12\x1aUpdate a connected account\x1a%Update an existing connected account.\x82\xb5\x18\x02\x18t\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02\x1f\x1a\x1a/api/v1/connected_accounts:\x01*\x12\xa6\x02\n\x16\x44\x65leteConnectedAccount\x12=.scalekit.v1.connected_accounts.DeleteConnectedAccountRequest\x1a>.scalekit.v1.connected_accounts.DeleteConnectedAccountResponse\"\x8c\x01\x92\x41H\n\rAppConnectors\x12\x1a\x44\x65lete a connected account\x1a\x1b\x44\x65lete a connected account.\x82\xb5\x18\x02\x18t\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02&\"!/api/v1/connected_accounts:delete:\x01*\x12\xe1\x02\n\x1fGetMagicLinkForConnectedAccount\x12\x46.scalekit.v1.connected_accounts.GetMagicLinkForConnectedAccountRequest\x1aG.scalekit.v1.connected_accounts.GetMagicLinkForConnectedAccountResponse\"\xac\x01\x92\x41\x64\n\rAppConnectors\x12(Get a magic link for a connected account\x1a)Get a magic link for a connected account.\x82\xb5\x18\x02\x18t\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02*\"%/api/v1/connected_accounts/magic_link:\x01*\x12\xcc\x02\n\x17GetConnectedAccountAuth\x12\x46.scalekit.v1.connected_accounts.GetConnectedAccountByIdentifierRequest\x1aG.scalekit.v1.connected_accounts.GetConnectedAccountByIdentifierResponse\"\x9f\x01\x92\x41`\n\rAppConnectors\x12#Get connected account by identifier\x1a*Get a connected account by its identifier.\x82\xb5\x18\x02\x18t\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02!\x12\x1f/api/v1/connected_accounts/auth\x12\x86\x03\n+GetMagicLinkForConnectedAccountWithRedirect\x12N.scalekit.v1.connected_accounts.GetMagicLinkForConnectedAccountRedirectRequest\x1aO.scalekit.v1.connected_accounts.GetMagicLinkForConnectedAccountRedirectResponse\"\xb5\x01\x92\x41\x64\n\rAppConnectors\x12(Get a magic link for a connected account\x1a)Get a magic link for a connected account.\x82\xb5\x18\x02\x18\x01\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02\x33\"./api/v1/connected_accounts/magic_link/redirect:\x01*B>Z<github.com/scalekit-inc/scalekit/pkg/grpc/connected_accountsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'scalekit.v1.connected_accounts.connected_accounts_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z<github.com/scalekit-inc/scalekit/pkg/grpc/connected_accounts'
  _globals['_LISTCONNECTEDACCOUNTSREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_LISTCONNECTEDACCOUNTSREQUEST'].fields_by_name['organization_id']._serialized_options = b'\222A:2!Organization ID for the connectorJ\025\"org_121312434123312\"\272H\006r\004\020\000\030 '
  _globals['_LISTCONNECTEDACCOUNTSREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_LISTCONNECTEDACCOUNTSREQUEST'].fields_by_name['user_id']._serialized_options = b'\222A32\031User ID for the connectorJ\026\"user_121312434123312\"\272H\006r\004\020\000\030 '
  _globals['_LISTCONNECTEDACCOUNTSREQUEST'].fields_by_name['connector']._loaded_options = None
  _globals['_LISTCONNECTEDACCOUNTSREQUEST'].fields_by_name['connector']._serialized_options = b'\222A 2\024Connector identifierJ\010\"notion\"\272H\030r\026\020\000\03022\020^[a-zA-Z0-9_-]*$'
  _globals['_LISTCONNECTEDACCOUNTSREQUEST'].fields_by_name['identifier']._loaded_options = None
  _globals['_LISTCONNECTEDACCOUNTSREQUEST'].fields_by_name['identifier']._serialized_options = b'\222A12!Organization ID for the connectorJ\014\"app_google\"\272H\006r\004\020\000\030d'
  _globals['_LISTCONNECTEDACCOUNTSREQUEST'].fields_by_name['provider']._loaded_options = None
  _globals['_LISTCONNECTEDACCOUNTSREQUEST'].fields_by_name['provider']._serialized_options = b'\222A-2!Provider of the connected accountJ\010\"google\"\272H\006r\004\020\000\0302'
  _globals['_LISTCONNECTEDACCOUNTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCONNECTEDACCOUNTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\222A52/Number of connected accounts to return per pageJ\00210\272H\006*\004\020d(\000'
  _globals['_LISTCONNECTEDACCOUNTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCONNECTEDACCOUNTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\222AA2<Token for pagination, used to fetch the next page of resultsJ\0011\272H\006r\004\020\000\030d'
  _globals['_LISTCONNECTEDACCOUNTSREQUEST'].fields_by_name['query']._loaded_options = None
  _globals['_LISTCONNECTEDACCOUNTSREQUEST'].fields_by_name['query']._serialized_options = b'\222A:2)Search query to filter connected accountsJ\r\"search_term\"\272H\006r\004\020\000\030d'
  _globals['_LISTCONNECTEDACCOUNTSRESPONSE'].fields_by_name['total_size']._loaded_options = None
  _globals['_LISTCONNECTEDACCOUNTSRESPONSE'].fields_by_name['total_size']._serialized_options = b'\222A>27Total number of connected accounts matching the requestJ\003100'
  _globals['_LISTCONNECTEDACCOUNTSRESPONSE'].fields_by_name['next_page_token']._loaded_options = None
  _globals['_LISTCONNECTEDACCOUNTSRESPONSE'].fields_by_name['next_page_token']._serialized_options = b'\222A;2\"Token for the next page of resultsJ\025\"next_page_token_123\"\272H\006r\004\020\000\030 '
  _globals['_LISTCONNECTEDACCOUNTSRESPONSE'].fields_by_name['prev_page_token']._loaded_options = None
  _globals['_LISTCONNECTEDACCOUNTSRESPONSE'].fields_by_name['prev_page_token']._serialized_options = b'\222AC2&Token for the previous page of resultsJ\031\"previous_page_token_123\"\272H\006r\004\020\000\030 '
  _globals['_SEARCHCONNECTEDACCOUNTSREQUEST'].fields_by_name['query']._loaded_options = None
  _globals['_SEARCHCONNECTEDACCOUNTSREQUEST'].fields_by_name['query']._serialized_options = b'\222A\221\0012\206\001Search term to match against connected account identifiers, providers, or connectors. Must be at least 3 characters. Case insensitive.J\006google\272H\nr\005\020\003\030\310\001\310\001\001'
  _globals['_SEARCHCONNECTEDACCOUNTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_SEARCHCONNECTEDACCOUNTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\222A^2XMaximum number of connected accounts to return per page. Value must be between 1 and 30.J\00230\272H\004*\002\030\036'
  _globals['_SEARCHCONNECTEDACCOUNTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_SEARCHCONNECTEDACCOUNTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\222A\201\0012aToken from a previous response for pagination. Provide this to retrieve the next page of results.J\034eyJwYWdlIjoyLCJsaW1pdCI6MzB9'
  _globals['_SEARCHCONNECTEDACCOUNTSREQUEST']._loaded_options = None
  _globals['_SEARCHCONNECTEDACCOUNTSREQUEST']._serialized_options = b'\222A\342\001\n\234\001*\031Search Connected Accounts2\177Search for connected accounts in your environment using a text query that matches against identifiers, providers, or connectors2Aquery=google&page_size=30&page_token=eyJwYWdlIjoyLCJsaW1pdCI6MzB9'
  _globals['_SEARCHCONNECTEDACCOUNTSRESPONSE'].fields_by_name['total_size']._loaded_options = None
  _globals['_SEARCHCONNECTEDACCOUNTSRESPONSE'].fields_by_name['total_size']._serialized_options = b'\222AC2<Total number of connected accounts matching the search queryJ\003100'
  _globals['_SEARCHCONNECTEDACCOUNTSRESPONSE'].fields_by_name['next_page_token']._loaded_options = None
  _globals['_SEARCHCONNECTEDACCOUNTSRESPONSE'].fields_by_name['next_page_token']._serialized_options = b'\222A;2\"Token for the next page of resultsJ\025\"next_page_token_123\"\272H\006r\004\020\000\030 '
  _globals['_SEARCHCONNECTEDACCOUNTSRESPONSE'].fields_by_name['prev_page_token']._loaded_options = None
  _globals['_SEARCHCONNECTEDACCOUNTSRESPONSE'].fields_by_name['prev_page_token']._serialized_options = b'\222AC2&Token for the previous page of resultsJ\031\"previous_page_token_123\"\272H\006r\004\020\000\030 '
  _globals['_CREATECONNECTEDACCOUNTREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_CREATECONNECTEDACCOUNTREQUEST'].fields_by_name['organization_id']._serialized_options = b'\222A:2!Organization ID for the connectorJ\025\"org_121312434123312\"\272H\006r\004\020\000\030 '
  _globals['_CREATECONNECTEDACCOUNTREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_CREATECONNECTEDACCOUNTREQUEST'].fields_by_name['user_id']._serialized_options = b'\222A32\031User ID for the connectorJ\026\"user_121312434123312\"\272H\006r\004\020\000\030 '
  _globals['_CREATECONNECTEDACCOUNTREQUEST'].fields_by_name['connector']._loaded_options = None
  _globals['_CREATECONNECTEDACCOUNTREQUEST'].fields_by_name['connector']._serialized_options = b'\222A 2\024Connector identifierJ\010\"notion\"\272H\030r\026\020\000\03022\020^[a-zA-Z0-9_-]*$'
  _globals['_CREATECONNECTEDACCOUNTREQUEST'].fields_by_name['identifier']._loaded_options = None
  _globals['_CREATECONNECTEDACCOUNTREQUEST'].fields_by_name['identifier']._serialized_options = b'\222A12!Organization ID for the connectorJ\014\"app_google\"\272H\006r\004\020\000\030d'
  _globals['_CREATECONNECTEDACCOUNTREQUEST'].fields_by_name['connected_account']._loaded_options = None
  _globals['_CREATECONNECTEDACCOUNTREQUEST'].fields_by_name['connected_account']._serialized_options = b'\222A\315\0012*Details of the connected account to createJ\236\001{ \"authorization_type\": \"OAUTH2\", \"authorization_details\": { \"oauth_token\": { \"access_token\": \"...\", \"refresh_token\": \"...\", \"scopes\": [\"read\", \"write\"] } } }\272H\003\310\001\001'
  _globals['_CREATECONNECTEDACCOUNTRESPONSE'].fields_by_name['connected_account']._loaded_options = None
  _globals['_CREATECONNECTEDACCOUNTRESPONSE'].fields_by_name['connected_account']._serialized_options = b'\222A*2(Details of the created connected account'
  _globals['_UPDATECONNECTEDACCOUNTREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_UPDATECONNECTEDACCOUNTREQUEST'].fields_by_name['organization_id']._serialized_options = b'\222A:2!Organization ID for the connectorJ\025\"org_121312434123312\"\272H\006r\004\020\000\030 '
  _globals['_UPDATECONNECTEDACCOUNTREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_UPDATECONNECTEDACCOUNTREQUEST'].fields_by_name['user_id']._serialized_options = b'\222A32\031User ID for the connectorJ\026\"user_121312434123312\"\272H\006r\004\020\000\030 '
  _globals['_UPDATECONNECTEDACCOUNTREQUEST'].fields_by_name['connector']._loaded_options = None
  _globals['_UPDATECONNECTEDACCOUNTREQUEST'].fields_by_name['connector']._serialized_options = b'\222A 2\024Connector identifierJ\010\"notion\"\272H\006r\004\020\000\0302'
  _globals['_UPDATECONNECTEDACCOUNTREQUEST'].fields_by_name['identifier']._loaded_options = None
  _globals['_UPDATECONNECTEDACCOUNTREQUEST'].fields_by_name['identifier']._serialized_options = b'\222A12!Organization ID for the connectorJ\014\"app_google\"\272H\006r\004\020\000\030d'
  _globals['_UPDATECONNECTEDACCOUNTREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_UPDATECONNECTEDACCOUNTREQUEST'].fields_by_name['id']._serialized_options = b'\222AA25Unique identifier for the connected account to updateJ\010\"ca_123\"\272H\013r\t\020\000\030 :\003ca_'
  _globals['_UPDATECONNECTEDACCOUNTREQUEST'].fields_by_name['connected_account']._loaded_options = None
  _globals['_UPDATECONNECTEDACCOUNTREQUEST'].fields_by_name['connected_account']._serialized_options = b'\222A\315\0012*Details of the connected account to updateJ\236\001{ \"authorization_type\": \"OAUTH2\", \"authorization_details\": { \"oauth_token\": { \"access_token\": \"...\", \"refresh_token\": \"...\", \"scopes\": [\"read\", \"write\"] } } }\272H\003\310\001\001'
  _globals['_UPDATECONNECTEDACCOUNTRESPONSE'].fields_by_name['connected_account']._loaded_options = None
  _globals['_UPDATECONNECTEDACCOUNTRESPONSE'].fields_by_name['connected_account']._serialized_options = b'\222A*2(Details of the updated connected account'
  _globals['_DELETECONNECTEDACCOUNTREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_DELETECONNECTEDACCOUNTREQUEST'].fields_by_name['organization_id']._serialized_options = b'\222A:2!Organization ID for the connectorJ\025\"org_121312434123312\"\272H\006r\004\020\000\030 '
  _globals['_DELETECONNECTEDACCOUNTREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_DELETECONNECTEDACCOUNTREQUEST'].fields_by_name['user_id']._serialized_options = b'\222A32\031User ID for the connectorJ\026\"user_121312434123312\"\272H\006r\004\020\000\030 '
  _globals['_DELETECONNECTEDACCOUNTREQUEST'].fields_by_name['connector']._loaded_options = None
  _globals['_DELETECONNECTEDACCOUNTREQUEST'].fields_by_name['connector']._serialized_options = b'\222A 2\024Connector identifierJ\010\"notion\"\272H\030r\026\020\000\03022\020^[a-zA-Z0-9_-]*$'
  _globals['_DELETECONNECTEDACCOUNTREQUEST'].fields_by_name['identifier']._loaded_options = None
  _globals['_DELETECONNECTEDACCOUNTREQUEST'].fields_by_name['identifier']._serialized_options = b'\222A12!Organization ID for the connectorJ\014\"app_google\"\272H\006r\004\020\000\030d'
  _globals['_DELETECONNECTEDACCOUNTREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_DELETECONNECTEDACCOUNTREQUEST'].fields_by_name['id']._serialized_options = b'\222AA25Unique identifier for the connected account to deleteJ\010\"ca_123\"\272H\013r\t\020\000\030 :\003ca_'
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREQUEST'].fields_by_name['organization_id']._serialized_options = b'\222A:2!Organization ID for the connectorJ\025\"org_121312434123312\"\272H\006r\004\020\000\030 '
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREQUEST'].fields_by_name['user_id']._serialized_options = b'\222A32\031User ID for the connectorJ\026\"user_121312434123312\"\272H\006r\004\020\000\030 '
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREQUEST'].fields_by_name['connector']._loaded_options = None
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREQUEST'].fields_by_name['connector']._serialized_options = b'\222A 2\024Connector identifierJ\010\"notion\"\272H\006r\004\020\000\0302'
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREQUEST'].fields_by_name['identifier']._loaded_options = None
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREQUEST'].fields_by_name['identifier']._serialized_options = b'\222A12!Organization ID for the connectorJ\014\"app_google\"\272H\006r\004\020\000\030d'
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREQUEST'].fields_by_name['id']._serialized_options = b'\222A72+Unique identifier for the connected accountJ\010\"ca_123\"\272H\013r\t\020\000\030 :\003ca_'
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREDIRECTREQUEST'].fields_by_name['redirect_to']._loaded_options = None
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREDIRECTREQUEST'].fields_by_name['redirect_to']._serialized_options = b'\222A:2!Organization ID for the connectorJ\025\"org_121312434123312\"\272H\006r\004\020\000\030 '
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTRESPONSE'].fields_by_name['link']._loaded_options = None
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTRESPONSE'].fields_by_name['link']._serialized_options = b'\222A[2%Authentication link for the connectorJ2\"https://notion.com/oauth/authorize?client_id=...\"'
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTRESPONSE'].fields_by_name['expiry']._loaded_options = None
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTRESPONSE'].fields_by_name['expiry']._serialized_options = b'\222AF2,Expiry timestamp for the authentication linkJ\026\"2024-03-20T15:04:05Z\"'
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREDIRECTRESPONSE'].fields_by_name['redirect_to']._loaded_options = None
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREDIRECTRESPONSE'].fields_by_name['redirect_to']._serialized_options = b'\222A[2%Authentication link for the connectorJ2\"https://notion.com/oauth/authorize?client_id=...\"'
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREDIRECTRESPONSE'].fields_by_name['expiry']._loaded_options = None
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREDIRECTRESPONSE'].fields_by_name['expiry']._serialized_options = b'\222AF2,Expiry timestamp for the authentication linkJ\026\"2024-03-20T15:04:05Z\"'
  _globals['_GETCONNECTEDACCOUNTBYIDENTIFIERREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_GETCONNECTEDACCOUNTBYIDENTIFIERREQUEST'].fields_by_name['organization_id']._serialized_options = b'\222A:2!Organization ID for the connectorJ\025\"org_121312434123312\"\272H\006r\004\020\000\030 '
  _globals['_GETCONNECTEDACCOUNTBYIDENTIFIERREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_GETCONNECTEDACCOUNTBYIDENTIFIERREQUEST'].fields_by_name['user_id']._serialized_options = b'\222A32\031User ID for the connectorJ\026\"user_121312434123312\"\272H\006r\004\020\000\030 '
  _globals['_GETCONNECTEDACCOUNTBYIDENTIFIERREQUEST'].fields_by_name['connector']._loaded_options = None
  _globals['_GETCONNECTEDACCOUNTBYIDENTIFIERREQUEST'].fields_by_name['connector']._serialized_options = b'\222A 2\024Connector identifierJ\010\"notion\"\272H\006r\004\020\000\0302'
  _globals['_GETCONNECTEDACCOUNTBYIDENTIFIERREQUEST'].fields_by_name['identifier']._loaded_options = None
  _globals['_GETCONNECTEDACCOUNTBYIDENTIFIERREQUEST'].fields_by_name['identifier']._serialized_options = b'\222A12!Organization ID for the connectorJ\014\"app_google\"\272H\006r\004\020\000\030d'
  _globals['_GETCONNECTEDACCOUNTBYIDENTIFIERREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETCONNECTEDACCOUNTBYIDENTIFIERREQUEST'].fields_by_name['id']._serialized_options = b'\222A72+Unique identifier for the connected accountJ\010\"ca_123\"\272H\013r\t\020\000\030 :\003ca_'
  _globals['_CONNECTEDACCOUNT'].fields_by_name['id']._loaded_options = None
  _globals['_CONNECTEDACCOUNT'].fields_by_name['id']._serialized_options = b'\222A72+Unique identifier for the connected accountJ\010\"ca_123\"\272H\013r\t\020\000\030 :\003ca_'
  _globals['_CONNECTEDACCOUNT'].fields_by_name['connection_id']._loaded_options = None
  _globals['_CONNECTEDACCOUNT'].fields_by_name['connection_id']._serialized_options = b'\222A52\'Connection ID for the connected accountJ\n\"conn_123\"\272H\006r\004\020\000\030 '
  _globals['_CREATECONNECTEDACCOUNT'].fields_by_name['authorization_details']._loaded_options = None
  _globals['_CREATECONNECTEDACCOUNT'].fields_by_name['authorization_details']._serialized_options = b'\222A826Details of the authorization for the connected account\272H\003\310\001\001'
  _globals['_UPDATECONNECTEDACCOUNT'].fields_by_name['authorization_details']._loaded_options = None
  _globals['_UPDATECONNECTEDACCOUNT'].fields_by_name['authorization_details']._serialized_options = b'\222A826Details of the authorization for the connected account\272H\003\310\001\001'
  _globals['_CONNECTEDACCOUNTFORLIST'].fields_by_name['connection_id']._loaded_options = None
  _globals['_CONNECTEDACCOUNTFORLIST'].fields_by_name['connection_id']._serialized_options = b'\222A52\'Connection ID for the connected accountJ\n\"conn_123\"\272H\006r\004\020\000\030 '
  _globals['_CONNECTEDACCOUNTSERVICE'].methods_by_name['ListConnectedAccounts']._loaded_options = None
  _globals['_CONNECTEDACCOUNTSERVICE'].methods_by_name['ListConnectedAccounts']._serialized_options = b'\222A\177\n\rAppConnectors\022\033List all connected accounts\032QList all connected accounts, optionally filtered by connection and/or identifier.\202\265\030\002\030t\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002\034\022\032/api/v1/connected_accounts'
  _globals['_CONNECTEDACCOUNTSERVICE'].methods_by_name['SearchConnectedAccounts']._loaded_options = None
  _globals['_CONNECTEDACCOUNTSERVICE'].methods_by_name['SearchConnectedAccounts']._serialized_options = b'\222A\253\001\n\rAppConnectors\022\031Search connected accounts\032\177Search for connected accounts in your environment using a text query that matches against identifiers, providers, or connectors\202\265\030\002\030t\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002#\022!/api/v1/connected_accounts:search'
  _globals['_CONNECTEDACCOUNTSERVICE'].methods_by_name['CreateConnectedAccount']._loaded_options = None
  _globals['_CONNECTEDACCOUNTSERVICE'].methods_by_name['CreateConnectedAccount']._serialized_options = b'\222AL\n\rAppConnectors\022\032Create a connected account\032\037Create a new connected account.\202\265\030\002\030t\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002\037\"\032/api/v1/connected_accounts:\001*'
  _globals['_CONNECTEDACCOUNTSERVICE'].methods_by_name['UpdateConnectedAccount']._loaded_options = None
  _globals['_CONNECTEDACCOUNTSERVICE'].methods_by_name['UpdateConnectedAccount']._serialized_options = b'\222AR\n\rAppConnectors\022\032Update a connected account\032%Update an existing connected account.\202\265\030\002\030t\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002\037\032\032/api/v1/connected_accounts:\001*'
  _globals['_CONNECTEDACCOUNTSERVICE'].methods_by_name['DeleteConnectedAccount']._loaded_options = None
  _globals['_CONNECTEDACCOUNTSERVICE'].methods_by_name['DeleteConnectedAccount']._serialized_options = b'\222AH\n\rAppConnectors\022\032Delete a connected account\032\033Delete a connected account.\202\265\030\002\030t\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002&\"!/api/v1/connected_accounts:delete:\001*'
  _globals['_CONNECTEDACCOUNTSERVICE'].methods_by_name['GetMagicLinkForConnectedAccount']._loaded_options = None
  _globals['_CONNECTEDACCOUNTSERVICE'].methods_by_name['GetMagicLinkForConnectedAccount']._serialized_options = b'\222Ad\n\rAppConnectors\022(Get a magic link for a connected account\032)Get a magic link for a connected account.\202\265\030\002\030t\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002*\"%/api/v1/connected_accounts/magic_link:\001*'
  _globals['_CONNECTEDACCOUNTSERVICE'].methods_by_name['GetConnectedAccountAuth']._loaded_options = None
  _globals['_CONNECTEDACCOUNTSERVICE'].methods_by_name['GetConnectedAccountAuth']._serialized_options = b'\222A`\n\rAppConnectors\022#Get connected account by identifier\032*Get a connected account by its identifier.\202\265\030\002\030t\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002!\022\037/api/v1/connected_accounts/auth'
  _globals['_CONNECTEDACCOUNTSERVICE'].methods_by_name['GetMagicLinkForConnectedAccountWithRedirect']._loaded_options = None
  _globals['_CONNECTEDACCOUNTSERVICE'].methods_by_name['GetMagicLinkForConnectedAccountWithRedirect']._serialized_options = b'\222Ad\n\rAppConnectors\022(Get a magic link for a connected account\032)Get a magic link for a connected account.\202\265\030\002\030\001\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\0023\"./api/v1/connected_accounts/magic_link/redirect:\001*'
  _globals['_CONNECTORSTATUS']._serialized_start=10052
  _globals['_CONNECTORSTATUS']._serialized_end=10147
  _globals['_CONNECTORTYPE']._serialized_start=10150
  _globals['_CONNECTORTYPE']._serialized_end=10279
  _globals['_LISTCONNECTEDACCOUNTSREQUEST']._serialized_start=359
  _globals['_LISTCONNECTEDACCOUNTSREQUEST']._serialized_end=1249
  _globals['_LISTCONNECTEDACCOUNTSRESPONSE']._serialized_start=1252
  _globals['_LISTCONNECTEDACCOUNTSRESPONSE']._serialized_end=1719
  _globals['_SEARCHCONNECTEDACCOUNTSREQUEST']._serialized_start=1722
  _globals['_SEARCHCONNECTEDACCOUNTSREQUEST']._serialized_end=2479
  _globals['_SEARCHCONNECTEDACCOUNTSRESPONSE']._serialized_start=2482
  _globals['_SEARCHCONNECTEDACCOUNTSRESPONSE']._serialized_end=2956
  _globals['_CREATECONNECTEDACCOUNTREQUEST']._serialized_start=2959
  _globals['_CREATECONNECTEDACCOUNTREQUEST']._serialized_end=3783
  _globals['_CREATECONNECTEDACCOUNTRESPONSE']._serialized_start=3786
  _globals['_CREATECONNECTEDACCOUNTRESPONSE']._serialized_end=3961
  _globals['_UPDATECONNECTEDACCOUNTREQUEST']._serialized_start=3964
  _globals['_UPDATECONNECTEDACCOUNTREQUEST']._serialized_end=4882
  _globals['_UPDATECONNECTEDACCOUNTRESPONSE']._serialized_start=4885
  _globals['_UPDATECONNECTEDACCOUNTRESPONSE']._serialized_end=5060
  _globals['_DELETECONNECTEDACCOUNTREQUEST']._serialized_start=5063
  _globals['_DELETECONNECTEDACCOUNTREQUEST']._serialized_end=5679
  _globals['_DELETECONNECTEDACCOUNTRESPONSE']._serialized_start=5681
  _globals['_DELETECONNECTEDACCOUNTRESPONSE']._serialized_end=5713
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREQUEST']._serialized_start=5716
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREQUEST']._serialized_end=6313
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREDIRECTREQUEST']._serialized_start=6316
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREDIRECTREQUEST']._serialized_end=6469
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTRESPONSE']._serialized_start=6472
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTRESPONSE']._serialized_end=6756
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREDIRECTRESPONSE']._serialized_start=6759
  _globals['_GETMAGICLINKFORCONNECTEDACCOUNTREDIRECTRESPONSE']._serialized_end=7064
  _globals['_GETCONNECTEDACCOUNTBYIDENTIFIERREQUEST']._serialized_start=7067
  _globals['_GETCONNECTEDACCOUNTBYIDENTIFIERREQUEST']._serialized_end=7664
  _globals['_GETCONNECTEDACCOUNTBYIDENTIFIERRESPONSE']._serialized_start=7667
  _globals['_GETCONNECTEDACCOUNTBYIDENTIFIERRESPONSE']._serialized_end=7803
  _globals['_CONNECTEDACCOUNT']._serialized_start=7806
  _globals['_CONNECTEDACCOUNT']._serialized_end=8573
  _globals['_CREATECONNECTEDACCOUNT']._serialized_start=8576
  _globals['_CREATECONNECTEDACCOUNT']._serialized_end=8829
  _globals['_UPDATECONNECTEDACCOUNT']._serialized_start=8832
  _globals['_UPDATECONNECTEDACCOUNT']._serialized_end=9079
  _globals['_CONNECTEDACCOUNTFORLIST']._serialized_start=9082
  _globals['_CONNECTEDACCOUNTFORLIST']._serialized_end=9681
  _globals['_AUTHORIZATIONDETAILS']._serialized_start=9684
  _globals['_AUTHORIZATIONDETAILS']._serialized_end=9875
  _globals['_OAUTHTOKEN']._serialized_start=9877
  _globals['_OAUTHTOKEN']._serialized_end=9985
  _globals['_STATICAUTH']._serialized_start=9987
  _globals['_STATICAUTH']._serialized_end=10050
  _globals['_CONNECTEDACCOUNTSERVICE']._serialized_start=10282
  _globals['_CONNECTEDACCOUNTSERVICE']._serialized_end=13018
# @@protoc_insertion_point(module_scope)
