# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: scalekit/v1/mcp/mcp.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2
from scalekit.v1.options import options_pb2 as scalekit_dot_v1_dot_options_dot_options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19scalekit/v1/mcp/mcp.proto\x12\x0fscalekit.v1.mcp\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1bgoogle/api/visibility.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\x1a!scalekit/v1/options/options.proto\"q\n\x10\x43reateMcpRequest\x12]\n\x03mcp\x18\x01 \x01(\x0b\x32\x14.scalekit.v1.mcp.McpB5\x92\x41,2*MCP tool configuration to create or update\xbaH\x03\xc8\x01\x01R\x03mcp\"X\n\x11\x43reateMcpResponse\x12\x43\n\x03mcp\x18\x01 \x01(\x0b\x32\x14.scalekit.v1.mcp.McpB\x1b\x92\x41\x18\x32\x16The MCP server detailsR\x03mcp\"\x93\x03\n\x03Mcp\x12\x38\n\x02id\x18\x01 \x01(\tB(\x92\x41\"2\x15Unique ID of the toolJ\t\"res_123\"\xe0\x41\x03R\x02id\x12x\n\rtool_mappings\x18\x02 \x03(\x0b\x32\x1c.scalekit.v1.mcp.ToolMappingB5\x92\x41\'2\x1bProvider name (e.g. GOOGLE)J\x08\"GOOGLE\"\xbaH\x08\x92\x01\x02\x08\x01\xc8\x01\x01R\x0ctoolMappings\x12\x84\x01\n\x1c\x63onnected_account_identifier\x18\x03 \x01(\tBB\x92\x41\x35\x32$Identifier for the connected accountJ\r\"account_123\"\xbaH\x07r\x02\x10\x01\xc8\x01\x01R\x1a\x63onnectedAccountIdentifier\x12Q\n\x03url\x18\x04 \x01(\tB?\x92\x41\x39\x32\x15Unique ID of the toolJ \"https://example.com/mcp/v1/abc\"\xe0\x41\x03R\x03url\"\x96\x02\n\x0bToolMapping\x12\\\n\ntool_names\x18\x01 \x03(\tB=\x92\x41:2\x12List of tool namesJ$[\"GMAIL_FETCH_MAILS\", \"LIST_DRAFTS\"]R\ttoolNames\x12\\\n\x0f\x63onnection_name\x18\x02 \x01(\tB3\x92\x41*2\x1c\x43onnection name for the toolJ\n\"MY-GMAIL\"\xbaH\x03\xc8\x01\x01R\x0e\x63onnectionName\x12K\n\x06status\x18\x03 \x01(\tB3\x92\x41-2!Authentication status of the toolJ\x08\"ACTIVE\"\xe0\x41\x03R\x06status\"L\n\rGetMcpRequest\x12;\n\x06mcp_id\x18\x01 \x01(\tB$\x92\x41\x1b\x32\x19ID of the MCP to retrieve\xbaH\x03\xc8\x01\x01R\x05mcpId\"N\n\x0eGetMcpResponse\x12<\n\x03mcp\x18\x01 \x01(\x0b\x32\x14.scalekit.v1.mcp.McpB\x14\x92\x41\x11\x32\x0fThe MCP detailsR\x03mcp\"\x84\x02\n\x0eListMcpRequest\x12>\n\x06\x66ilter\x18\x01 \x01(\x0b\x32&.scalekit.v1.mcp.ListMcpRequest.FilterR\x06\x66ilter\x1a\xb1\x01\n\x06\x46ilter\x12m\n\x1c\x63onnected_account_identifier\x18\x01 \x01(\tB+\x92\x41(2&Filter by connected account identifierR\x1a\x63onnectedAccountIdentifier\x12\x38\n\nlink_token\x18\x02 \x01(\tB\x19\x92\x41\x16\x32\x14\x46ilter by link tokenR\tlinkToken\"N\n\x0fListMcpResponse\x12;\n\x04mcps\x18\x01 \x03(\x0b\x32\x14.scalekit.v1.mcp.McpB\x11\x92\x41\x0e\x32\x0cList of MCPsR\x04mcps\"M\n\x10\x44\x65leteMcpRequest\x12\x39\n\x06mcp_id\x18\x01 \x01(\tB\"\x92\x41\x19\x32\x17ID of the MCP to delete\xbaH\x03\xc8\x01\x01R\x05mcpId\"\x13\n\x11\x44\x65leteMcpResponse2\xaf\x07\n\nMcpService\x12\xa8\x02\n\tCreateMcp\x12!.scalekit.v1.mcp.CreateMcpRequest\x1a\".scalekit.v1.mcp.CreateMcpResponse\"\xd3\x01\x92\x41\xb1\x01\n\x03mcp\x12\x41\x43reates or returns the existing MCP with the given configuration.\x1agCreates a new MCP for the configuration. If same configuration exists, it will return the existing MCP.\x82\xb5\x18\x02\x18t\x82\xd3\xe4\x93\x02\x12\"\x0b/api/v1/mcp:\x03mcp\x12\xbe\x01\n\x06GetMcp\x12\x1e.scalekit.v1.mcp.GetMcpRequest\x1a\x1f.scalekit.v1.mcp.GetMcpResponse\"s\x92\x41N\n\x03mcp\x12\x1aGet an existing MCP by ID.\x1a+Returns the existing MCP with the given ID.\x82\xb5\x18\x02\x18t\x82\xd3\xe4\x93\x02\x16\x12\x14/api/v1/mcp/{mcp_id}\x12\xf9\x01\n\x07ListMcp\x12\x1f.scalekit.v1.mcp.ListMcpRequest\x1a .scalekit.v1.mcp.ListMcpResponse\"\xaa\x01\x92\x41\x8d\x01\n\x03mcp\x12 List MCPs with optional filters.\x1a\x64Returns a list of existing MCPs, optionally filtered by connected_account_identifier and link_token.\x82\xb5\x18\x02\x18t\x82\xd3\xe4\x93\x02\r\x12\x0b/api/v1/mcp\x12\xb8\x01\n\tDeleteMcp\x12!.scalekit.v1.mcp.DeleteMcpRequest\x1a\".scalekit.v1.mcp.DeleteMcpResponse\"d\x92\x41?\n\x03mcp\x12\x14\x44\x65lete an MCP by ID.\x1a\"Deletes the MCP with the given ID.\x82\xb5\x18\x02\x18t\x82\xd3\xe4\x93\x02\x16*\x14/api/v1/mcp/{mcp_id}B/Z-github.com/scalekit-inc/scalekit/pkg/grpc/mcpb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'scalekit.v1.mcp.mcp_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/scalekit-inc/scalekit/pkg/grpc/mcp'
  _globals['_CREATEMCPREQUEST'].fields_by_name['mcp']._loaded_options = None
  _globals['_CREATEMCPREQUEST'].fields_by_name['mcp']._serialized_options = b'\222A,2*MCP tool configuration to create or update\272H\003\310\001\001'
  _globals['_CREATEMCPRESPONSE'].fields_by_name['mcp']._loaded_options = None
  _globals['_CREATEMCPRESPONSE'].fields_by_name['mcp']._serialized_options = b'\222A\0302\026The MCP server details'
  _globals['_MCP'].fields_by_name['id']._loaded_options = None
  _globals['_MCP'].fields_by_name['id']._serialized_options = b'\222A\"2\025Unique ID of the toolJ\t\"res_123\"\340A\003'
  _globals['_MCP'].fields_by_name['tool_mappings']._loaded_options = None
  _globals['_MCP'].fields_by_name['tool_mappings']._serialized_options = b'\222A\'2\033Provider name (e.g. GOOGLE)J\010\"GOOGLE\"\272H\010\222\001\002\010\001\310\001\001'
  _globals['_MCP'].fields_by_name['connected_account_identifier']._loaded_options = None
  _globals['_MCP'].fields_by_name['connected_account_identifier']._serialized_options = b'\222A52$Identifier for the connected accountJ\r\"account_123\"\272H\007r\002\020\001\310\001\001'
  _globals['_MCP'].fields_by_name['url']._loaded_options = None
  _globals['_MCP'].fields_by_name['url']._serialized_options = b'\222A92\025Unique ID of the toolJ \"https://example.com/mcp/v1/abc\"\340A\003'
  _globals['_TOOLMAPPING'].fields_by_name['tool_names']._loaded_options = None
  _globals['_TOOLMAPPING'].fields_by_name['tool_names']._serialized_options = b'\222A:2\022List of tool namesJ$[\"GMAIL_FETCH_MAILS\", \"LIST_DRAFTS\"]'
  _globals['_TOOLMAPPING'].fields_by_name['connection_name']._loaded_options = None
  _globals['_TOOLMAPPING'].fields_by_name['connection_name']._serialized_options = b'\222A*2\034Connection name for the toolJ\n\"MY-GMAIL\"\272H\003\310\001\001'
  _globals['_TOOLMAPPING'].fields_by_name['status']._loaded_options = None
  _globals['_TOOLMAPPING'].fields_by_name['status']._serialized_options = b'\222A-2!Authentication status of the toolJ\010\"ACTIVE\"\340A\003'
  _globals['_GETMCPREQUEST'].fields_by_name['mcp_id']._loaded_options = None
  _globals['_GETMCPREQUEST'].fields_by_name['mcp_id']._serialized_options = b'\222A\0332\031ID of the MCP to retrieve\272H\003\310\001\001'
  _globals['_GETMCPRESPONSE'].fields_by_name['mcp']._loaded_options = None
  _globals['_GETMCPRESPONSE'].fields_by_name['mcp']._serialized_options = b'\222A\0212\017The MCP details'
  _globals['_LISTMCPREQUEST_FILTER'].fields_by_name['connected_account_identifier']._loaded_options = None
  _globals['_LISTMCPREQUEST_FILTER'].fields_by_name['connected_account_identifier']._serialized_options = b'\222A(2&Filter by connected account identifier'
  _globals['_LISTMCPREQUEST_FILTER'].fields_by_name['link_token']._loaded_options = None
  _globals['_LISTMCPREQUEST_FILTER'].fields_by_name['link_token']._serialized_options = b'\222A\0262\024Filter by link token'
  _globals['_LISTMCPRESPONSE'].fields_by_name['mcps']._loaded_options = None
  _globals['_LISTMCPRESPONSE'].fields_by_name['mcps']._serialized_options = b'\222A\0162\014List of MCPs'
  _globals['_DELETEMCPREQUEST'].fields_by_name['mcp_id']._loaded_options = None
  _globals['_DELETEMCPREQUEST'].fields_by_name['mcp_id']._serialized_options = b'\222A\0312\027ID of the MCP to delete\272H\003\310\001\001'
  _globals['_MCPSERVICE'].methods_by_name['CreateMcp']._loaded_options = None
  _globals['_MCPSERVICE'].methods_by_name['CreateMcp']._serialized_options = b'\222A\261\001\n\003mcp\022ACreates or returns the existing MCP with the given configuration.\032gCreates a new MCP for the configuration. If same configuration exists, it will return the existing MCP.\202\265\030\002\030t\202\323\344\223\002\022\"\013/api/v1/mcp:\003mcp'
  _globals['_MCPSERVICE'].methods_by_name['GetMcp']._loaded_options = None
  _globals['_MCPSERVICE'].methods_by_name['GetMcp']._serialized_options = b'\222AN\n\003mcp\022\032Get an existing MCP by ID.\032+Returns the existing MCP with the given ID.\202\265\030\002\030t\202\323\344\223\002\026\022\024/api/v1/mcp/{mcp_id}'
  _globals['_MCPSERVICE'].methods_by_name['ListMcp']._loaded_options = None
  _globals['_MCPSERVICE'].methods_by_name['ListMcp']._serialized_options = b'\222A\215\001\n\003mcp\022 List MCPs with optional filters.\032dReturns a list of existing MCPs, optionally filtered by connected_account_identifier and link_token.\202\265\030\002\030t\202\323\344\223\002\r\022\013/api/v1/mcp'
  _globals['_MCPSERVICE'].methods_by_name['DeleteMcp']._loaded_options = None
  _globals['_MCPSERVICE'].methods_by_name['DeleteMcp']._serialized_options = b'\222A?\n\003mcp\022\024Delete an MCP by ID.\032\"Deletes the MCP with the given ID.\202\265\030\002\030t\202\323\344\223\002\026*\024/api/v1/mcp/{mcp_id}'
  _globals['_CREATEMCPREQUEST']._serialized_start=374
  _globals['_CREATEMCPREQUEST']._serialized_end=487
  _globals['_CREATEMCPRESPONSE']._serialized_start=489
  _globals['_CREATEMCPRESPONSE']._serialized_end=577
  _globals['_MCP']._serialized_start=580
  _globals['_MCP']._serialized_end=983
  _globals['_TOOLMAPPING']._serialized_start=986
  _globals['_TOOLMAPPING']._serialized_end=1264
  _globals['_GETMCPREQUEST']._serialized_start=1266
  _globals['_GETMCPREQUEST']._serialized_end=1342
  _globals['_GETMCPRESPONSE']._serialized_start=1344
  _globals['_GETMCPRESPONSE']._serialized_end=1422
  _globals['_LISTMCPREQUEST']._serialized_start=1425
  _globals['_LISTMCPREQUEST']._serialized_end=1685
  _globals['_LISTMCPREQUEST_FILTER']._serialized_start=1508
  _globals['_LISTMCPREQUEST_FILTER']._serialized_end=1685
  _globals['_LISTMCPRESPONSE']._serialized_start=1687
  _globals['_LISTMCPRESPONSE']._serialized_end=1765
  _globals['_DELETEMCPREQUEST']._serialized_start=1767
  _globals['_DELETEMCPREQUEST']._serialized_end=1844
  _globals['_DELETEMCPRESPONSE']._serialized_start=1846
  _globals['_DELETEMCPRESPONSE']._serialized_end=1865
  _globals['_MCPSERVICE']._serialized_start=1868
  _globals['_MCPSERVICE']._serialized_end=2811
# @@protoc_insertion_point(module_scope)
