# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: scalekit/v1/tools/tools.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2
from scalekit.v1.options import options_pb2 as scalekit_dot_v1_dot_options_dot_options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dscalekit/v1/tools/tools.proto\x12\x11scalekit.v1.tools\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1bgoogle/api/visibility.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\x1a!scalekit/v1/options/options.proto\"\x88\x01\n\x11\x43reateToolRequest\x12s\n\x04tool\x18\x01 \x01(\x0b\x32\x17.scalekit.v1.tools.ToolBF\x92\x41=2;Tool details including name, schema version, and definition\xbaH\x03\xc8\x01\x01R\x04tool\"c\n\x12\x43reateToolResponse\x12M\n\x04tool\x18\x01 \x01(\x0b\x32\x17.scalekit.v1.tools.ToolB \x92\x41\x1d\x32\x1b\x44\x65tails of the created toolR\x04tool\"\xf0\x05\n\x04Tool\x12\x38\n\x02id\x18\x01 \x01(\tB(\x92\x41\"2\x15Unique ID of the toolJ\t\"tol_123\"\xe0\x41\x03R\x02id\x12I\n\x08provider\x18\x02 \x01(\tB-\x92\x41\'2\x1bProvider name (e.g. GOOGLE)J\x08\"GOOGLE\"\xe0\x41\x03R\x08provider\x12\x87\x01\n\ndefinition\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructBN\x92\x41\x45\x32$Tool definition in structured formatJ\x1d{\"input\": {\"type\": \"object\"}}\xbaH\x03\xc8\x01\x01R\ndefinition\x12s\n\x08metadata\x18\x04 \x01(\x0b\x32\x17.google.protobuf.StructB>\x92\x41;2\"Additional metadata about the toolJ\x15{\"category\": \"email\"}R\x08metadata\x12X\n\x04tags\x18\x05 \x03(\tBD\x92\x41\x41\x32$Tags for categorization or filteringJ\x19[\"notification\", \"email\"]R\x04tags\x12\x83\x01\n\nis_default\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValueBH\x92\x41\x42\x32:Marks this tool as the default version for the combinationJ\x04true\xe0\x41\x03R\tisDefault\x12\x83\x01\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampBH\x92\x41\x42\x32(Timestamp when the tool was last updatedJ\x16\"2023-10-01T12:00:00Z\"\xe0\x41\x03R\tupdatedAt\"\xd3\x01\n\nScopedTool\x12+\n\x04tool\x18\x01 \x01(\x0b\x32\x17.scalekit.v1.tools.ToolR\x04tool\x12\x1e\n\nidentifier\x18\x02 \x01(\tR\nidentifier\x12x\n\x14\x63onnected_account_id\x18\x03 \x01(\tBF\x92\x41<20ID of the connected account for this scoped toolJ\x08\"ca_123\"\xbaH\x04r\x02\x18\x64R\x12\x63onnectedAccountId\"\xfe\x01\n\x10ListToolsRequest\x12[\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x19.scalekit.v1.tools.FilterB(\x92\x41%2#Filter parameters for listing toolsR\x06\x66ilter\x12\x1b\n\tpage_size\x18\x02 \x01(\rR\x08pageSize\x12p\n\npage_token\x18\x03 \x01(\tBQ\x92\x41N2.Token from a previous response for pagination.J\x1c\x65yJwYWdlIjoyLCJsaW1pdCI6MzB9R\tpageToken\"\x80\x03\n\x06\x46ilter\x12t\n\x07summary\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB>\x92\x41;23Return only tool names instead of full tool detailsJ\x04trueR\x07summary\x12I\n\x08provider\x18\x02 \x01(\tB-\x92\x41#2\x17\x46ilter by tool providerJ\x08\"GOOGLE\"\xbaH\x04r\x02\x18\x32R\x08provider\x12j\n\nidentifier\x18\x03 \x01(\tBJ\x92\x41@2&Filter by connected account identifierJ\x16\"app_google_workspace\"\xbaH\x04r\x02\x18\x64R\nidentifier\x12I\n\ttool_name\x18\x04 \x03(\tB,\x92\x41)2\x13\x46ilter by tool nameJ\x12\"gmail_send_email\"R\x08toolName\"\x9b\x04\n\x11ListToolsResponse\x12v\n\x0fnext_page_token\x18\x01 \x01(\tBN\x92\x41K2)Token for fetching the next page of toolsJ\x1e\"eyJwYWdlIjozLCJsaW1pdCI6MzB9\"R\rnextPageToken\x12Q\n\ntotal_size\x18\x02 \x01(\rB2\x92\x41/2(Total number of tools matching the queryJ\x03\x31\x30\x34R\ttotalSize\x12z\n\x0fprev_page_token\x18\x03 \x01(\tBR\x92\x41O2-Token for fetching the previous page of toolsJ\x1e\"eyJwYWdlIjoxLCJsaW1pdCI6MzB9\"R\rprevPageToken\x12^\n\ntool_names\x18\x04 \x03(\tB?\x92\x41<2$List of tool names (if summary=true)J\x14[\"gmail_send_email\"]R\ttoolNames\x12_\n\x05tools\x18\x05 \x03(\x0b\x32\x17.scalekit.v1.tools.ToolB0\x92\x41-2+List of tools (if summary=false or omitted)R\x05tools\"\xc9\x07\n\x12\x45xecuteToolRequest\x12Q\n\ttool_name\x18\x01 \x01(\tB4\x92\x41+2\x1bName of the tool to executeJ\x0c\"send_email\"\xbaH\x03\xc8\x01\x01R\x08toolName\x12\x7f\n\nidentifier\x18\x02 \x01(\tBZ\x92\x41W2=Identifier of the connected account to use for tool executionJ\x16\"app_google_workspace\"H\x00R\nidentifier\x88\x01\x01\x12\xb0\x01\n\x06params\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructB\x7f\x92\x41|23Free-flowing JSON parameters for the tool executionJE{\"to\": \"user@example.com\", \"subject\": \"Hello\", \"body\": \"Hello World\"}R\x06params\x12\x82\x01\n\x14\x63onnected_account_id\x18\x04 \x01(\tBK\x92\x41\x41\x32\x35ID of the connected account to use for tool executionJ\x08\"ca_123\"\xbaH\x04r\x02\x18\x64H\x01R\x12\x63onnectedAccountId\x88\x01\x01\x12z\n\tconnector\x18\x05 \x01(\tBW\x92\x41M27Name of the connected account to use for tool executionJ\x12\"Google Workspace\"\xbaH\x04r\x02\x18\x64H\x02R\tconnector\x88\x01\x01\x12u\n\x0forganization_id\x18\x06 \x01(\tBG\x92\x41=20ID of the organization to use for tool executionJ\t\"org_123\"\xbaH\x04r\x02\x18\x64H\x03R\x0eorganizationId\x88\x01\x01\x12^\n\x07user_id\x18\x07 \x01(\tB@\x92\x41\x36\x32(ID of the user to use for tool executionJ\n\"user_123\"\xbaH\x04r\x02\x18\x64H\x04R\x06userId\x88\x01\x01\x42\r\n\x0b_identifierB\x17\n\x15_connected_account_idB\x0c\n\n_connectorB\x12\n\x10_organization_idB\n\n\x08_user_id\"\xa3\x02\n\x13\x45xecuteToolResponse\x12\xac\x01\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x17.google.protobuf.StructB\x7f\x92\x41|23Free-flowing JSON parameters for the tool executionJE{\"to\": \"user@example.com\", \"subject\": \"Hello\", \"body\": \"Hello World\"}R\x04\x64\x61ta\x12]\n\x0c\x65xecution_id\x18\x02 \x01(\tB:\x92\x41\x37\x32(Unique identifier for the tool executionJ\x0b\"123456789\"R\x0b\x65xecutionId\"\xad\x02\n\x15SetToolDefaultRequest\x12\x61\n\x04name\x18\x01 \x01(\tBM\x92\x41/2\x19\x46ully qualified tool nameJ\x12\"gmail_send_email\"\xbaH\x18r\x13\x10\x01\x18\x64\x32\r^[a-z0-9_].*$\xc8\x01\x01R\x04name\x12W\n\x0eschema_version\x18\x02 \x01(\tB0\x92\x41!2\x1aSchema version of the toolJ\x03\"1\"\xbaH\tr\x04\x10\x01\x18\n\xc8\x01\x01R\rschemaVersion\x12X\n\x0ctool_version\x18\x03 \x01(\tB5\x92\x41&2\x1fTool version to mark as defaultJ\x03\"1\"\xbaH\tr\x04\x10\x01\x18\n\xc8\x01\x01R\x0btoolVersion\"j\n\x16SetToolDefaultResponse\x12P\n\x04tool\x18\x01 \x01(\x0b\x32\x17.scalekit.v1.tools.ToolB#\x92\x41 2\x1eThe tool now marked as defaultR\x04tool\"^\n\x11UpdateToolRequest\x12I\n\x04tool\x18\x01 \x01(\x0b\x32\x17.scalekit.v1.tools.ToolB\x1c\x92\x41\x13\x32\x11Updated tool data\xbaH\x03\xc8\x01\x01R\x04tool\"X\n\x12UpdateToolResponse\x12\x42\n\x04tool\x18\x01 \x01(\x0b\x32\x17.scalekit.v1.tools.ToolB\x15\x92\x41\x12\x32\x10The updated toolR\x04tool\"0\n\x11\x44\x65leteToolRequest\x12\x1b\n\x02id\x18\x01 \x01(\tB\x0b\xbaH\x08r\x06:\x04tol_R\x02id\"\x91\x03\n\x16ListScopedToolsRequest\x12z\n\nidentifier\x18\x01 \x01(\tBZ\x92\x41M23Identifier of the connected account to filter toolsJ\x16\"app_google_workspace\"\xbaH\x07r\x02\x18\x64\xc8\x01\x01R\nidentifier\x12l\n\x06\x66ilter\x18\x02 \x01(\x0b\x32#.scalekit.v1.tools.ScopedToolFilterB/\x92\x41,2*Filter parameters for listing scoped toolsR\x06\x66ilter\x12\x1b\n\tpage_size\x18\x03 \x01(\rR\x08pageSize\x12p\n\npage_token\x18\x04 \x01(\tBQ\x92\x41N2.Token from a previous response for pagination.J\x1c\x65yJwYWdlIjoyLCJsaW1pdCI6MzB9R\tpageToken\"\x95\x03\n\x17ListScopedToolsResponse\x12v\n\x0fnext_page_token\x18\x01 \x01(\tBN\x92\x41K2)Token for fetching the next page of toolsJ\x1e\"eyJwYWdlIjozLCJsaW1pdCI6MzB9\"R\rnextPageToken\x12Q\n\ntotal_size\x18\x02 \x01(\rB2\x92\x41/2(Total number of tools matching the queryJ\x03\x31\x30\x34R\ttotalSize\x12z\n\x0fprev_page_token\x18\x03 \x01(\tBR\x92\x41O2-Token for fetching the previous page of toolsJ\x1e\"eyJwYWdlIjoxLCJsaW1pdCI6MzB9\"R\rprevPageToken\x12\x33\n\x05tools\x18\x05 \x03(\x0b\x32\x1d.scalekit.v1.tools.ScopedToolR\x05tools\"z\n\x10ScopedToolFilter\x12\x1c\n\tproviders\x18\x01 \x03(\tR\tproviders\x12\x1d\n\ntool_names\x18\x02 \x03(\tR\ttoolNames\x12)\n\x10\x63onnection_names\x18\x03 \x03(\tR\x0f\x63onnectionNames2\xaa\r\n\x0bToolService\x12\xf2\x01\n\nCreateTool\x12$.scalekit.v1.tools.CreateToolRequest\x1a%.scalekit.v1.tools.CreateToolResponse\"\x96\x01\x92\x41\x63\n\x05Tools\x12\x11\x43reate a new tool\x1aGRegister a new tool with its schema, metadata, and other configuration.\x82\xb5\x18\x02\x18\x04\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02\x15\"\r/api/v1/tools:\x04tool\x12\xfa\x01\n\tListTools\x12#.scalekit.v1.tools.ListToolsRequest\x1a$.scalekit.v1.tools.ListToolsResponse\"\xa1\x01\x92\x41t\n\x05Tools\x12\nList tools\x1a_Fetch tools by provider, identifier, and connector. If `summary=true`, returns only tool names.\x82\xb5\x18\x02\x18t\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02\x0f\x12\r/api/v1/tools\x12\x9b\x01\n\x0fListScopedTools\x12).scalekit.v1.tools.ListScopedToolsRequest\x1a*.scalekit.v1.tools.ListScopedToolsResponse\"1\x82\xb5\x18\x02\x18\x04\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02\x16\x12\x14/api/v1/tools/scoped\x12\xac\x02\n\x0eSetToolDefault\x12(.scalekit.v1.tools.SetToolDefaultRequest\x1a).scalekit.v1.tools.SetToolDefaultResponse\"\xc4\x01\x92\x41\x87\x01\n\x05Tools\x12#Marks a tool as the default version\x1aYSet a specific tool (by name, schema version, tool version, and provider) as the default.\x82\xb5\x18\x02\x18\x04\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02\x1e\"\x19/api/v1/tools:set_default:\x01*\x12\xd8\x01\n\nUpdateTool\x12$.scalekit.v1.tools.UpdateToolRequest\x1a%.scalekit.v1.tools.UpdateToolResponse\"}\x92\x41J\n\x05Tools\x12\rUpdate a tool\x1a\x32Update an existing tool by provider and tool name.\x82\xb5\x18\x02\x18\x04\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02\x15\x1a\r/api/v1/tools:\x04tool\x12\xd9\x01\n\nDeleteTool\x12$.scalekit.v1.tools.DeleteToolRequest\x1a\x16.google.protobuf.Empty\"\x8c\x01\x92\x41Z\n\x05Tools\x12\rDelete a tool\x1a\x42\x44\x65lete a tool by name, schema version, tool version, and provider.\x82\xb5\x18\x02\x18\x04\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02\x14*\x12/api/v1/tools/{id}\x12\xa4\x02\n\x0b\x45xecuteTool\x12%.scalekit.v1.tools.ExecuteToolRequest\x1a&.scalekit.v1.tools.ExecuteToolResponse\"\xc5\x01\x92\x41\x8d\x01\n\rAppConnectors\x12(Execute a tool using a connected account\x1aRExecute a tool using the specified connected account with the provided parameters.\x82\xb5\x18\x02\x18t\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02\x19\"\x14/api/v1/execute_tool:\x01*B1Z/github.com/scalekit-inc/scalekit/pkg/grpc/toolsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'scalekit.v1.tools.tools_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/scalekit-inc/scalekit/pkg/grpc/tools'
  _globals['_CREATETOOLREQUEST'].fields_by_name['tool']._loaded_options = None
  _globals['_CREATETOOLREQUEST'].fields_by_name['tool']._serialized_options = b'\222A=2;Tool details including name, schema version, and definition\272H\003\310\001\001'
  _globals['_CREATETOOLRESPONSE'].fields_by_name['tool']._loaded_options = None
  _globals['_CREATETOOLRESPONSE'].fields_by_name['tool']._serialized_options = b'\222A\0352\033Details of the created tool'
  _globals['_TOOL'].fields_by_name['id']._loaded_options = None
  _globals['_TOOL'].fields_by_name['id']._serialized_options = b'\222A\"2\025Unique ID of the toolJ\t\"tol_123\"\340A\003'
  _globals['_TOOL'].fields_by_name['provider']._loaded_options = None
  _globals['_TOOL'].fields_by_name['provider']._serialized_options = b'\222A\'2\033Provider name (e.g. GOOGLE)J\010\"GOOGLE\"\340A\003'
  _globals['_TOOL'].fields_by_name['definition']._loaded_options = None
  _globals['_TOOL'].fields_by_name['definition']._serialized_options = b'\222AE2$Tool definition in structured formatJ\035{\"input\": {\"type\": \"object\"}}\272H\003\310\001\001'
  _globals['_TOOL'].fields_by_name['metadata']._loaded_options = None
  _globals['_TOOL'].fields_by_name['metadata']._serialized_options = b'\222A;2\"Additional metadata about the toolJ\025{\"category\": \"email\"}'
  _globals['_TOOL'].fields_by_name['tags']._loaded_options = None
  _globals['_TOOL'].fields_by_name['tags']._serialized_options = b'\222AA2$Tags for categorization or filteringJ\031[\"notification\", \"email\"]'
  _globals['_TOOL'].fields_by_name['is_default']._loaded_options = None
  _globals['_TOOL'].fields_by_name['is_default']._serialized_options = b'\222AB2:Marks this tool as the default version for the combinationJ\004true\340A\003'
  _globals['_TOOL'].fields_by_name['updated_at']._loaded_options = None
  _globals['_TOOL'].fields_by_name['updated_at']._serialized_options = b'\222AB2(Timestamp when the tool was last updatedJ\026\"2023-10-01T12:00:00Z\"\340A\003'
  _globals['_SCOPEDTOOL'].fields_by_name['connected_account_id']._loaded_options = None
  _globals['_SCOPEDTOOL'].fields_by_name['connected_account_id']._serialized_options = b'\222A<20ID of the connected account for this scoped toolJ\010\"ca_123\"\272H\004r\002\030d'
  _globals['_LISTTOOLSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTTOOLSREQUEST'].fields_by_name['filter']._serialized_options = b'\222A%2#Filter parameters for listing tools'
  _globals['_LISTTOOLSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTTOOLSREQUEST'].fields_by_name['page_token']._serialized_options = b'\222AN2.Token from a previous response for pagination.J\034eyJwYWdlIjoyLCJsaW1pdCI6MzB9'
  _globals['_FILTER'].fields_by_name['summary']._loaded_options = None
  _globals['_FILTER'].fields_by_name['summary']._serialized_options = b'\222A;23Return only tool names instead of full tool detailsJ\004true'
  _globals['_FILTER'].fields_by_name['provider']._loaded_options = None
  _globals['_FILTER'].fields_by_name['provider']._serialized_options = b'\222A#2\027Filter by tool providerJ\010\"GOOGLE\"\272H\004r\002\0302'
  _globals['_FILTER'].fields_by_name['identifier']._loaded_options = None
  _globals['_FILTER'].fields_by_name['identifier']._serialized_options = b'\222A@2&Filter by connected account identifierJ\026\"app_google_workspace\"\272H\004r\002\030d'
  _globals['_FILTER'].fields_by_name['tool_name']._loaded_options = None
  _globals['_FILTER'].fields_by_name['tool_name']._serialized_options = b'\222A)2\023Filter by tool nameJ\022\"gmail_send_email\"'
  _globals['_LISTTOOLSRESPONSE'].fields_by_name['next_page_token']._loaded_options = None
  _globals['_LISTTOOLSRESPONSE'].fields_by_name['next_page_token']._serialized_options = b'\222AK2)Token for fetching the next page of toolsJ\036\"eyJwYWdlIjozLCJsaW1pdCI6MzB9\"'
  _globals['_LISTTOOLSRESPONSE'].fields_by_name['total_size']._loaded_options = None
  _globals['_LISTTOOLSRESPONSE'].fields_by_name['total_size']._serialized_options = b'\222A/2(Total number of tools matching the queryJ\003104'
  _globals['_LISTTOOLSRESPONSE'].fields_by_name['prev_page_token']._loaded_options = None
  _globals['_LISTTOOLSRESPONSE'].fields_by_name['prev_page_token']._serialized_options = b'\222AO2-Token for fetching the previous page of toolsJ\036\"eyJwYWdlIjoxLCJsaW1pdCI6MzB9\"'
  _globals['_LISTTOOLSRESPONSE'].fields_by_name['tool_names']._loaded_options = None
  _globals['_LISTTOOLSRESPONSE'].fields_by_name['tool_names']._serialized_options = b'\222A<2$List of tool names (if summary=true)J\024[\"gmail_send_email\"]'
  _globals['_LISTTOOLSRESPONSE'].fields_by_name['tools']._loaded_options = None
  _globals['_LISTTOOLSRESPONSE'].fields_by_name['tools']._serialized_options = b'\222A-2+List of tools (if summary=false or omitted)'
  _globals['_EXECUTETOOLREQUEST'].fields_by_name['tool_name']._loaded_options = None
  _globals['_EXECUTETOOLREQUEST'].fields_by_name['tool_name']._serialized_options = b'\222A+2\033Name of the tool to executeJ\014\"send_email\"\272H\003\310\001\001'
  _globals['_EXECUTETOOLREQUEST'].fields_by_name['identifier']._loaded_options = None
  _globals['_EXECUTETOOLREQUEST'].fields_by_name['identifier']._serialized_options = b'\222AW2=Identifier of the connected account to use for tool executionJ\026\"app_google_workspace\"'
  _globals['_EXECUTETOOLREQUEST'].fields_by_name['params']._loaded_options = None
  _globals['_EXECUTETOOLREQUEST'].fields_by_name['params']._serialized_options = b'\222A|23Free-flowing JSON parameters for the tool executionJE{\"to\": \"user@example.com\", \"subject\": \"Hello\", \"body\": \"Hello World\"}'
  _globals['_EXECUTETOOLREQUEST'].fields_by_name['connected_account_id']._loaded_options = None
  _globals['_EXECUTETOOLREQUEST'].fields_by_name['connected_account_id']._serialized_options = b'\222AA25ID of the connected account to use for tool executionJ\010\"ca_123\"\272H\004r\002\030d'
  _globals['_EXECUTETOOLREQUEST'].fields_by_name['connector']._loaded_options = None
  _globals['_EXECUTETOOLREQUEST'].fields_by_name['connector']._serialized_options = b'\222AM27Name of the connected account to use for tool executionJ\022\"Google Workspace\"\272H\004r\002\030d'
  _globals['_EXECUTETOOLREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_EXECUTETOOLREQUEST'].fields_by_name['organization_id']._serialized_options = b'\222A=20ID of the organization to use for tool executionJ\t\"org_123\"\272H\004r\002\030d'
  _globals['_EXECUTETOOLREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_EXECUTETOOLREQUEST'].fields_by_name['user_id']._serialized_options = b'\222A62(ID of the user to use for tool executionJ\n\"user_123\"\272H\004r\002\030d'
  _globals['_EXECUTETOOLRESPONSE'].fields_by_name['data']._loaded_options = None
  _globals['_EXECUTETOOLRESPONSE'].fields_by_name['data']._serialized_options = b'\222A|23Free-flowing JSON parameters for the tool executionJE{\"to\": \"user@example.com\", \"subject\": \"Hello\", \"body\": \"Hello World\"}'
  _globals['_EXECUTETOOLRESPONSE'].fields_by_name['execution_id']._loaded_options = None
  _globals['_EXECUTETOOLRESPONSE'].fields_by_name['execution_id']._serialized_options = b'\222A72(Unique identifier for the tool executionJ\013\"123456789\"'
  _globals['_SETTOOLDEFAULTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_SETTOOLDEFAULTREQUEST'].fields_by_name['name']._serialized_options = b'\222A/2\031Fully qualified tool nameJ\022\"gmail_send_email\"\272H\030r\023\020\001\030d2\r^[a-z0-9_].*$\310\001\001'
  _globals['_SETTOOLDEFAULTREQUEST'].fields_by_name['schema_version']._loaded_options = None
  _globals['_SETTOOLDEFAULTREQUEST'].fields_by_name['schema_version']._serialized_options = b'\222A!2\032Schema version of the toolJ\003\"1\"\272H\tr\004\020\001\030\n\310\001\001'
  _globals['_SETTOOLDEFAULTREQUEST'].fields_by_name['tool_version']._loaded_options = None
  _globals['_SETTOOLDEFAULTREQUEST'].fields_by_name['tool_version']._serialized_options = b'\222A&2\037Tool version to mark as defaultJ\003\"1\"\272H\tr\004\020\001\030\n\310\001\001'
  _globals['_SETTOOLDEFAULTRESPONSE'].fields_by_name['tool']._loaded_options = None
  _globals['_SETTOOLDEFAULTRESPONSE'].fields_by_name['tool']._serialized_options = b'\222A 2\036The tool now marked as default'
  _globals['_UPDATETOOLREQUEST'].fields_by_name['tool']._loaded_options = None
  _globals['_UPDATETOOLREQUEST'].fields_by_name['tool']._serialized_options = b'\222A\0232\021Updated tool data\272H\003\310\001\001'
  _globals['_UPDATETOOLRESPONSE'].fields_by_name['tool']._loaded_options = None
  _globals['_UPDATETOOLRESPONSE'].fields_by_name['tool']._serialized_options = b'\222A\0222\020The updated tool'
  _globals['_DELETETOOLREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_DELETETOOLREQUEST'].fields_by_name['id']._serialized_options = b'\272H\010r\006:\004tol_'
  _globals['_LISTSCOPEDTOOLSREQUEST'].fields_by_name['identifier']._loaded_options = None
  _globals['_LISTSCOPEDTOOLSREQUEST'].fields_by_name['identifier']._serialized_options = b'\222AM23Identifier of the connected account to filter toolsJ\026\"app_google_workspace\"\272H\007r\002\030d\310\001\001'
  _globals['_LISTSCOPEDTOOLSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTSCOPEDTOOLSREQUEST'].fields_by_name['filter']._serialized_options = b'\222A,2*Filter parameters for listing scoped tools'
  _globals['_LISTSCOPEDTOOLSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTSCOPEDTOOLSREQUEST'].fields_by_name['page_token']._serialized_options = b'\222AN2.Token from a previous response for pagination.J\034eyJwYWdlIjoyLCJsaW1pdCI6MzB9'
  _globals['_LISTSCOPEDTOOLSRESPONSE'].fields_by_name['next_page_token']._loaded_options = None
  _globals['_LISTSCOPEDTOOLSRESPONSE'].fields_by_name['next_page_token']._serialized_options = b'\222AK2)Token for fetching the next page of toolsJ\036\"eyJwYWdlIjozLCJsaW1pdCI6MzB9\"'
  _globals['_LISTSCOPEDTOOLSRESPONSE'].fields_by_name['total_size']._loaded_options = None
  _globals['_LISTSCOPEDTOOLSRESPONSE'].fields_by_name['total_size']._serialized_options = b'\222A/2(Total number of tools matching the queryJ\003104'
  _globals['_LISTSCOPEDTOOLSRESPONSE'].fields_by_name['prev_page_token']._loaded_options = None
  _globals['_LISTSCOPEDTOOLSRESPONSE'].fields_by_name['prev_page_token']._serialized_options = b'\222AO2-Token for fetching the previous page of toolsJ\036\"eyJwYWdlIjoxLCJsaW1pdCI6MzB9\"'
  _globals['_TOOLSERVICE'].methods_by_name['CreateTool']._loaded_options = None
  _globals['_TOOLSERVICE'].methods_by_name['CreateTool']._serialized_options = b'\222Ac\n\005Tools\022\021Create a new tool\032GRegister a new tool with its schema, metadata, and other configuration.\202\265\030\002\030\004\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002\025\"\r/api/v1/tools:\004tool'
  _globals['_TOOLSERVICE'].methods_by_name['ListTools']._loaded_options = None
  _globals['_TOOLSERVICE'].methods_by_name['ListTools']._serialized_options = b'\222At\n\005Tools\022\nList tools\032_Fetch tools by provider, identifier, and connector. If `summary=true`, returns only tool names.\202\265\030\002\030t\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002\017\022\r/api/v1/tools'
  _globals['_TOOLSERVICE'].methods_by_name['ListScopedTools']._loaded_options = None
  _globals['_TOOLSERVICE'].methods_by_name['ListScopedTools']._serialized_options = b'\202\265\030\002\030\004\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002\026\022\024/api/v1/tools/scoped'
  _globals['_TOOLSERVICE'].methods_by_name['SetToolDefault']._loaded_options = None
  _globals['_TOOLSERVICE'].methods_by_name['SetToolDefault']._serialized_options = b'\222A\207\001\n\005Tools\022#Marks a tool as the default version\032YSet a specific tool (by name, schema version, tool version, and provider) as the default.\202\265\030\002\030\004\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002\036\"\031/api/v1/tools:set_default:\001*'
  _globals['_TOOLSERVICE'].methods_by_name['UpdateTool']._loaded_options = None
  _globals['_TOOLSERVICE'].methods_by_name['UpdateTool']._serialized_options = b'\222AJ\n\005Tools\022\rUpdate a tool\0322Update an existing tool by provider and tool name.\202\265\030\002\030\004\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002\025\032\r/api/v1/tools:\004tool'
  _globals['_TOOLSERVICE'].methods_by_name['DeleteTool']._loaded_options = None
  _globals['_TOOLSERVICE'].methods_by_name['DeleteTool']._serialized_options = b'\222AZ\n\005Tools\022\rDelete a tool\032BDelete a tool by name, schema version, tool version, and provider.\202\265\030\002\030\004\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002\024*\022/api/v1/tools/{id}'
  _globals['_TOOLSERVICE'].methods_by_name['ExecuteTool']._loaded_options = None
  _globals['_TOOLSERVICE'].methods_by_name['ExecuteTool']._serialized_options = b'\222A\215\001\n\rAppConnectors\022(Execute a tool using a connected account\032RExecute a tool using the specified connected account with the provided parameters.\202\265\030\002\030t\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002\031\"\024/api/v1/execute_tool:\001*'
  _globals['_CREATETOOLREQUEST']._serialized_start=381
  _globals['_CREATETOOLREQUEST']._serialized_end=517
  _globals['_CREATETOOLRESPONSE']._serialized_start=519
  _globals['_CREATETOOLRESPONSE']._serialized_end=618
  _globals['_TOOL']._serialized_start=621
  _globals['_TOOL']._serialized_end=1373
  _globals['_SCOPEDTOOL']._serialized_start=1376
  _globals['_SCOPEDTOOL']._serialized_end=1587
  _globals['_LISTTOOLSREQUEST']._serialized_start=1590
  _globals['_LISTTOOLSREQUEST']._serialized_end=1844
  _globals['_FILTER']._serialized_start=1847
  _globals['_FILTER']._serialized_end=2231
  _globals['_LISTTOOLSRESPONSE']._serialized_start=2234
  _globals['_LISTTOOLSRESPONSE']._serialized_end=2773
  _globals['_EXECUTETOOLREQUEST']._serialized_start=2776
  _globals['_EXECUTETOOLREQUEST']._serialized_end=3745
  _globals['_EXECUTETOOLRESPONSE']._serialized_start=3748
  _globals['_EXECUTETOOLRESPONSE']._serialized_end=4039
  _globals['_SETTOOLDEFAULTREQUEST']._serialized_start=4042
  _globals['_SETTOOLDEFAULTREQUEST']._serialized_end=4343
  _globals['_SETTOOLDEFAULTRESPONSE']._serialized_start=4345
  _globals['_SETTOOLDEFAULTRESPONSE']._serialized_end=4451
  _globals['_UPDATETOOLREQUEST']._serialized_start=4453
  _globals['_UPDATETOOLREQUEST']._serialized_end=4547
  _globals['_UPDATETOOLRESPONSE']._serialized_start=4549
  _globals['_UPDATETOOLRESPONSE']._serialized_end=4637
  _globals['_DELETETOOLREQUEST']._serialized_start=4639
  _globals['_DELETETOOLREQUEST']._serialized_end=4687
  _globals['_LISTSCOPEDTOOLSREQUEST']._serialized_start=4690
  _globals['_LISTSCOPEDTOOLSREQUEST']._serialized_end=5091
  _globals['_LISTSCOPEDTOOLSRESPONSE']._serialized_start=5094
  _globals['_LISTSCOPEDTOOLSRESPONSE']._serialized_end=5499
  _globals['_SCOPEDTOOLFILTER']._serialized_start=5501
  _globals['_SCOPEDTOOLFILTER']._serialized_end=5623
  _globals['_TOOLSERVICE']._serialized_start=5626
  _globals['_TOOLSERVICE']._serialized_end=7332
# @@protoc_insertion_point(module_scope)
