# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: scalekit/v1/user_attributes/user_attributes.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from scalekit.v1.commons import commons_pb2 as scalekit_dot_v1_dot_commons_dot_commons__pb2
from scalekit.v1.options import options_pb2 as scalekit_dot_v1_dot_options_dot_options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1scalekit/v1/user_attributes/user_attributes.proto\x12\x1bscalekit.v1.user_attributes\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a!scalekit/v1/commons/commons.proto\x1a!scalekit/v1/options/options.proto\"\xc3\x04\n\rUserAttribute\x12\x36\n\x03key\x18\x01 \x01(\tB$\xbaH!r\x1f\x10\x03\x18\x19\x32\x19^[a-zA-Z][a-zA-Z0-9\\-_]+$R\x03key\x12\x18\n\x07\x65nabled\x18\x02 \x01(\x08R\x07\x65nabled\x12\x1a\n\x08required\x18\x03 \x01(\x08R\x08required\x12 \n\x05label\x18\x04 \x01(\tB\n\xbaH\x07r\x05\x10\x03\x18\xfa\x01R\x05label\x12Y\n\x08\x64\x61tatype\x18\x05 \x01(\x0e\x32\x32.scalekit.v1.user_attributes.UserAttributeDatatypeB\t\xbaH\x06\x82\x01\x03\"\x01\x00R\x08\x64\x61tatype\x12S\n\x08\x63\x61tegory\x18\x06 \x01(\x0e\x32\x32.scalekit.v1.user_attributes.UserAttributeCategoryB\x03\xe0\x41\x03R\x08\x63\x61tegory\x12^\n\x11sso_addition_info\x18\x07 \x01(\x0b\x32\x30.scalekit.v1.user_attributes.SSOUserAdditionInfoH\x00R\x0fssoAdditionInfo\x12\x7f\n\x1e\x64irectory_user_additional_info\x18\x08 \x01(\x0b\x32\x38.scalekit.v1.user_attributes.DirectoryUserAdditionalInfoH\x00R\x1b\x64irectoryUserAdditionalInfoB\x11\n\x0f\x61\x64\x64itional_info\"\xc5\x01\n\x13SSOUserAdditionInfo\x12V\n\x14\x64\x65\x66\x61ult_saml_mapping\x18\x01 \x01(\tB$\xbaH!r\x1f\x10\x00\x18\x19\x32\x19^[a-zA-Z][a-zA-Z0-9\\-_]+$R\x12\x64\x65\x66\x61ultSamlMapping\x12V\n\x14\x64\x65\x66\x61ult_oidc_mapping\x18\x02 \x01(\tB$\xbaH!r\x1f\x10\x00\x18\x19\x32\x19^[a-zA-Z][a-zA-Z0-9\\-_]+$R\x12\x64\x65\x66\x61ultOidcMapping\"\x1d\n\x1b\x44irectoryUserAdditionalInfo\"w\n\x1a\x43reateUserAttributeRequest\x12Y\n\x0euser_attribute\x18\x01 \x01(\x0b\x32*.scalekit.v1.user_attributes.UserAttributeB\x06\xbaH\x03\xc8\x01\x01R\ruserAttribute\"p\n\x1b\x43reateUserAttributeResponse\x12Q\n\x0euser_attribute\x18\x01 \x01(\x0b\x32*.scalekit.v1.user_attributes.UserAttributeR\ruserAttribute\"q\n\x1aListUserAttributesResponse\x12S\n\x0fuser_attributes\x18\x01 \x03(\x0b\x32*.scalekit.v1.user_attributes.UserAttributeR\x0euserAttributes\"\x95\x01\n\x1aUpdateUserAttributeRequest\x12\x1c\n\x03key\x18\x01 \x01(\tB\n\xbaH\x07r\x05\x10\x03\x18\xfa\x01R\x03key\x12Y\n\x0euser_attribute\x18\x02 \x01(\x0b\x32*.scalekit.v1.user_attributes.UserAttributeB\x06\xbaH\x03\xc8\x01\x01R\ruserAttribute\"p\n\x1bUpdateUserAttributeResponse\x12Q\n\x0euser_attribute\x18\x01 \x01(\x0b\x32*.scalekit.v1.user_attributes.UserAttributeR\ruserAttribute\":\n\x1a\x44\x65leteUserAttributeRequest\x12\x1c\n\x03key\x18\x01 \x01(\tB\n\xbaH\x07r\x05\x10\x03\x18\xfa\x01R\x03key*j\n\x15UserAttributeDatatype\x12\x18\n\x14UNSPECIFIED_DATATYPE\x10\x00\x12\n\n\x06STRING\x10\x01\x12\n\n\x06NUMBER\x10\x02\x12\x08\n\x04\x42OOL\x10\x03\x12\t\n\x05\x41RRAY\x10\x04\x12\n\n\x06OBJECT\x10\x05*K\n\x15UserAttributeCategory\x12\x18\n\x14UNSPECIFIED_CATEGORY\x10\x00\x12\x0c\n\x08STANDARD\x10\x01\x12\n\n\x06\x43USTOM\x10\x02\x32\x94\r\n\x14UserAttributeService\x12\xf9\x01\n\x16\x43reateSsoUserAttribute\x12\x37.scalekit.v1.user_attributes.CreateUserAttributeRequest\x1a\x38.scalekit.v1.user_attributes.CreateUserAttributeResponse\"l\x82\xb5\x18\x02\x18t\x82\xd3\xe4\x93\x02`\"\x1b/api/v1/sso-user-attributes:\x0euser_attributeZ1\"\x1f/api/v1/user-profile-attributes:\x0euser_attribute\x12\xb6\x01\n\x15ListSsoUserAttributes\x12\x16.google.protobuf.Empty\x1a\x37.scalekit.v1.user_attributes.ListUserAttributesResponse\"L\x82\xb5\x18\x02\x18t\x82\xd3\xe4\x93\x02@\x12\x1b/api/v1/sso-user-attributesZ!\x12\x1f/api/v1/user-profile-attributes\x12\x85\x02\n\x16UpdateSsoUserAttribute\x12\x37.scalekit.v1.user_attributes.UpdateUserAttributeRequest\x1a\x38.scalekit.v1.user_attributes.UpdateUserAttributeResponse\"x\x82\xb5\x18\x02\x18t\x82\xd3\xe4\x93\x02l2!/api/v1/sso-user-attributes/{key}:\x0euser_attributeZ72%/api/v1/user-profile-attributes/{key}:\x0euser_attribute\x12\xc3\x01\n\x16\x44\x65leteSsoUserAttribute\x12\x37.scalekit.v1.user_attributes.DeleteUserAttributeRequest\x1a\x16.google.protobuf.Empty\"X\x82\xb5\x18\x02\x18t\x82\xd3\xe4\x93\x02L*!/api/v1/sso-user-attributes/{key}Z\'*%/api/v1/user-profile-attributes/{key}\x12\xd2\x01\n\x1c\x43reateDirectoryUserAttribute\x12\x37.scalekit.v1.user_attributes.CreateUserAttributeRequest\x1a\x38.scalekit.v1.user_attributes.CreateUserAttributeResponse\"?\x82\xb5\x18\x02\x18t\x82\xd3\xe4\x93\x02\x33\"!/api/v1/directory-user-attributes:\x0euser_attribute\x12\x9f\x01\n\x1bListDirectoryUserAttributes\x12\x16.google.protobuf.Empty\x1a\x37.scalekit.v1.user_attributes.ListUserAttributesResponse\"/\x82\xb5\x18\x02\x18t\x82\xd3\xe4\x93\x02#\x12!/api/v1/directory-user-attributes\x12\xd8\x01\n\x1cUpdateDirectoryUserAttribute\x12\x37.scalekit.v1.user_attributes.UpdateUserAttributeRequest\x1a\x38.scalekit.v1.user_attributes.UpdateUserAttributeResponse\"E\x82\xb5\x18\x02\x18t\x82\xd3\xe4\x93\x02\x39\x32\'/api/v1/directory-user-attributes/{key}:\x0euser_attribute\x12\xa6\x01\n\x1c\x44\x65leteDirectoryUserAttribute\x12\x37.scalekit.v1.user_attributes.DeleteUserAttributeRequest\x1a\x16.google.protobuf.Empty\"5\x82\xb5\x18\x02\x18t\x82\xd3\xe4\x93\x02)*\'/api/v1/directory-user-attributes/{key}B;Z9github.com/scalekit-inc/scalekit/pkg/grpc/user_attributesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'scalekit.v1.user_attributes.user_attributes_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z9github.com/scalekit-inc/scalekit/pkg/grpc/user_attributes'
  _globals['_USERATTRIBUTE'].fields_by_name['key']._loaded_options = None
  _globals['_USERATTRIBUTE'].fields_by_name['key']._serialized_options = b'\272H!r\037\020\003\030\0312\031^[a-zA-Z][a-zA-Z0-9\\-_]+$'
  _globals['_USERATTRIBUTE'].fields_by_name['label']._loaded_options = None
  _globals['_USERATTRIBUTE'].fields_by_name['label']._serialized_options = b'\272H\007r\005\020\003\030\372\001'
  _globals['_USERATTRIBUTE'].fields_by_name['datatype']._loaded_options = None
  _globals['_USERATTRIBUTE'].fields_by_name['datatype']._serialized_options = b'\272H\006\202\001\003\"\001\000'
  _globals['_USERATTRIBUTE'].fields_by_name['category']._loaded_options = None
  _globals['_USERATTRIBUTE'].fields_by_name['category']._serialized_options = b'\340A\003'
  _globals['_SSOUSERADDITIONINFO'].fields_by_name['default_saml_mapping']._loaded_options = None
  _globals['_SSOUSERADDITIONINFO'].fields_by_name['default_saml_mapping']._serialized_options = b'\272H!r\037\020\000\030\0312\031^[a-zA-Z][a-zA-Z0-9\\-_]+$'
  _globals['_SSOUSERADDITIONINFO'].fields_by_name['default_oidc_mapping']._loaded_options = None
  _globals['_SSOUSERADDITIONINFO'].fields_by_name['default_oidc_mapping']._serialized_options = b'\272H!r\037\020\000\030\0312\031^[a-zA-Z][a-zA-Z0-9\\-_]+$'
  _globals['_CREATEUSERATTRIBUTEREQUEST'].fields_by_name['user_attribute']._loaded_options = None
  _globals['_CREATEUSERATTRIBUTEREQUEST'].fields_by_name['user_attribute']._serialized_options = b'\272H\003\310\001\001'
  _globals['_UPDATEUSERATTRIBUTEREQUEST'].fields_by_name['key']._loaded_options = None
  _globals['_UPDATEUSERATTRIBUTEREQUEST'].fields_by_name['key']._serialized_options = b'\272H\007r\005\020\003\030\372\001'
  _globals['_UPDATEUSERATTRIBUTEREQUEST'].fields_by_name['user_attribute']._loaded_options = None
  _globals['_UPDATEUSERATTRIBUTEREQUEST'].fields_by_name['user_attribute']._serialized_options = b'\272H\003\310\001\001'
  _globals['_DELETEUSERATTRIBUTEREQUEST'].fields_by_name['key']._loaded_options = None
  _globals['_DELETEUSERATTRIBUTEREQUEST'].fields_by_name['key']._serialized_options = b'\272H\007r\005\020\003\030\372\001'
  _globals['_USERATTRIBUTESERVICE'].methods_by_name['CreateSsoUserAttribute']._loaded_options = None
  _globals['_USERATTRIBUTESERVICE'].methods_by_name['CreateSsoUserAttribute']._serialized_options = b'\202\265\030\002\030t\202\323\344\223\002`\"\033/api/v1/sso-user-attributes:\016user_attributeZ1\"\037/api/v1/user-profile-attributes:\016user_attribute'
  _globals['_USERATTRIBUTESERVICE'].methods_by_name['ListSsoUserAttributes']._loaded_options = None
  _globals['_USERATTRIBUTESERVICE'].methods_by_name['ListSsoUserAttributes']._serialized_options = b'\202\265\030\002\030t\202\323\344\223\002@\022\033/api/v1/sso-user-attributesZ!\022\037/api/v1/user-profile-attributes'
  _globals['_USERATTRIBUTESERVICE'].methods_by_name['UpdateSsoUserAttribute']._loaded_options = None
  _globals['_USERATTRIBUTESERVICE'].methods_by_name['UpdateSsoUserAttribute']._serialized_options = b'\202\265\030\002\030t\202\323\344\223\002l2!/api/v1/sso-user-attributes/{key}:\016user_attributeZ72%/api/v1/user-profile-attributes/{key}:\016user_attribute'
  _globals['_USERATTRIBUTESERVICE'].methods_by_name['DeleteSsoUserAttribute']._loaded_options = None
  _globals['_USERATTRIBUTESERVICE'].methods_by_name['DeleteSsoUserAttribute']._serialized_options = b'\202\265\030\002\030t\202\323\344\223\002L*!/api/v1/sso-user-attributes/{key}Z\'*%/api/v1/user-profile-attributes/{key}'
  _globals['_USERATTRIBUTESERVICE'].methods_by_name['CreateDirectoryUserAttribute']._loaded_options = None
  _globals['_USERATTRIBUTESERVICE'].methods_by_name['CreateDirectoryUserAttribute']._serialized_options = b'\202\265\030\002\030t\202\323\344\223\0023\"!/api/v1/directory-user-attributes:\016user_attribute'
  _globals['_USERATTRIBUTESERVICE'].methods_by_name['ListDirectoryUserAttributes']._loaded_options = None
  _globals['_USERATTRIBUTESERVICE'].methods_by_name['ListDirectoryUserAttributes']._serialized_options = b'\202\265\030\002\030t\202\323\344\223\002#\022!/api/v1/directory-user-attributes'
  _globals['_USERATTRIBUTESERVICE'].methods_by_name['UpdateDirectoryUserAttribute']._loaded_options = None
  _globals['_USERATTRIBUTESERVICE'].methods_by_name['UpdateDirectoryUserAttribute']._serialized_options = b'\202\265\030\002\030t\202\323\344\223\00292\'/api/v1/directory-user-attributes/{key}:\016user_attribute'
  _globals['_USERATTRIBUTESERVICE'].methods_by_name['DeleteDirectoryUserAttribute']._loaded_options = None
  _globals['_USERATTRIBUTESERVICE'].methods_by_name['DeleteDirectoryUserAttribute']._serialized_options = b'\202\265\030\002\030t\202\323\344\223\002)*\'/api/v1/directory-user-attributes/{key}'
  _globals['_USERATTRIBUTEDATATYPE']._serialized_start=1884
  _globals['_USERATTRIBUTEDATATYPE']._serialized_end=1990
  _globals['_USERATTRIBUTECATEGORY']._serialized_start=1992
  _globals['_USERATTRIBUTECATEGORY']._serialized_end=2067
  _globals['_USERATTRIBUTE']._serialized_start=396
  _globals['_USERATTRIBUTE']._serialized_end=975
  _globals['_SSOUSERADDITIONINFO']._serialized_start=978
  _globals['_SSOUSERADDITIONINFO']._serialized_end=1175
  _globals['_DIRECTORYUSERADDITIONALINFO']._serialized_start=1177
  _globals['_DIRECTORYUSERADDITIONALINFO']._serialized_end=1206
  _globals['_CREATEUSERATTRIBUTEREQUEST']._serialized_start=1208
  _globals['_CREATEUSERATTRIBUTEREQUEST']._serialized_end=1327
  _globals['_CREATEUSERATTRIBUTERESPONSE']._serialized_start=1329
  _globals['_CREATEUSERATTRIBUTERESPONSE']._serialized_end=1441
  _globals['_LISTUSERATTRIBUTESRESPONSE']._serialized_start=1443
  _globals['_LISTUSERATTRIBUTESRESPONSE']._serialized_end=1556
  _globals['_UPDATEUSERATTRIBUTEREQUEST']._serialized_start=1559
  _globals['_UPDATEUSERATTRIBUTEREQUEST']._serialized_end=1708
  _globals['_UPDATEUSERATTRIBUTERESPONSE']._serialized_start=1710
  _globals['_UPDATEUSERATTRIBUTERESPONSE']._serialized_end=1822
  _globals['_DELETEUSERATTRIBUTEREQUEST']._serialized_start=1824
  _globals['_DELETEUSERATTRIBUTEREQUEST']._serialized_end=1882
  _globals['_USERATTRIBUTESERVICE']._serialized_start=2070
  _globals['_USERATTRIBUTESERVICE']._serialized_end=3754
# @@protoc_insertion_point(module_scope)
