# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from scalekit.v1.auth import passwordless_pb2 as scalekit_dot_v1_dot_auth_dot_passwordless__pb2


class PasswordlessServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SendPasswordlessEmail = channel.unary_unary(
                '/scalekit.v1.auth.passwordless.PasswordlessService/SendPasswordlessEmail',
                request_serializer=scalekit_dot_v1_dot_auth_dot_passwordless__pb2.SendPasswordlessRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_auth_dot_passwordless__pb2.SendPasswordlessResponse.FromString,
                )
        self.VerifyPasswordlessEmail = channel.unary_unary(
                '/scalekit.v1.auth.passwordless.PasswordlessService/VerifyPasswordlessEmail',
                request_serializer=scalekit_dot_v1_dot_auth_dot_passwordless__pb2.VerifyPasswordLessRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_auth_dot_passwordless__pb2.VerifyPasswordLessResponse.FromString,
                )
        self.ResendPasswordlessEmail = channel.unary_unary(
                '/scalekit.v1.auth.passwordless.PasswordlessService/ResendPasswordlessEmail',
                request_serializer=scalekit_dot_v1_dot_auth_dot_passwordless__pb2.ResendPasswordlessRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_auth_dot_passwordless__pb2.SendPasswordlessResponse.FromString,
                )


class PasswordlessServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def SendPasswordlessEmail(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VerifyPasswordlessEmail(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResendPasswordlessEmail(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PasswordlessServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SendPasswordlessEmail': grpc.unary_unary_rpc_method_handler(
                    servicer.SendPasswordlessEmail,
                    request_deserializer=scalekit_dot_v1_dot_auth_dot_passwordless__pb2.SendPasswordlessRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_auth_dot_passwordless__pb2.SendPasswordlessResponse.SerializeToString,
            ),
            'VerifyPasswordlessEmail': grpc.unary_unary_rpc_method_handler(
                    servicer.VerifyPasswordlessEmail,
                    request_deserializer=scalekit_dot_v1_dot_auth_dot_passwordless__pb2.VerifyPasswordLessRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_auth_dot_passwordless__pb2.VerifyPasswordLessResponse.SerializeToString,
            ),
            'ResendPasswordlessEmail': grpc.unary_unary_rpc_method_handler(
                    servicer.ResendPasswordlessEmail,
                    request_deserializer=scalekit_dot_v1_dot_auth_dot_passwordless__pb2.ResendPasswordlessRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_auth_dot_passwordless__pb2.SendPasswordlessResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'scalekit.v1.auth.passwordless.PasswordlessService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class PasswordlessService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def SendPasswordlessEmail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.auth.passwordless.PasswordlessService/SendPasswordlessEmail',
            scalekit_dot_v1_dot_auth_dot_passwordless__pb2.SendPasswordlessRequest.SerializeToString,
            scalekit_dot_v1_dot_auth_dot_passwordless__pb2.SendPasswordlessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def VerifyPasswordlessEmail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.auth.passwordless.PasswordlessService/VerifyPasswordlessEmail',
            scalekit_dot_v1_dot_auth_dot_passwordless__pb2.VerifyPasswordLessRequest.SerializeToString,
            scalekit_dot_v1_dot_auth_dot_passwordless__pb2.VerifyPasswordLessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResendPasswordlessEmail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.auth.passwordless.PasswordlessService/ResendPasswordlessEmail',
            scalekit_dot_v1_dot_auth_dot_passwordless__pb2.ResendPasswordlessRequest.SerializeToString,
            scalekit_dot_v1_dot_auth_dot_passwordless__pb2.SendPasswordlessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
