# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from scalekit.v1.tools import tools_pb2 as scalekit_dot_v1_dot_tools_dot_tools__pb2


class ToolServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateTool = channel.unary_unary(
                '/scalekit.v1.tools.ToolService/CreateTool',
                request_serializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.CreateToolRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.CreateToolResponse.FromString,
                )
        self.ListTools = channel.unary_unary(
                '/scalekit.v1.tools.ToolService/ListTools',
                request_serializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.ListToolsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.ListToolsResponse.FromString,
                )
        self.ListScopedTools = channel.unary_unary(
                '/scalekit.v1.tools.ToolService/ListScopedTools',
                request_serializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.ListScopedToolsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.ListScopedToolsResponse.FromString,
                )
        self.SetToolDefault = channel.unary_unary(
                '/scalekit.v1.tools.ToolService/SetToolDefault',
                request_serializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.SetToolDefaultRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.SetToolDefaultResponse.FromString,
                )
        self.UpdateTool = channel.unary_unary(
                '/scalekit.v1.tools.ToolService/UpdateTool',
                request_serializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.UpdateToolRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.UpdateToolResponse.FromString,
                )
        self.DeleteTool = channel.unary_unary(
                '/scalekit.v1.tools.ToolService/DeleteTool',
                request_serializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.DeleteToolRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ExecuteTool = channel.unary_unary(
                '/scalekit.v1.tools.ToolService/ExecuteTool',
                request_serializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.ExecuteToolRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.ExecuteToolResponse.FromString,
                )


class ToolServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateTool(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListTools(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListScopedTools(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetToolDefault(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateTool(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteTool(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExecuteTool(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ToolServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateTool': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateTool,
                    request_deserializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.CreateToolRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.CreateToolResponse.SerializeToString,
            ),
            'ListTools': grpc.unary_unary_rpc_method_handler(
                    servicer.ListTools,
                    request_deserializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.ListToolsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.ListToolsResponse.SerializeToString,
            ),
            'ListScopedTools': grpc.unary_unary_rpc_method_handler(
                    servicer.ListScopedTools,
                    request_deserializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.ListScopedToolsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.ListScopedToolsResponse.SerializeToString,
            ),
            'SetToolDefault': grpc.unary_unary_rpc_method_handler(
                    servicer.SetToolDefault,
                    request_deserializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.SetToolDefaultRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.SetToolDefaultResponse.SerializeToString,
            ),
            'UpdateTool': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateTool,
                    request_deserializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.UpdateToolRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.UpdateToolResponse.SerializeToString,
            ),
            'DeleteTool': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteTool,
                    request_deserializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.DeleteToolRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ExecuteTool': grpc.unary_unary_rpc_method_handler(
                    servicer.ExecuteTool,
                    request_deserializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.ExecuteToolRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.ExecuteToolResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'scalekit.v1.tools.ToolService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ToolService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateTool(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.tools.ToolService/CreateTool',
            scalekit_dot_v1_dot_tools_dot_tools__pb2.CreateToolRequest.SerializeToString,
            scalekit_dot_v1_dot_tools_dot_tools__pb2.CreateToolResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListTools(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.tools.ToolService/ListTools',
            scalekit_dot_v1_dot_tools_dot_tools__pb2.ListToolsRequest.SerializeToString,
            scalekit_dot_v1_dot_tools_dot_tools__pb2.ListToolsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListScopedTools(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.tools.ToolService/ListScopedTools',
            scalekit_dot_v1_dot_tools_dot_tools__pb2.ListScopedToolsRequest.SerializeToString,
            scalekit_dot_v1_dot_tools_dot_tools__pb2.ListScopedToolsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetToolDefault(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.tools.ToolService/SetToolDefault',
            scalekit_dot_v1_dot_tools_dot_tools__pb2.SetToolDefaultRequest.SerializeToString,
            scalekit_dot_v1_dot_tools_dot_tools__pb2.SetToolDefaultResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateTool(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.tools.ToolService/UpdateTool',
            scalekit_dot_v1_dot_tools_dot_tools__pb2.UpdateToolRequest.SerializeToString,
            scalekit_dot_v1_dot_tools_dot_tools__pb2.UpdateToolResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteTool(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.tools.ToolService/DeleteTool',
            scalekit_dot_v1_dot_tools_dot_tools__pb2.DeleteToolRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExecuteTool(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.tools.ToolService/ExecuteTool',
            scalekit_dot_v1_dot_tools_dot_tools__pb2.ExecuteToolRequest.SerializeToString,
            scalekit_dot_v1_dot_tools_dot_tools__pb2.ExecuteToolResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
